Summary: The Linux kernel (the core of the Linux operating system)

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows and
# no contrary --with/--without arguments are given on the command line.

%define buildup 1
%define buildsmp 1
%define buildBOOT 1
%define buildhugemem 1
%define buildsource 1

# Versions of various parts
%define rh_release_major 3
%define rh_release_minor 9

#
# Polite request for people who spin their own kernel rpms:
# please modify the "release" field in a way that identifies
# that the kernel isn't the stock RHL kernel, for example by
# adding some text to the end of the version number.
#
%define release 53.EL
%define sublevel 21
%define kversion 2.4.%{sublevel}
# /usr/src/%{kslnk} -> /usr/src/linux-%{KVERREL}
%define kslnk linux-2.4
%define KVERREL %{PACKAGE_VERSION}-%{PACKAGE_RELEASE}

# groups of related archs
%define all_x86 i386 i686 athlon
%define all_x86_64 x86_64 ia32e
%define all_ppc64 ppc64 ppc64pseries ppc64iseries

#
# RPM magic
#
%define _missing_doc_files_terminate_build    0
%define _unpackaged_files_terminate_build 0
# disable build root strip policy
%define __spec_install_post /usr/lib/rpm/brp-compress || :


# Override generic defaults with per-arch defaults 
# These must ONLY be "0", never "1"

# First, architecture-specific kernels off on all other archs (ifnarch)
%ifnarch i686
%define buildhugemem 0
%endif
%ifnarch i386 
%define buildBOOT 0
%endif
%ifnarch i386 x86_64 ia64 s390 s390x ppc64
%define buildsource 0
%endif

# Second, per-architecture exclusions (ifarch)
%ifarch i386
%define buildsmp 0
%define buildup 0
%endif
%ifarch i586
%define buildsmp 0
%endif
%ifarch s390 s390x
%define buildsmp 0
%endif
%ifarch ppc64
%define buildup 0
%define buildsmp 0
%define buildBOOT 0
%define buildhugemem 0
%endif
%ifarch ppc64pseries ppc64iseries
%define buildsmp 0
%endif
%ifarch ia64
%define buildsmp 0
%endif
%ifarch ia32e
%define buildsmp 0
%endif

%ifarch ia64
%define image_install_path boot/efi/EFI/redhat
%else
%define image_install_path boot
%endif

%ifarch %{all_x86} %{all_x86_64}
%define buildtarget bzImage
%endif
%ifarch s390 s390x
%define buildtarget image
%endif
%ifarch %{all_ppc64}
%define buildtarget boot
%endif
%ifarch ia64
%define buildtarget compressed
%endif

#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.4 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts  ppp <= 2.3.15, pcmcia-cs <= 3.1.20, isdn4k-utils <= 3.0, mount < 2.10r-5, nfs-utils < 0.3.1, e2fsprogs < 1.22 

# 
# Then a series of requirements that are Red Hat specific, either 
# because we add patches for something, or the older versions have 
# problems with the newer kernel or lack certain things that make 
# integration in the distro harder than needed.
#
%define package_conflicts  cipe < 1.4.5, tux < 2.1.0, kudzu <= 0.92, initscripts < 6.41, dev < 3.2-7, iptables < 1.2.5-3, bcm5820 < 1.81, nvidia-rh72 <= 1.0, oprofile < 0.4, ipsec-tools <= 0.2.2-5, s390utils < 1.2.4-3

#
# Several packages had bugs in them that became obvious when the NPTL
# threading code got integrated. 
#
%define nptl_conflicts SysVinit < 2.84-13, pam < 0.75-48, vixie-cron < 3.0.1-73, privoxy < 3.0.0-8, spamassassin < 2.44-4.8.x,  cups < 1.1.17-13

#
# Things that need to be installed before the kernel is, because the %post
# scripts use them.
#
%define kernel_prereq  fileutils, modutils >=  2.4.18, initscripts >= 5.83, mkinitrd >= 3.2.6


Name: kernel
Group: System Environment/Kernel
License: GPLv2
Version: %{kversion}
Release: %{release}
ExclusiveArch: %{all_x86} %{all_x86_64} s390 s390x %{all_ppc64} ia64
ExclusiveOS: Linux
Obsoletes: kernel-modules
Provides: kernel = %{version}
Provides: kernel-drm = 4.1.0, kernel-drm = 4.2.0, kernel-drm = 4.3.0 
Autoreqprov: no
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}

BuildPreReq: modutils >= 2.4.21-1, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildPreReq: bzip2, findutils, dev, gzip, m4, perl
# BuildProvides: rhbuildsys(ParallelBuild) <= 8
BuildConflicts: rhbuildsys(DiskFree) < 500Mb
BuildRequires: gcc >= 2.96-98

Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.4/linux-%{kversion}.tar.bz2

Source10: COPYING.modules
Source11: linux-rhconfig.h
Source12: linux-merge-config.awk
Source13: linux-merge-modules.awk
Source14: linux-modules-unsupported
Source15: linux-modules-unsupported-hugemem

Source20: kernel-%{kversion}-i386.config
Source21: kernel-%{kversion}-i386-BOOT.config
Source22: kernel-%{kversion}-i686.config
Source23: kernel-%{kversion}-i686-smp.config
Source24: kernel-%{kversion}-i586.config
Source25: kernel-%{kversion}-i586-smp.config
Source26: kernel-%{kversion}-i686-hugemem.config
Source27: kernel-%{kversion}-athlon.config
Source28: kernel-%{kversion}-athlon-smp.config
Source29: kernel-%{kversion}-x86_64.config
Source30: kernel-%{kversion}-x86_64-smp.config
Source31: kernel-%{kversion}-s390.config
Source32: kernel-%{kversion}-s390x.config
Source33: kernel-%{kversion}-ppc64pseries.config
Source34: kernel-%{kversion}-ppc64iseries.config
Source35: kernel-%{kversion}-ia64.config
Source36: kernel-%{kversion}-ppc64.config
Source37: kernel-%{kversion}-ia32e.config

#
# Patches 0 through 99 are meant for core subsystem upgrades
#

Patch2: linux-2.4.21-dailybk.patch
# select bits from 2.4 upstream
Patch3: linux-2.4.21-select-upstream-bits.patch
# -ac patch, minus ACPI, dm, irqbalance, XAPIC and XFS
Patch4: linux-2.4.21-selected-ac-bits.patch

Patch10: linux-2.4.20-o1-nptl.patch
Patch20: linux-2.4.21-o1-fairness.patch
Patch30: linux-2.4.21-compat.patch
Patch40: linux-2.4.21-o1-ht.patch

# 
# Patches 100 through 500 are architecture specific patches
# Each architecture has 80 slots reserved.
#

# x86 is 100 - 179
Patch100: linux-2.4.20-x86-syscalls.patch
Patch110: linux-2.4.20-x86-oprofile.patch
Patch115: linux-2.4.21-x86-acpi.patch
Patch120: linux-2.4.21-x86-xapic.patch
Patch123: linux-2.4.21-x86-nx-support.patch
Patch125: linux-2.4.21-x86-ucode-loader.patch
Patch130: linux-2.4.21-amd-golem.patch

# X86-64 is 180 - 259
Patch180: linux-2.4.21-amd64.patch
Patch181: linux-2.4.21-amd64-o1.patch
Patch190: linux-2.4.20-amd64-oprofile.patch
Patch200: linux-2.4.21-amd64-compat.patch
Patch201: linux-2.4.21-amd64-coredump-fix.patch
Patch202: linux-2.4.21-amd64-acpi.patch
Patch203: linux-2.4.21-amd64-siginfo_t.patch
Patch204: linux-2.4.21-amd64-numa-support.patch
Patch210: linux-2.4.21-ia32e-support.patch
Patch211: linux-2.4.21-amd64-xapic.patch
Patch212: linux-2.4.21-amd64-fpu.patch

# IA64 is 260 - 339
Patch260: linux-2.4.20-ia64-syscalls.patch
Patch262: linux-2.4.20-ia64-core.patch
Patch264: linux-2.4.20-ia64-signals.patch
Patch266: linux-2.4.20-ia64-irq.patch
Patch268: linux-2.4.20-ia64-o1-nptl.patch
Patch270: linux-2.4.21-ia64-compat.patch
Patch272: linux-2.4.20-ia64-oprofile.patch
Patch273: linux-2.4.20-ia64-perfmon.patch
Patch274: linux-2.4.20-ia64-mcadump.patch
Patch275: linux-2.4.21-ia64-salinfo.patch
Patch276: linux-2.4.21-ia64-fancyiommu.patch
Patch278: linux-2.4.21-ia64-cyclone.patch
Patch279: linux-2.4.21-ia64-montecito.patch

# PPC is 340 - 419
Patch340: linux-2.4.21-ppc64-core.patch
Patch341: linux-2.4.21-early-console.patch
Patch342: linux-2.4.21-iseries-drivers.patch
Patch343: linux-2.4.21-ppc64-nptl.patch
Patch344: linux-2.4.21-ppc64-aio.patch
Patch345: linux-2.4.21-ppc64-syscalls.patch
Patch346: linux-2.4.21-ppc64-flags.patch
Patch347: linux-2.4.21-ppc64-biarch.patch
Patch348: linux-2.4.21-ppc64-pseries-makefile.patch
Patch349: linux-2.4.21-ppc64-dump_fpu.patch
Patch350: linux-2.4.21-ppc64-kallsyms.patch
Patch351: linux-2.4.21-ppc64-ptrace.patch
Patch352: linux-2.4.20-ppc64-bitops.patch
Patch353: linux-2.4.21-ppc64-compat.patch
Patch354: linux-2.4.21-ppc64-strip-kernel.patch
Patch355: linux-2.4.21-ppc64-oprofile.patch
Patch356: linux-2.4.21-ppc64-wchan.patch
Patch357: linux-2.4.21-ppc64-scsi_timeout.patch
Patch358: linux-2.4.21-ppc64-ethtool-ioctl32.patch
Patch359: linux-2.4.21-ppc64-enable-xmon.patch
Patch360: linux-2.4.21-ppc64-ras-support.patch
Patch361: linux-2.4.21-ppc64-pci-multifunc.patch
Patch362: linux-2.4.21-ppc64-power-blade.patch
Patch363: linux-2.4.21-ppc64-lparcfg.patch
Patch364: linux-2.4.21-ppc64-segtab.patch
Patch365: linux-2.4.21-ppc64-signal-fixes.patch
Patch370: linux-2.4.21-ppc64-power5-base.patch
Patch371: linux-2.4.21-ppc64-power5-locks.patch
Patch372: linux-2.4.21-ppc64-power5-irq.patch
Patch373: linux-2.4.21-ppc64-power5-vio.patch
Patch374: linux-2.4.21-ppc64-power5-hvsi.patch

# S390 is 420 - 499
Patch420: linux-2.4.20-s390-common.patch
Patch422: linux-2.4.20-s390-o1-nptl.patch
Patch432: linux-2.4.20-s390-aio.patch
Patch437: linux-2.4.20-s390-compat.patch
Patch439: linux-2.4.20-s390-elfper.patch
Patch440: linux-2.4.20-s390-maxargs25.patch
Patch441: linux-2.4.20-s390-lcs.patch
Patch442: linux-2.4.20-s390-oprofile.patch
Patch443: linux-2.4.21-s390-bug97055.patch
Patch444: linux-2.4.21-s390-ctc_carrier.patch
Patch459: linux-2.4.20-s390-make390x.patch
Patch460: linux-2.4.20-s390-misc.patch
Patch461: linux-2.4.21-s390-cio.patch
Patch462: linux-2.4.21-s390-ctc-locking.patch
Patch463: linux-2.4.21-s390-iucv-update.patch

#
# Patches 600 through 1000 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#
Patch600: linux-2.4.0-nonintconfig.patch
Patch610: linux-2.4.18-flock.patch
Patch620: linux-2.4.7-quotareturn.patch
Patch630: linux-2.2.16-rhconfig.patch
Patch640: linux-2.4.2-changeloop.patch
Patch650: linux-2.4.18-loopfixes.patch
Patch660: linux-2.4.2-scsi_scan.patch
Patch670: linux-2.4.9-kksymoops.patch
Patch680: linux-2.4.9-kallsyms.patch
Patch690: linux-2.4.18-dmi-hall-of-shame.patch
Patch700: linux-2.4.20-extra_cflags.patch
Patch710: linux-2.4.18-laptopbits.patch
Patch720: linux-2.4.21-binfmt-elf.patch
Patch730: linux-2.4.20-pci_64b_bar.patch
Patch750: linux-2.4.20-aio.patch
Patch770: linux-2.4.20-varyio.patch
Patch780: linux-2.4.20-superbh.patch
Patch781: linux-2.4.20-superbh-aio.patch
Patch790: linux-2.4.20-oprofile.patch
Patch800: linux-2.4.21-semtimedop.patch
Patch810: linux-2.4.21-pci_large_bus.patch
Patch820: linux-2.4.21-logbufsize.patch
Patch830: linux-2.4.20-elevator.patch
Patch840: linux-2.4.21-tux.patch
Patch850: linux-2.4.21-odirect.patch
Patch860: linux-2.4.21-semaphore-scale.patch
Patch870: linux-2.4.21-sysrq-allcpus.patch
Patch871: linux-2.4.21-sticky-sysrq.patch
Patch880: linux-2.4.21-iorl.patch
Patch890: linux-2.4.21-compat-32.patch
Patch900: linux-2.4.21-binfmt-interp.patch
Patch910: linux-2.4.21-strncpy-zero-pad.patch
Patch920: linux-2.4.21-rwsem-updates.patch
Patch930: linux-2.4.21-siginfo-mismatch.patch

#
# Patches 1000 to 2000 are reserved for VM changes.
#
Patch1000: linux-2.4.21-rmap.patch
Patch1020: linux-2.4.21-rmap-updates.patch
Patch1025: linux-2.4.21-rmap-chain-ptep.patch
Patch1030: linux-2.4.21-iowait.patch
Patch1040: linux-2.4.20-virtual_memmap.patch
Patch1050: linux-2.4.21-mlock.patch
Patch1060: linux-2.4.21-x86-4Gsplit.patch
Patch1070: linux-2.4.20-fix-pausing.patch
Patch1080: linux-2.4.21-dma-isolation.patch
Patch1090: linux-2.4.21-vma-merging.patch
Patch1100: linux-2.4.21-exec-shield.patch
Patch1110: linux-2.4.21-pagecache-scale.patch
Patch1120: linux-2.4.21-flexible-mmap.patch
Patch1130: linux-2.4.21-remap_file_pages.patch
Patch1140: linux-2.4.20-statm.patch
Patch1141: linux-2.4.21-pte-clear.patch
Patch1150: linux-2.4.21-hugetlbfs.patch
Patch1151: linux-2.4.21-hugetlbfs-ia64.patch
Patch1160: linux-2.4.21-tunable-overcommit.patch
Patch1170: linux-2.4.21-x86-4G-lockless.patch
Patch1180: linux-2.4.21-mmap-updates.patch
Patch1190: linux-2.4.21-crosshost-mmap.patch
Patch1200: linux-2.4.21-3G-personality.patch
Patch1210: linux-2.4.21-s390-dirtybit.patch
Patch1220: linux-2.4.21-bufhead-reduction.patch
Patch1223: linux-2.4.21-refill-inactive-zone.patch
Patch1224: linux-2.4.21-ptes-from-highmem.patch
Patch1225: linux-2.4.21-page-deact-scale.patch
Patch1226: linux-2.4.21-ramfs-wired-lists.patch
Patch1227: linux-2.4.21-balance-page-alloc.patch
Patch1228: linux-2.4.21-enhanced-show-mem.patch
Patch1229: linux-2.4.21-oom-kill-updates.patch
Patch1230: linux-2.4.21-aio-safe-free-pages.patch
Patch1240: linux-2.4.21-ppc64-pte-hash-lock.patch
Patch1250: linux-2.4.21-bootmem-hash-alloc.patch
Patch1251: linux-2.4.21-odirect-with-bufio.patch
Patch1252: linux-2.4.21-page-pin-counts.patch
Patch1260: linux-2.4.21-insert-vm-struct.patch
Patch1270: linux-2.4.21-ptrace-restore-perms.patch
Patch1280: linux-2.4.21-change-page-attr.patch

#
# Patches 2000 to 5000 are reserved for the network protocol subsystem
#
Patch2000: linux-2.4.21-ipsec.patch
Patch2010: linux-2.4.21-ipsec-compilefixes.patch
Patch2020: linux-2.4.21-igmpv3.patch
Patch2030: linux-2.4.21-ipvs.patch
Patch2040: linux-2.4.21-max-addr-len.patch
Patch2050: linux-2.4.20-aio-poll-and-net.patch
Patch2060: linux-2.4.21-nptl-network.patch
Patch2070: linux-2.4.21-netfixes.patch
Patch2080: linux-2.4.21-ethtool_ops.patch
Patch2090: linux-2.4.21-cmsg-validation.patch
Patch2100: linux-2.4.21-ipfrag-flush.patch
Patch2110: linux-2.4.21-arp-announce.patch

#
# Patches 5000 to 7000 are reserved for bugfixes, changes and updates to
# existing drivers and filesystems
#
Patch5000: linux-2.4.18-nousb.patch
Patch5010: linux-2.4.0-test11-vidfail.patch
Patch5020: linux-2.4.0-e820.patch
Patch5030: linux-2.4.2-page_bitmap.patch
Patch5040: linux-2.4.0-apic-quiet.patch
Patch5050: linux-2.4.20-irixnfs.patch
Patch5060: linux-2.4.3-pcipenalty.patch
Patch5070: linux-2.4.2-keyboardsilence.patch
Patch5080: linux-2.4.7-scsitimeout.patch
Patch5090: linux-2.4.9-freevxfs.patch
Patch5100: linux-2.4.9-nmiprofiling.patch
Patch5110: linux-2.4.18-moreunnamed.patch
Patch5120: linux-2.4.20-lvm-updates.patch
Patch5121: linux-2.4.17-lvm-bulkcopy.patch
Patch5122: linux-2.4.17-lvm-pvmove.patch
Patch5123: linux-2.4.18-lvm-VFSlock.patch
Patch5124: linux-2.4.21-lvm-compat.patch
Patch5125: linux-2.4.21-lvm-varyio.patch
Patch5130: linux-2.4.18-input-35215.patch
Patch5135: linux-2.4.21-dev-random-updates.patch
Patch5140: linux-2.4.20-egenera-scan-new-devices.patch
Patch5150: linux-2.4.21-scsi-dump-status.patch
Patch5160: linux-2.4.9-scsilun0.patch
Patch5170: linux-2.4.18-netdump.patch
Patch5175: linux-2.4.21-diskdump.patch
Patch5176: linux-2.4.21-diskdump-scsi.patch
Patch5177: linux-2.4.21-diskdump-block.patch
Patch5178: linux-2.4.21-nmi-trigger-switch.patch
Patch5179: linux-2.4.21-init-trigger-switch.patch
Patch5180: linux-2.4.21-ide-driver-updates.patch
Patch5220: linux-2.4.7-suspend.patch
Patch5230: linux-2.4.18-orinoco.patch
Patch5250: linux-2.4.18-scsidevices.patch
Patch5260: linux-2.4.18-usb-bug56856.patch
Patch5270: linux-2.4.20-usb-bug81091.patch
Patch5280: linux-2.4.20-usb-bug82546.patch
Patch5288: linux-2.4.20-usb-bug98264.patch
Patch5290: linux-2.4.20-usb-updates.patch
Patch5300: linux-2.4.21-sound-updates.patch
Patch5390: linux-2.4.21-isofs-updates.patch
Patch5395: linux-2.4.21-smbfs-updates.patch
Patch5396: linux-2.4.21-cramfs-updates.patch
Patch5400: linux-2.4.20-deepersymlink.patch
Patch5410: linux-2.4.20-acpi-updates.patch
Patch5411: linux-2.4.21-ia64-acpi.patch
Patch5412: linux-2.4.21-ipmi-update.patch
Patch5413: linux-2.4.21-acpi-serial.patch
Patch5420: linux-2.4.21-matroxfb.patch
Patch5430: linux-2.4.21-sym53c8xx.patch
Patch5431: linux-2.4.21-sym53c8xx-diskdump.patch
Patch5440: linux-2.4.21-cmpci-update.patch
Patch5450: linux-2.4.21-raid-autorun.patch
Patch5460: linux-2.4.20-nfs-odirectfix.patch
Patch5470: linux-2.4.20-nfsd-deadsocks.patch
Patch5480: linux-2.4.20-nfsd-flowcontrol.patch
Patch5500: linux-2.4.21-inode-delete-race.patch
Patch5510: linux-2.4.21-vfs-unmount-race.patch
Patch5520: linux-2.4.21-xattr-core.patch
Patch5530: linux-2.4.21-xattr-ext3.patch
Patch5540: linux-2.4.21-xattr-syscalls.patch
Patch5550: linux-2.4.21-acl-core.patch
Patch5560: linux-2.4.21-acl-ext3.patch
Patch5570: linux-2.4.21-acl-nfs.patch
Patch5580: linux-2.4.21-xattr-vm.patch
Patch5590: linux-2.4.21-lockd-svc.patch
Patch5600: linux-2.4.21-lockd-blkreq.patch
Patch5610: linux-2.4.20-nfsd-expacl.patch
Patch5620: linux-2.4.21-nfs-tcp-discon-race.patch
Patch5630: linux-2.4.21-nfs-tcp-reconn.patch
Patch5640: linux-2.4.21-nfsd-aclfix.patch
Patch5650: linux-2.4.21-lockd-resvport.patch
Patch5660: linux-2.4.21-nfs-acl-otw.patch
Patch5670: linux-2.4.21-scsi-timer.patch
Patch5675: linux-2.4.21-ips-update.patch
Patch5680: linux-2.4.21-cciss-update.patch
Patch5681: linux-2.4.21-cciss-diskdump.patch
Patch5685: linux-2.4.21-st-update.patch
Patch5690: linux-2.4.21-megaraid-update.patch
Patch5691: linux-2.4.21-megaraid-varyio.patch
Patch5692: linux-2.4.21-megaraid-diskdump.patch
Patch5700: linux-2.4.21-nfs-tcp-corrup.patch
Patch5710: linux-2.4.21-nfs-xdr-kmap.patch
Patch5720: linux-2.4.21-nfs-64aligned.patch
Patch5730: linux-2.4.21-aic7xxx-update.patch
Patch5731: linux-2.4.21-aic7xxx-iorl.patch
Patch5732: linux-2.4.21-aic7xxx-varyio.patch
Patch5733: linux-2.4.21-aic7xxx-diskdump.patch
Patch5735: linux-2.4.21-dpt_i2o-update.patch
Patch5736: linux-2.4.21-dpt_i2o-diskdump.patch
Patch5740: linux-2.4.21-cpqarray-update.patch
Patch5745: linux-2.4.21-aacraid-update.patch
Patch5748: linux-2.4.21-siimage-update.patch
Patch5750: linux-2.4.20-autofs4-update.patch
Patch5760: linux-2.4.21-3ware-update.patch
Patch5770: linux-2.4.21-emu10k1.patch
Patch5780: linux-2.4.21-acl-jfs.patch
Patch5790: linux-2.4.21-nfs-failover.patch
Patch5800: linux-2.4.21-scsi-device-list.patch
Patch5810: linux-2.4.21-lvm-rwsem-irq.patch
Patch5820: linux-2.4.21-ext3-acl-update.patch
Patch5821: linux-2.4.21-jbd-acl-update.patch
Patch5822: linux-2.4.21-nfsd-acl-hangfix.patch
Patch5830: linux-2.4.21-nfsd-reusefix.patch
Patch5840: linux-2.4.21-nfsd-acl-update.patch
Patch5850: linux-2.4.21-nfs-clu-opps.patch
Patch5860: linux-2.4.21-nfs-highmemfix.patch
Patch5870: linux-2.4.21-cdrom-compat.patch
Patch5880: linux-2.4.21-nfs-softirqs.patch
Patch5890: linux-2.4.21-knfsd-symlink-error.patch
Patch5900: linux-2.4.21-knfsd-missing-locks.patch
Patch5910: linux-2.4.21-lockd-blockedlks.patch
Patch5920: linux-2.4.21-i810-update.patch
Patch5930: linux-2.4.21-netdrvr-fixes.patch
Patch5931: linux-2.4.21-e100-update.patch
Patch5932: linux-2.4.21-e1000-update.patch
Patch5933: linux-2.4.21-r8169-update.patch
Patch5934: linux-2.4.21-vlan-update.patch
Patch5935: linux-2.4.21-aironet-update.patch
Patch5936: linux-2.4.21-pcnet32-update.patch
Patch5937: linux-2.4.21-3c59x-update.patch
Patch5938: linux-2.4.21-8139too-update.patch
Patch5940: linux-2.4.21-usb-ohci.patch
Patch5950: linux-2.4.21-lockd-sysctlif.patch
Patch5960: linux-2.4.21-sunrpc-calldecode.patch
Patch5970: linux-2.4.21-tg3.patch
Patch5980: linux-2.4.21-pci-ids.patch
Patch5990: linux-2.4.21-md-multipath.patch
Patch6000: linux-2.4.21-nfs-vxfs.patch
Patch6010: linux-2.4.21-lastsector.patch
Patch6020: linux-2.4.18-netdump-drivers.patch
Patch6030: linux-2.4.21-fdunshare.patch
Patch6040: linux-2.4.21-nfs-nfsrootfail.patch
Patch6050: linux-2.4.21-nfs-accesscache.patch
Patch6060: linux-2.4.21-nfs-solaris_acls.patch
Patch6065: linux-2.4.21-nfs-stack-usage.patch
Patch6070: linux-2.4.21-nfs-callreserve.patch
Patch6080: linux-2.4.21-nfs-softmnts.patch
Patch6090: linux-2.4.21-nfs-updates.patch
Patch6091: linux-2.4.21-nfs-estale.patch
Patch6092: linux-2.4.21-nfs-aio-sync.patch
Patch6100: linux-2.4.21-proc-tty-driver.patch
Patch6110: linux-2.4.21-ncpfs-updates.patch
Patch6120: linux-2.4.21-fatfs-updates.patch
Patch6200: linux-2.4.21-gfs-enablers.patch
Patch6210: linux-2.4.21-statfs64-support.patch
Patch6220: linux-2.4.21-o-sync-eio-propagation.patch

#
# Patches 7000 to 8000 are reserved for scalability fixes
# that touch various subsystems
#
Patch7000: linux-2.4.21-gendisk-scale.patch
Patch7001: linux-2.4.21-2TB-partition.patch
Patch7010: linux-2.4.21-kstat-percpu.patch
Patch7020: linux-2.4.21-gettimeofday-scale.patch
Patch7030: linux-2.4.21-scsi-affine-queue.patch
Patch7040: linux-2.4.21-scsi-softirq.patch
Patch7045: linux-2.4.21-scsi-dynamic-add.patch
Patch7050: linux-2.4.21-scsi-rqlock-scale.patch
Patch7055: linux-2.4.21-scsi-queue-fixes.patch
Patch7060: linux-2.4.21-scalable-timers.patch
Patch7065: linux-2.4.21-filtered-wakeup.patch
Patch7070: linux-2.4.21-slab-scale.patch
Patch7080: linux-2.4.21-kiobuf-fixes.patch
Patch7081: linux-2.4.21-aio-odirect-blkdev.patch
Patch7090: linux-2.4.21-proc_irq_many.patch
Patch7100: linux-2.4.21-process_acct.patch
Patch7110: linux-2.4.21-rawio-readv-writev.patch
Patch7120: linux-2.4.21-sync-supers.patch
Patch7130: linux-2.4.21-dcache-priority.patch
Patch7140: linux-2.4.21-softirq-defer.patch
Patch7150: linux-2.4.21-s390-on-demand-timer.patch
Patch7151: linux-2.4.21-s390-time-accounting.patch
Patch7160: linux-2.4.21-sys-epoll-support.patch
Patch7170: linux-2.4.21-printk-rate-limit.patch
Patch7180: linux-2.4.21-sysctl-unregister.patch

#
# Patches 8000 to 9000 are reserved for new drivers
#
Patch8000: linux-2.4.9-addon.patch
Patch8010: linux-2.4.18-megarac.patch
Patch8020: linux-2.4.18-wvlan-cs.patch
Patch8030: linux-2.4.18-ecc.patch
Patch8040: linux-2.4.6-bcm5820.patch
Patch8050: linux-2.4.7-tulip.patch
Patch8060: linux-2.4.0-cipe-1.4.5.patch
Patch8061: linux-2.4.21-cipe-ipsec.patch
Patch8070: linux-2.4.20-lm_sensors.patch
Patch8080: linux-2.4.9-qla2200.patch
Patch8081: linux-2.4.21-qla2200-diskdump.patch
Patch8090: linux-2.4.9-aep.patch
Patch8100: linux-2.4.18-loop-cryptoapi.patch
Patch8110: linux-2.4.18-audigy.patch
Patch8120: linux-2.4.21-bonding-core.patch
Patch8121: linux-2.4.21-bonding.patch
Patch8140: linux-2.4.21-sata.patch
Patch8143: linux-2.4.21-sata-carmel.patch
Patch8144: linux-2.4.21-sata-diskdump.patch
Patch8145: linux-2.4.21-ich6-pata.patch
Patch8150: linux-2.4.21-fusion.patch
Patch8151: linux-2.4.21-fusion-varyio.patch
Patch8152: linux-2.4.21-fusion-diskdump.patch
Patch8155: linux-2.4.21-emulex.patch
Patch8156: linux-2.4.21-emulex-ioctl.patch
Patch8158: linux-2.4.21-iscsi_sfnet.patch
Patch8160: linux-2.4.21-icom.patch
Patch8161: linux-2.4.21-icom-serial-debugger.patch
Patch8170: linux-2.4.21-hangcheck-timer.patch
Patch8180: linux-2.4.21-agp3gart.patch
Patch8181: linux-2.4.21-drm-updates.patch
Patch8190: linux-2.4.20-s390-qdio.patch
Patch8200: linux-2.4.20-s390-qeth.patch
Patch8210: linux-2.4.21-s390-zcrypt.patch
Patch8220: linux-2.4.21-s390-zfcp.patch
Patch8230: linux-2.4.21-b44.patch
Patch8235: linux-2.4.21-forcedeth.patch
Patch8236: linux-2.4.21-bnx2.patch
Patch8240: linux-2.4.21-ppc64-ipr.patch
Patch8245: linux-2.4.21-3ware-9xxx.patch
Patch8246: linux-2.4.21-megaraid_sas.patch
Patch8247: linux-2.4.21-megaraid_sas-diskdump.patch
Patch8248: linux-2.4.21-adp94xx.patch
Patch8250: linux-2.4.21-dell_rbu.patch
Patch8251: linux-2.4.21-dell_dcdbas.patch
Patch8260: linux-2.4.21-syscall-auditing.patch
Patch8270: linux-2.4.21-ptrace-single-step.patch


#
# 9000 to 10000 is for stuff that has to come last due to the
# amount of drivers they touch.  But only these should go here. 
#

# file offset handling fixes
Patch9000: linux-2.4.21-file-offset-fixes.patch

# tty line discipline references
Patch9010: linux-2.4.21-tty-ldisc-refs.patch

# fix a lot of warnings in the plain kernel and previous patches
Patch9020: linux-2.4.1-compilefailure.patch

# several small tweaks not worth their own patch
Patch9030: linux-2.4.18-smallpatches.patch

# add missing MODULE_LICENSE() tags
Patch9040: linux-2.4.18-missing-license-tags.patch

# snip out some luxury code when CONFIG_SMALL is on, for -BOOT kernel
Patch9050: linux-2.4.21-config-small.patch

# empty final patch file to facilitate testing of kernel patches
Patch10000: linux-kernel-test.patch

# END OF PATCH DEFINITIONS

BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root

%package source
Summary: The source code for the Linux kernel.
Group: Development/System
Prereq: fileutils
Requires: gawk, make
Requires: gcc >= 2.96-98

%package doc
Summary: Various documentation bits found in the kernel source.
Group: Documentation

%description 
The kernel package contains the Linux kernel (vmlinuz), the core of your
Red Hat Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

%description source
The kernel-source package contains the source code files for the Linux
kernel. These source files are needed to build custom/third party device
drivers. The source files can also be used to build a custom kernel that is
better tuned to your particular hardware. Make sure you understand the
support implications of building your own custom kernel.

%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files. 

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.

%package unsupported
Summary: An extra, unsupported, set of kernel modules
Group: System Environment/Kernel
Provides: kernel-modules

%description unsupported
This package contains extra modules for those drivers which are present in
the kernel org kernel, but have not been tested by Red Hat. These drivers
are provided as a courtesy and are not officially supported by Red Hat.

%package smp-unsupported
Summary: An extra, unsupported, set of kernel modules
Group: System Environment/Kernel
Provides: kernel-modules

%description smp-unsupported
This package contains extra modules for those drivers which are present in
the kernel org kernel, but have not been tested by Red Hat. These drivers
are provided as a courtesy and are not officially supported by Red Hat.

%package hugemem-unsupported
Summary: An extra, unsupported, set of kernel modules
Group: System Environment/Kernel
Provides: kernel-modules

%description hugemem-unsupported
This package contains extra modules for those drivers which are present in
the kernel org kernel, but have not been tested by Red Hat. These drivers
are provided as a courtesy and are not officially supported by Red Hat.

%package smp
Summary: The Linux kernel compiled for SMP machines.
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.1.0, kernel-drm = 4.2.0, kernel-drm = 4.3.0
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
Obsoletes: kernel-enterprise < 2.4.10

%description smp
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs.

Install the kernel-smp package if your machine uses two or more CPUs.

%package hugemem
Summary: The Linux Kernel for machines with more than 16 Gigabytes of memory.
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.1.0, kernel-drm = 4.2.0, kernel-drm = 4.3.0
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}


%description hugemem
This package includes a kernel that has appropriate configuration options
enabled for Pentium III machines with 16 Gigabytes or more of physical memory.

%package BOOT
Summary: The version of the Linux kernel used on installation boot disks.
Group: System Environment/Kernel
Provides: kernel = %{version}
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}

%description BOOT
This package includes a trimmed down version of the Linux kernel.
This kernel is used on the installation boot disks only and should not
be used for an installed system, as many features in this kernel are
turned off because of the size constraints of floppy disks.

%prep

%setup -q -n %{name}-%{version} -c
cd linux-%{version}

#
# Patches 0 through 100 are meant for core subsystem upgrades
# 

# update to recent upstream
%patch2 -p1
%patch3 -p1
%patch4 -p1

# O(1) update + NPTL
%patch10 -p1 -E
# O(1) SMP fairness improvement
%patch20 -p1
# generic 32 bit compatibility for 64 bit architectures
%patch30 -p1
# HT scheduler
%patch40 -p1

# 
# Patches 100 through 400 are architecture specific patches
# Each architecture has 20 slots reserved.
#

# x86
# additional syscalls for this tree
%patch100 -p1
# oprofile x86 bits
%patch110 -p1
# larger acpi table size
%patch115 -p1
# clustered APIC support
%patch120 -p1
# no-execute (NX) support
%patch123 -p1
# microcode loader update
%patch125 -p1
# AMD Golem IO-APIC fixup for i686 kernel on AMD64
%patch130 -p1

# X86-64
# Base updates for arch
%patch180 -p1
# Patches specific to o1/nptl support
%patch181 -p1
# oprofile amd64 bits
%patch190 -p1
# 32 bit emulation
%patch200 -p1
# coredump fix
%patch201 -p1
# Backport of ACPI support from 2.5
%patch202 -p1 -E
# correct siginfo_t size for 32 bit emulation
%patch203 -p1
# amd64 NUMA support
%patch204 -p1
# Intel ia32e support
%patch210 -p1
# clustered APIC support
%patch211 -p1
# tweaks to FPU handling
%patch212 -p1

# IA64
# syscalls
%patch260 -p1
# ia64 core architecture updates
%patch262 -p1
# ia64 signal handling stuff
%patch264 -p1
# ia64 irq stuff
%patch266 -p1
# ia64 o1-nptl support
%patch268 -p1
# 32 bit emulation
%patch270 -p1
# oprofile for ia64
%patch272 -p1
# perfmon updates
%patch273 -p1
# mca dump for ia64
%patch274 -p1
# sal info for ia64
%patch275 -p1
# software io mmu for chipsets without hardware iommu
%patch276 -p1
# cyclone timer support
%patch278 -p1
# multi-core/hyper-threading support for Montecito
%patch279 -p1


# s390 s390x
# The kmap_types.h - needed for aio
%patch420 -p1
# O(1) & NPTL, they share some code.
%patch422 -p1
# aio
%patch432 -p1
# 31(32) bit mode updates
%patch437 -p1
# "31 bit init cannot mmap anything" - instead of arch_get_unmapped_area.
%patch439 -p1
# Increase the maximum number of boot arguments for s390.
%patch440 -p1
# lcs
%patch441 -p1
# oprofile.
%patch442 -p1
# kill illegal calls to dst_link_failure from interrupt context.
%patch443 -p1
# implement carrier reporting in ctc, see what happens.
%patch444 -p1
# This is handy: it allows to build rpms outside of buildroots.
# Even in Beehive, it reduces warnings.
%patch459 -p1
# Miscellanea: build fixes.
%patch460 -p1
# cio updates
%patch461 -p1
# ctc locking fixes
%patch462 -p1
# iucv driver fixes
%patch463 -p1

#
# PPC64
#
%patch340 -p1
%patch341 -p1
%patch342 -p1
%patch343 -p1
%patch344 -p1
%patch345 -p1
%patch346 -p1
%patch347 -p1
%patch348 -p1
%patch349 -p1
%patch350 -p1
%patch351 -p1
# explicit typing for ppc64 bitops
%patch352 -p1
# 32 bit emulation
%patch353 -p1
# strip debugging symbols from kernel
%patch354 -p1
# oprofile for ppc64
%patch355 -p1
# make wchan show something useful on ppc64
%patch356 -p1
# some DVD-ROM drives in ppc64 machines need a longer timeout
%patch357 -p1
# ethtool ioctl support for 32-bit compat mode
%patch358 -p1
# xmon enabling at boot-time
%patch359 -p1
# ppc64 revised ras support
%patch360 -p1
# pci multifunction support
%patch361 -p1
# Power Blade (JS20) support
%patch362 -p1
# /proc/ppc64/lparcfg support
%patch363 -p1
# round-robin segment table entry replacement
%patch364 -p1
# ppc64 signal catching fixes
%patch365 -p1
# Squadrons/Power5 support
%patch370 -p1
%patch371 -p1
%patch372 -p1
%patch373 -p1
%patch374 -p1

#
# Patches 600 through 1000 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#


# This patch adds a "make oldconfig_nonint" which is non-interactive and
# also gives a list of missing options at the end. Useful for automated
# builds (as used in the Red Hat buildsystem).
%patch600 -p1

#
# flock() accounting is broken; disable for 2.4 kernels
#
%patch610 -p1

# tty_write_message needs \r\n -- makes quota messages look nicer
%patch620 -p1
#
# Make "make oldconfig" smarter and have it use the config file for the
# currently running kernel as default.
#
%patch630 -p1
# Al Viro's loopback patch 
%patch640 -p1
%patch650 -p1

# fix lun probing on multilun RAID chassis
%patch660 -p1

#
# kksymoops - automatically decode oopses/backtraces from within the kernel
%patch670 -p1
%patch680 -p1

#
#
# update the list of vendors who can't program a bios
#
%patch690 -p1

#
# use SPEC_CFLAGS to pass in extra CFLAGS options from the spec file
#
%patch700 -p1

#
# add some laptop power consumption improvements
#
%patch710 -p1

# ELF loader fix for PPC64
%patch720 -p1

# bugfix for 64 bit PCI buses on 64 bit systems
%patch730 -p1

# AIO subsystem
%patch750 -p1

# varyio
%patch770 -p1

# superbh
%patch780 -p1
# superbh for AIO
%patch781 -p1

# oprofile
%patch790 -p1 

# semtimedop 32bit compat stuff and arch support
%patch800 -p1

# large pci bus numbers, only for pSeries
%patch810 -p1

# larger log buffer size and boot option
%patch820 -p1

# akpm's IO elevator fix
%patch830 -p1

# tux
%patch840 -p1 -E

# odirect updates
%patch850 -p1

# IPC semaphore scalability patch
%patch860 -p1

# sysrq+C shows the stack dump of all CPUs
%patch870 -p1
# sticky key (with timeout)
%patch871 -p1

# split up the IO request lock into per-queue locks
%patch880 -p1

# 32 bit compatibility for statfs, sysinfo,
%patch890 -p1

# report the right executable file in /proc for interpreted scripts
%patch900 -p1

# strncpy() fixes to zero-pad unused portion of destination buffer
%patch910 -p1

# updates to rw-semaphore handling
%patch920 -p1

# work-around for siginfo mismatch on x86_64/ppc64/s390x
%patch930 -p1


# rmap 15f
%patch1000 -p1

# rmap updates
%patch1020 -p1
%patch1025 -p1

# iowait statistics
%patch1030 -p1

# virtual mem_map for ia64
%patch1040 -p1

# allow users to have locked down pages
%patch1050 -p1

# 4G/4G split
%patch1060 -p1

# fix IO wait stalls
%patch1070 -p1

# DMA zone isolation
%patch1080 -p1

# VMA merging
%patch1090 -p1

# exec-shield
%patch1100 -p1

# pagecache scalability using brlocks
%patch1110 -p1

# flexible mmap, removes the need for TASK_MAPPED_BASE
%patch1120 -p1

# remap_file_pages
%patch1130 -p1

# statm
%patch1140 -p1

# pte_clear() races
%patch1141 -p1

# hugetlbfs (x86 and amd64, dummy functions for ppc64 and s390)
%patch1150 -p1
# hugetlbfs for ia64
%patch1151 -p1

# tunable VM overcommit
%patch1160 -p1

# 4G/4G: lockless fastpath access in copy_to/from_user
%patch1170 -p1

# miscellaneous fixes to mmap/mremap handling
%patch1180 -p1

# crosshost mmap consistency for distributed filesystems
%patch1190 -p1

# 3G personality for 32 bit programs, to work around bugs in programs
%patch1200 -p1

# correct page dirty bit handling on s390
%patch1210 -p1

# reduction of buf head memory footprint for read-only pages
%patch1220 -p1

# redesign of refill_inactive_zone() for smarter deactivation
%patch1223 -p1

# allocation of pte and ramfs pages from highmem via __GFP_WIRED
%patch1224 -p1

# delayed laundering for better page deactivation scalability
%patch1225 -p1

# wired page lists for more efficient handling of ramfs pages
%patch1226 -p1

# balanced page allocation to reduce unnecessary swapping
%patch1227 -p1

# enhanced altsysrq-M with slab, kern-stack, page-table pages
%patch1228 -p1

# improvements to OOM killing logic
%patch1229 -p1

# deferred LRU page free handling for interrupt level calls
%patch1230 -p1

# ppc64 pte hash table locking rework
%patch1240 -p1

# bootmem hash table allocator
%patch1250 -p1

# EIO avoidance with O_DIRECT+buffered i/o
%patch1251 -p1

# page pin counts for rawio/O_DIRECT usage
%patch1252 -p1

# vma overlap checking with insert_vm_struct()
%patch1260 -p1

# ptrace() page permissions
%patch1270 -p1

# change_page_attr() fixes
%patch1280 -p1


#
# Patches 2000 to 5000 are reserved for network protocol updates
#
# ipsec
%patch2000 -p1 -E
%patch2010 -p1
# igmpv3
%patch2020 -p1
# ipvs
%patch2030 -p1
# Increase MAX_ADDR_LEN from 8 to 32 for Infiniband over IP
%patch2040 -p1
# AIO on sockets
%patch2050 -p1
# fix network permission checks to nptl
%patch2060 -p1
# networking fixes from 2.4.22
%patch2070 -p1
# ethtool_ops
%patch2080 -p1
# CMSG validation checks
%patch2090 -p1
# ipfrag_flush/netfilter
%patch2100 -p1
# arp_announce sysctl
%patch2110 -p1

#
# Patches 5000 to 7000 are reserved for bugfixes to drivers and filesystems
#

#
# Add a "nousb" kernel option to disable all USB loading. On some older
# machines and ACPI-only boxes trying to use ANY usb crashes the machine.
#
%patch5000 -p1

# add vidfail capability; 
# without this patch specifying a framebuffer on the kernel prompt would
# make the boot stop if there's no supported framebuffer device; this is bad
# for the installer floppy that wants to automatically fall back to textmode
# in that case
%patch5010 -p1

#
# add e820 reporting in /proc; needed for anaconda to find out which
# kernels to install
#
%patch5020 -p1

# conservative zone bitmaps to prevent potential memory corruption
%patch5030 -p1
#
# Silence the APIC errors a bit; they are harmless mostly and can happen
# in normal use.
#
%patch5040 -p1

#
# NFS patch fron trond:
# A patch that papers over an IRIX bug. In glibc-2.2 and above, they use
# the new getdents64() syscall even for the 32-bit readdir. As a result, they
# have problems coping with the unsigned 64-bit d_off values that may get
# invalidly returned by some NFSv3 servers, since the values are specified
# to be signed.
# NOTE: You might still have to set the '32bitclients' export option on
# some IRIX servers.

%patch5050 -p1

#
# change IRQ penalty for IRQ 12
# This tries to avoid assigning cardbus irq's to irq12 which is "special"
# for certain laptops that emulate PS/2 hardware via SMM mode.
#
%patch5060 -p1

#
# Silence the PS/2 code for USB keyboards
# It's not uncommon to have no PS/2 keyboard these days
#
%patch5070 -p1

#
# make the scsi timeout longer; 30 seconds is too short for big raid arrays
# with lots of large concurrent requests in flight
#
%patch5080 -p1

#
# make freevxfs autoload when doing mount -t vxfs /dev/foo /mnt/bar
#
%patch5090 -p1


#
# use the nmi interrupt for profiling; this allows the kernel profiler
# to profile even with interrupts disabled. Note: you have to specify the
# nmi watchdog now as well for profiling to work:
# vmlinuz profile=1 nmi_watchdog=1
#
%patch5100 -p1

#
# allow more unnamed mounts by borrowing old, unused major devices
# This is needed if you want more than 255 NFS mounts; some people use the
# "one mount per user" automount setup and they need this if they have more
# than 255 users.
#
%patch5110 -p1



#
# LVM updates:
#
# add important bugfixes from Sistina's LVM-1.0.3
%patch5120 -p1
# Add bulk-copy-via-kiobufs code
%patch5121 -p1
# Add locked copy-and-remap pvmove code
%patch5122 -p1
# LVM atomic snapshot patch: quiesce the filesystem automatically when
# taking snapshots.
%patch5123 -p1
# Allow 32 bit userland on AMD64 and PPC64 to use volumes > 2GB
%patch5124 -p1
# O_DIRECT support
%patch5125 -p1


#
# Gamepad (all kbds and mice were affected, but we kludged arount it in hplug)
# autoload the proper modules
%patch5130 -p1

# updates to /dev/random driver
%patch5135 -p1

# rescan the SCSI bus for new devices when userland asks us to
%patch5140 -p1

# locking fix and format cleanups for /proc/scsi/scsi dump command
%patch5150 -p1

#
# allow ioctls to lun0 even if there's no lun0 (needed for some FC kit)
#
%patch5160 -p1

#
# Netdump / Netconsole - crashdumps and kernel messages over
# the network via a lightweight UDP stack that can run with interrupts
# disabled
#
%patch5170 -p1

#
# diskdump support
#
%patch5175 -p1
%patch5176 -p1
%patch5177 -p1
%patch5178 -p1
%patch5179 -p1

#
# add cenatek PCI ID's to the ide layer
#
%patch5180 -p1

# 
# Some bioses "forget" to restore pci config space properly on resume;
# the following patch helps them a bit with this
#
%patch5220 -p1

#
# Older orinoco_cs driver that fixes some laptops
#
%patch5230 -p1

#
# Make use of all of the 256 scsi devices available
#
%patch5250 -p1



# SDDR-31 media check
%patch5260 -p1
# ALi in IBM i1200
# Installation BUGs when unmounting usbdevfs (workaround)
%patch5270 -p1
# Yukihiro's pet, will disappear eventually
%patch5280 -p1
# User insists we added usbstor2 (spin_unlock_irq(&io_request_lock))
%patch5288 -p1
# miscellaneous USB fixes
%patch5290 -p1
# miscellaneous sound driver fixes
%patch5300 -p1
# miscellaneous isofs fixes
%patch5390 -p1
# miscellaneous smbfs fixes
%patch5395 -p1
# miscellaneous cramfs fixes
%patch5396 -p1

# raise symlink recursion level to 8
%patch5400 -p1

# ACPI updates, for IA64 and AMD64
%patch5410 -p1 -E
# acpi for ia64
%patch5411 -p1
# acpi compile fixes for ipmi
%patch5412 -p1
# acpi serial port support
%patch5413 -p1

# matrox framebuffer for pSeries
%patch5420 -p1

# sym53c8xx driver fix for ppc64 Zapata DVD-ROM drives
%patch5430 -p1
%patch5431 -p1

# cmpci driver update
%patch5440 -p1

# raid autorun
%patch5450 -p1

# nfs + O_DIRECT fixes
%patch5460 -p1

#
# NFS over TCP patches

# check that the socket is still connected
%patch5470 -p1
# flow control improvements
%patch5480 -p1

# miscellaneous file system handling updates
%patch5500 -p1
%patch5510 -p1

#
# XATTR/ACL patches

# xattr core
%patch5520 -p1
# xattr/ext3
%patch5530 -p1
# xattr syscalls
%patch5540 -p1
# acl core
%patch5550 -p1
# acl/ext3
%patch5560 -p1
# acl/nfs
%patch5570 -p1
# VM changes for acl/xattr
%patch5580 -p1

# NFS lockd v4 granted responses and right blocking semantics
%patch5590 -p1

# place blocking locks that won't expire last on nlm_block list
%patch5600 -p1

# have nfsd honour ACLs on a per-export basis
%patch5610 -p1

# fix nfs over tcp disconnect race condition
%patch5620 -p1

# rework how the nfs client deals with reconnecting to the server
%patch5630 -p1

# ignore acl errors in knfsd, in some corner cases
%patch5640 -p1

# make sure lockd uses reserved ports
%patch5650 -p1

# NFS ACL over the wire protocol extensions
%patch5660 -p1

# fix a race with the scsi timer code
%patch5670 -p1

# ips driver updates
%patch5675 -p1

# CCISS driver update
%patch5680 -p1
%patch5681 -p1

# st driver update
%patch5685 -p1

# megaraid driver updates
%patch5690 -p1
%patch5691 -p1
%patch5692 -p1

# fix nfs tcp client corruption bug
%patch5700 -p1

# replace xdr_shift_buf() with 2.5 version, fix potential kmap deadlock
%patch5710 -p1

# ensure that 'unlink' XDR structures are correctly aligned on 64 bit systems
%patch5720 -p1

# update the aic7xxx/aic79xx drivers
%patch5730 -p1 -E
%patch5731 -p1
%patch5732 -p1
%patch5733 -p1

# dpt_i2o driver updates
%patch5735 -p1
%patch5736 -p1

# cpqarray driver updates
%patch5740 -p1

# aacraid driver updates
%patch5745 -p1

# siimage driver updates
%patch5748 -p1

# autofs4 upgrade
%patch5750 -p1

# 3ware driver updates
%patch5760 -p1

# emu10k1 driver fixes
%patch5770 -p1

# ACL support for JFS
%patch5780 -p1

# NFS HA failover support
%patch5790 -p1

# SCSI device list updates
%patch5800 -p1

# LVM does up() from irq context, so make their rwsems irq safe
%patch5810 -p1

# fix ACL/NFSD/ext3/jbd deadlock
%patch5820 -p1
%patch5821 -p1
%patch5822 -p1

# nfsd: only set ->reuse for tcp sockets, not udp
%patch5830 -p1

# nfsd: acl related mount and export flags
%patch5840 -p1

# fix nfs exp_fodrop oops
%patch5850 -p1

# unmap all pages when xdr_kmap() fails
%patch5860 -p1

# cdrom 32 bit compatibility ioctl fixes
%patch5870 -p1

# NFS softirq race fix
%patch5880 -p1

# kNFSd -  Convert error code to nfserror code in nfsd_symlink
%patch5890 -p1

# kNFSd - BKL is missing in once place in knfsd
%patch5900 -p1

# kNFSd/lockd - Blocked lockd not being purged correctly
%patch5910 -p1

# i810 sound driver updates
%patch5920 -p1

# net driver fixes and updates
%patch5930 -p1
%patch5931 -p1 -E
%patch5932 -p1
%patch5933 -p1
%patch5934 -p1
%patch5935 -p1
%patch5936 -p1
%patch5937 -p1
%patch5938 -p1

# bladecenter usb ohci fixes
%patch5940 -p1

# make lockd port configurable with sysctl
%patch5950 -p1

# fix bug in rpc retry code
%patch5960 -p1

# tg3 updates
%patch5970 -p1

# pci_ids.h updates
%patch5980 -p1

# md multipath enablers
%patch5990 -p1

# patch (merged upstream) that works around a VFS limitation and allows
# vxfs filesystems to be exported over NFS
%patch6000 -p1

# hack to read the last sector of a disk on IA64, where the partition
# table could be on the last sector
%patch6010 -p1

# add netdump support to various net drivers
%patch6020 -p1

# unshare file descriptors
%patch6030 -p1

# acl related nfs_get_root bugfix
%patch6040 -p1

# nfs permission bits efficiency patch
%patch6050 -p1

# NFS Solaris 8 acl fix
%patch6060 -p1

# NFS performance enhancements and miscellaneous fixes
%patch6065 -p1
%patch6070 -p1
%patch6080 -p1
%patch6090 -p1
%patch6091 -p1
%patch6092 -p1

# /proc/tty/driver directory permission restriction
%patch6100 -p1

# ncpfs fixes/updates
%patch6110 -p1

# fatfs fixes/updates
%patch6120 -p1

# GFS enablers
%patch6200 -p1

# statfs64
%patch6210 -p1

# O_SYNC EIO error propagation
%patch6220 -p1

#
# Patches 7000 to 8000 are reserved for scalability fixes
# that touch various subsystems
#

# gendisk statistics scalability
%patch7000 -p1

# support for 2-TB partitions
%patch7001 -p1

# make kstat array a per-cpu thing
%patch7010 -p1

# scalable gettimeofday
%patch7020 -p1

# cpu affinity for scsi command processing
# (most of patch has been disabled for performance reasons, but KMI preserved)
%patch7030 -p1

# use softirqs instead of bhs for the scsi layer
%patch7040 -p1

# scsi dynamic add (hot plug) support
%patch7045 -p1

# scsi request lock scalability
%patch7050 -p1

# scsi mid-layer queuing improvements
%patch7055 -p1

# SMP scalable timers
%patch7060 -p1 -E

# filtered wakeup support
%patch7065 -p1

# slab cache scalability improvements
%patch7070 -p1

# kiobuf fixes and optimisations
%patch7080 -p1
# aio w/ odirect on block devices
%patch7081 -p1

# use seq_file for /proc/interrupts to avoid overflowing the buffer (ppc64)
%patch7090 -p1

# finegrained process accounting
%patch7100 -p1

# readv/writev for raw IO
%patch7110 -p1

# make sure sync(2) terminates in a reasonable time
%patch7120 -p1

# change dentry cache reclaim priority for tux
%patch7130 -p1

# defer softirq processing if stack is too deep
%patch7140 -p1

# s390 on-demand timer and time accounting patches
%patch7150 -p1
%patch7151 -p1

# sys_epoll support (only implemented for s390/s390x)
%patch7160 -p1

# printk_ratelimit support
%patch7170 -p1

# sysctl table unregister race fixes
%patch7180 -p1


#
# Patches 8000 to 9000 are reserved for new drivers
#
# generic drivers/addon infrastructure
%patch8000 -p1
# (ugly) driver for the Dell megarac remote access cards
%patch8010 -p1
# old wvlan_cs driver
%patch8020 -p1
# ECC reporting module
%patch8030 -p1
# Broadcom 5820 driver
%patch8040 -p1
# add tulip_old driver (2.4.3 version)
%patch8050 -p1
# cipe 1.4.5
%patch8060 -p1
%patch8061 -p1
# LM-Sensors 2.6.5
%patch8070 -p1
# qla2x00
%patch8080 -p1
%patch8081 -p1
# AEP SSL Accelerator card
%patch8090 -p1

#
# Patches to support AES loop device
#
%patch8100 -p1

#
# Soundblaster Live! Audigy driver
#
%patch8110 -p1

# core changes for network channel bonding
%patch8120 -p1
# network channel bonding update
%patch8121 -p1 -E

# Serial ATA
%patch8140 -p1
# SATA Carmel (sx8) driver
%patch8143 -p1
# SATA diskdump support
%patch8144 -p1
# ICH6 PATA support
%patch8145 -p1

# mpt fusion 2.06.16i.01
%patch8150 -p1
%patch8151 -p1
%patch8152 -p1

# Emulex Fibre Channel (lpfc) driver
%patch8155 -p1
%patch8156 -p1

# Cisco iSCSI initiator driver
%patch8158 -p1

# IBM icom modem driver
%patch8160 -p1
# and some code to use a serial debugger over the icom card
%patch8161 -p1

# Oracle hangcheck timer
%patch8170 -p1

# recent (agp 3.0) Intel agpgart support and drm updates
%patch8180 -p1
%patch8181 -p1

# qdio (s390)
%patch8190 -p1

# qeth (s390)
%patch8200 -p1

# zcrypt (s390) - z90 crypt support
%patch8210 -p1

# zfcp (s390) - zSeries fibre channel driver
%patch8220 -p1

# b44, forcedeth, bnx2 network drivers
%patch8230 -p1
%patch8235 -p1
%patch8236 -p1

# ipr (ppc64) - IBM's PPC RAID adapters
%patch8240 -p1

# 3ware 3w-9xxx driver
%patch8245 -p1

# LSI megaraid_sas driver
%patch8246 -p1
%patch8247 -p1

# Adaptec's adp94xx driver for Razor chipset (9410 SAS adapter)
%patch8248 -p1

# Dell's dell_rbu and dcdbas drivers
%patch8250 -p1
%patch8251 -p1

# LAuS syscall auditing support
%patch8260 -p1

# ptrace PT_SINGLESTEP support
%patch8270 -p1


#
# final stuff
#

# file offset handling fixes
%patch9000 -p1

# tty line discipline references
%patch9010 -p1

# lots of small fixes to warnings and other silly bugs
%patch9020 -p1

# several small tweaks
%patch9030 -p1

# missing MODULE_LICENSE() tags
%patch9040 -p1

# CONFIG_SMALL support for -BOOT kernel
%patch9050 -p1

# correction of SUBLEVEL/EXTRAVERSION in top-level source tree Makefile
perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -prep/" Makefile
perl -p -i -e "s/^RHEL_VERSION.*/RHEL_VERSION = %{rh_release_major}/" Makefile
perl -p -i -e "s/^RHEL_UPDATE.*/RHEL_UPDATE = %{rh_release_minor}/" Makefile

# conditionally applied test patch for debugging convenience
%if %([ -s %{PATCH10000} ] && echo 1 || echo 0)
%patch10000 -p1
%endif


# END OF PATCH APPLICATIONS

cp %{SOURCE10} Documentation/

mkdir configs

cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-i?86*.config configs
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-athlon*.config configs
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-x86_64*.config configs
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-s390*.config configs
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-ppc64?series.config configs
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-ia64*.config configs
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-ia32e*.config configs
# not used for compilation, but needed for kernel-source rpm 
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-ppc64.config configs

# get rid of unwanted files
find . -name "*.orig" -exec rm -fv {} \;
find . -name "*~" -exec rm -fv {} \;

###
### build
###
%build

cd linux-%{version}

DependKernel() {
    # is this a special kernel we want to build?
    if [ -n "$2" ] ; then
	Config=$1-$2
	KernelVer=%{version}-%{release}$2
	echo MAKE DEPEND FOR $2 $1 KERNEL...
    else
	Config=$1
	KernelVer=%{version}-%{release}
	echo MAKE DEPEND FOR up $1 KERNEL...
    fi
    make -s mrproper
# We used to copy the config file to arch/.../defconfig, but for some time now
# the Configure script has been smart enough to override this with the
# config file found in configs/kernel-%{kversion}-${config}.config when it
# finds a valid /boot/kernel.h file.  As a result, making an RPM on a
# machine that has a valid kernel.h file will result in scripts/Configure
# overriding our config entries with whatever it thinks is appropriate
# (aka, if you try an i386 build on a machine with an i686 smp kernel.h file
# then you will get an i686 smp kernel in an i386 package).  So, instead we
# put our config file in .config, which is considered the ultimate source
# of default config information by make oldconfig.  Also, copy the config
# files out of the configs directory instead of the RPM_SOURCE_DIR.  It
# doesn't make any sense to put them in there and then not use them,
# especially when we could have a patch that modifies the config files
# as part of the hugemem patch set (or any other patch, it just makes
# us more flexible to use the configs from the configs directory).  Finally,
# since make mrproper wants to wipe out .config files, we move our mrproper
# up before we copy the config files around.
    cp configs/kernel-%{kversion}-$Config.config .config
    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}$2/" Makefile

    # We do make oldconfig twice; otherwise, make oldconfig tends to get stuff
    # wrong in the light of cyclic dependencies

    make -s oldconfig_nonint
    make -s oldconfig_nonint
    make -s scripts/mkdep
    make -s %{?_smp_mflags} dep
    make -s include/linux/version.h 
}

BuildKernel() {
    if [ -n "$1" ] ; then
	Config=%{_target_cpu}-$1
	KernelVer=%{version}-%{release}$1
	DependKernel %{_target_cpu} $1
	echo BUILDING A KERNEL FOR $1 %{_target_cpu}...
    else
	Config=%{_target_cpu}
	KernelVer=%{version}-%{release}
	DependKernel %{_target_cpu}
	echo BUILDING THE NORMAL KERNEL for %{_target_cpu}...
    fi

    make -s %{?_smp_mflags} SPEC_CFLAGS="-g" %{buildtarget}
    make -s %{?_smp_mflags} modules || exit 1

    # first make sure we are not losing any .ver files to make mrproper's
    # removal of zero sized files.
    find include/linux/modules -size 0 | while read file ; do \
	echo > $file
    done
    # Start installing stuff
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    install -m 644 configs/kernel-%{kversion}-$Config.config $RPM_BUILD_ROOT/boot/config-$KernelVer
    cp arch/*/boot/*mage $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-$KernelVer || :
    cp arch/*/boot/*mage.partial $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-partial-$KernelVer || :
    # make sure that we don't strip the partially linked vmlinuz for pSeries
    chmod 644 $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-partial-$KernelVer || :
    cp vmlinux $RPM_BUILD_ROOT/boot/vmlinux-$KernelVer


    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    make -s INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer

#   move the modules in the SOURCE14 file to the unsupported/ directory
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/unsupported
    pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/kernel ; {
	 tar cf - `cat %{SOURCE14}`  | tar xf - -C ../unsupported
	 rm -rf `cat %{SOURCE14}` 
	 if [ "$1." == "hugemem." ] ; then
		 tar cf - `cat %{SOURCE15}`  | tar xf - -C ../unsupported
		 rm -rf `cat %{SOURCE15}` 
	 fi 
    } ; popd


#   mark the modules executable
    if [ "$1" != "BOOT" ] ; then
     	find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.o" -type f  | xargs chmod u+x
    fi

#   now separate out the debug info from the modules/vmlinux
   /usr/lib/rpm/find-debuginfo.sh %{_builddir}/%{?buildsubdir} || :

#   and compress the modules for space saving
#    if [ "$1" != "BOOT" ] ; then
#    	find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.o" -type f  | xargs gzip -9
#    fi

#   remove files that will be auto generated by depmod at rpm -i time
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.*
#   remove legacy pcmcia symlink that's no longer useful
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/pcmcia


}

SaveHeaders() {
    echo "SAVING HEADERS for $1 $2"
    # deal with the kernel headers that are version specific
    mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1
    install -m 644 include/linux/autoconf.h \
	$RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1/autoconf.h
    install -m 644 include/linux/version.h \
	$RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1/version.h
    mv include/linux/modules \
	$RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1/
    echo $2 $1 ../../savedheaders/$2/$1/ >> $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/list
}

###
# DO it...
###

rm -rf $RPM_BUILD_ROOT

%if %{buildhugemem}
BuildKernel hugemem
SaveHeaders hugemem %{_target_cpu}
%endif

%if %{buildsmp}
BuildKernel smp
SaveHeaders smp %{_target_cpu}
%endif

%if %{buildBOOT}
BuildKernel BOOT
SaveHeaders BOOT %{_target_cpu}
%endif

# UNIPROCESSOR KERNEL
%if %{buildup}
BuildKernel
SaveHeaders up %{_target_cpu}
%endif

%ifarch ppc64
DependKernel ppc64pseries
SaveHeaders ppc64pseries ppc64pseries
DependKernel ppc64iseries
SaveHeaders ppc64iseries ppc64iseries
# we have to run this since we never do an actual build
/usr/lib/rpm/find-debuginfo.sh %{_builddir}/%{?buildsubdir} || :
%endif

#
# i386 is a special case; the kernel source there is supposed
# to also have the modversions/headers/config of i586/i686/athlon
#
%ifarch i386
DependKernel i586
SaveHeaders up i586
DependKernel i686
SaveHeaders up i686
DependKernel athlon
SaveHeaders up athlon
DependKernel i586 smp
SaveHeaders smp i586
DependKernel i686 smp
SaveHeaders smp i686
DependKernel i686 hugemem
SaveHeaders hugemem i686
DependKernel athlon smp
SaveHeaders smp athlon
%endif
%ifarch x86_64
DependKernel ia32e
SaveHeaders ia32e ia32e
%endif



###
### install
###

%install

cd linux-%{version}
mkdir -p $RPM_BUILD_ROOT/{boot,sbin}

for i in `ls -d $RPM_BUILD_ROOT/lib/modules/*`; do
  rm -f $i/build 
  ln -sf ../../../usr/src/linux-%{KVERREL} $i/build
done

# architectures that don't build kernel-source (i586/i686/athlon) are done here
# and can skip the next steps; the source building will do the header magic instead.

%if %{buildsource}

mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
# generated binaries should be removed; we don't want kernel-source to depend on glibc
rm -f drivers/net/hamradio/soundmodem/gentbl scripts/mkdep
# copy the source over
tar cf - . | tar xf - -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
# set the EXTRAVERSION to <version>custom, so that people who follow a kernel
# building howto don't accidentally overwrite their currently working moduleset
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}custom/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/Makefile
install -m 644 %{SOURCE10}  $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

# clean up the destination
make -s mrproper -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
cp configs/kernel-%{kversion}-%{_target_cpu}.config $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/.config
make -s oldconfig_nonint -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
make -s symlinks -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
make -s include/linux/version.h -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

# this generates modversions info which we want to include and we may as
# well include the depends stuff as well, after we fix the paths
make -s depend -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
find $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL} -name ".*depend" | \
while read file ; do
    mv $file $file.old
    sed -e "s|[^ ]*\(/usr/src/linux\)|\1|g" < $file.old > $file
    rm -f $file.old
done

# Try to put some smarter autoconf.h and version.h files in place
pushd $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/include/linux ; {
rm -rf modules modversions.h autoconf.h version.h
cat > modversions.h <<EOF
#ifndef _LINUX_MODVERSIONS_H
#define _LINUX_MODVERSIONS_H
#include <linux/rhconfig.h>
#include <linux/modsetver.h>
EOF
echo '#include <linux/rhconfig.h>' > autoconf.h
list=`find ../../savedheaders/* -name '*.ver' -exec basename '{}' \; | sort`
mkdir modules
for l in $list; do
    sed 's,$,modules/'$l, ../../savedheaders/list | awk -f %{SOURCE13} > modules/$l
    touch -r modules/$l modules/`basename $l .ver`.stamp
    echo '#include <linux/modules/'$l'>' >> modversions.h
done
echo '#endif' >> modversions.h
sed 's,$,autoconf.h,' ../../savedheaders/list | awk -f %{SOURCE12} >> autoconf.h
install -m 644 %{SOURCE11} rhconfig.h
echo "#include <linux/rhconfig.h>" >> version.h
keyword=if
for i in smp BOOT hugemem up ppc64pseries ppc64iseries; do
# When we build in an i386, we don't have an hugemem header directory
# in savedheaders/i386/hugemem.  We also don't have a BOOT directory
# anywhere except in savedheaders/i386.  So, we need to use this method
# of determining if a kernel version string needs to be included in the
# version.h file
    verh=`echo ../../savedheaders/*/$i/version.h | awk ' { print $1 } '`
    if [ -n "$verh" -a -f "$verh" ]; then
	if [ "$i" = up ]; then
	    if [ "$keyword" = if ]; then
		echo "#if 0" >> version.h
	    fi
  	    echo "#else" >> version.h
	else
	    echo "#$keyword defined(__module__$i)" >> version.h
	    keyword=elif
	fi
	grep UTS_RELEASE $verh >> version.h
    fi
done
echo "#endif" >> version.h
if [ -f ../../savedheaders/%{_target_cpu}/up/version.h ] ; then
    # keep to a standard normally
    HEADER_FILE=../../savedheaders/%{_target_cpu}/up/version.h
else
    # test build not including uniprocessor, must get info from somewhere
    HEADER_FILE=$(ls ../../savedheaders/%{_target_cpu}*/*/version.h | head -n 1)
fi
grep -v UTS_RELEASE $HEADER_FILE >> version.h
rm -rf ../../savedheaders
} ; popd
touch $RPM_BUILD_ROOT/boot/kernel.h-%{kversion}

for i in $RPM_BUILD_ROOT/lib/modules/*; do
  rm -f $i/modules.*
done

%endif
rm -rf $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders

# fix up the tmp_include_depends file wrt the buildroot path
perl -p -i -e "s|$RPM_BUILD_ROOT||g" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/tmp_include_depends

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

# do this for upgrades...in case the old modules get removed we have
# loopback in the kernel so that mkinitrd will work.
%pre 
%ifarch x86_64
if grep -qs '^vendor_id.*GenuineIntel' /proc/cpuinfo ; then cat << EOF

   ###########################################################################
   ###  WARNING: RHEL3 kernels from x86_64 RPMs will not boot on machines  ###
   ###     with Intel processors.  Please install an ia32e RPM instead.    ###
   ###########################################################################

EOF
fi
%endif
/sbin/modprobe loop 2> /dev/null > /dev/null  || :

%pre smp
%ifarch x86_64
if grep -qs '^vendor_id.*GenuineIntel' /proc/cpuinfo ; then cat << EOF

   ###########################################################################
   ###  WARNING: RHEL3 kernels from x86_64 RPMs will not boot on machines  ###
   ###     with Intel processors.  Please install an ia32e RPM instead.    ###
   ###########################################################################

EOF
fi
%endif
/sbin/modprobe loop 2> /dev/null > /dev/null  || :

%pre hugemem
/sbin/modprobe loop 2> /dev/null > /dev/null  || :

%post 
cd /boot
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}
exit 0

%post smp
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}smp
exit 0

%post hugemem
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}hugemem
exit 0

%post BOOT
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}BOOT
exit 0

%post unsupported
[ -x /sbin/depmod -a -e /boot/System.map-%{KVERREL} ] && \
    /sbin/depmod -ae -F /boot/System.map-%{KVERREL} %{KVERREL}
exit 0

%post smp-unsupported
[ -x /sbin/depmod -a -e /boot/System.map-%{KVERREL}smp ] && \
    /sbin/depmod -ae -F /boot/System.map-%{KVERREL}smp %{KVERREL}smp
exit 0

%post hugemem-unsupported
[ -x /sbin/depmod -a -e /boot/System.map-%{KVERREL}hugemem ] && \
    /sbin/depmod -ae -F /boot/System.map-%{KVERREL}hugemem %{KVERREL}hugemem
exit 0

# Allow clean removal of modules directory
%preun 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}
exit 0

%preun smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}smp
exit 0

%preun hugemem
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}hugemem
exit 0

%preun BOOT
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}BOOT
exit 0

# We need this here because we don't prereq kudzu; it could be
# installed after the kernel during an OS upgrade
%triggerin -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin smp -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin hugemem -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin BOOT -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

# Old kernel-headers packages owned include symlinks; new
# ones just make them so that we can have multiple kernel-headers
# packages installed.

%triggerpostun source -- kernel-headers < 2.2.16
cd /usr/src
rm -f %{kslnk}
ln -snf linux-%{KVERREL} %{kslnk}
exit 0

%post source
cd /usr/src
rm -f %{kslnk}
ln -snf linux-%{KVERREL} %{kslnk}

%postun source
#
# fix up the /usr/src/linux-2.4 symlink to point to another kernel-source dir if possible
#
if [ -L /usr/src/%{kslnk} ]; then 
    if [ -L /usr/src/%{kslnk} -a `ls -ld /usr/src/%{kslnk} 2>/dev/null| awk '{ print $11 }'` = "linux-%{KVERREL}" ]; then
	[ $1 = 0 ] && rm -f /usr/src/%{kslnk}
    fi
fi
exit 0

###
### file lists
###

%if %{buildup}
%files 
%defattr(-,root,root)
/boot/vmlinux-%{KVERREL}
/%{image_install_path}/vmlinu*-%{KVERREL}
/boot/System.map-%{KVERREL}
/boot/config-%{KVERREL}
%dir /lib/modules
%dir /lib/modules/%{KVERREL}
/lib/modules/%{KVERREL}/kernel
/lib/modules/%{KVERREL}/build

%files unsupported
%defattr(-,root,root)
%dir /lib/modules/%{KVERREL}
/lib/modules/%{KVERREL}/unsupported

%endif

%if %{buildsmp}
%files smp
%defattr(-,root,root)
/boot/vmlinu?-%{KVERREL}smp
/boot/System.map-%{KVERREL}smp
/boot/config-%{KVERREL}smp
%dir /lib/modules
%dir /lib/modules/%{KVERREL}smp
/lib/modules/%{KVERREL}smp/kernel
/lib/modules/%{KVERREL}smp/build

%files smp-unsupported
%defattr(-,root,root)
%dir /lib/modules/%{KVERREL}smp
/lib/modules/%{KVERREL}smp/unsupported
%endif

%if %{buildhugemem}
%files hugemem
%defattr(-,root,root)
/boot/vmlinu?-%{KVERREL}hugemem
/boot/System.map-%{KVERREL}hugemem
/boot/config-%{KVERREL}hugemem
%dir /lib/modules
%dir /lib/modules/%{KVERREL}hugemem
/lib/modules/%{KVERREL}hugemem/kernel
/lib/modules/%{KVERREL}hugemem/build

%files hugemem-unsupported
%defattr(-,root,root)
%dir /lib/modules/%{KVERREL}hugemem
/lib/modules/%{KVERREL}hugemem/unsupported
%endif

%if %{buildBOOT}
%files BOOT
%defattr(-,root,root)
/boot/vmlinu?-%{KVERREL}BOOT
/boot/System.map-%{KVERREL}BOOT
/boot/config-%{KVERREL}BOOT
%dir /lib/modules
%dir /lib/modules/%{KVERREL}BOOT
/lib/modules/%{KVERREL}BOOT/kernel
/lib/modules/%{KVERREL}BOOT/build
%endif

# only some architectures need kernel-source and kernel-doc

%if %{buildsource}

%files source
%defattr(-,root,root)
%dir /usr/src/linux-%{KVERREL}
/usr/src/linux-%{KVERREL}/COPYING*
/usr/src/linux-%{KVERREL}/CREDITS
/usr/src/linux-%{KVERREL}/Documentation
/usr/src/linux-%{KVERREL}/MAINTAINERS
/usr/src/linux-%{KVERREL}/Makefile
/usr/src/linux-%{KVERREL}/README
/usr/src/linux-%{KVERREL}/REPORTING-BUGS
/usr/src/linux-%{KVERREL}/Rules.make
/usr/src/linux-%{KVERREL}/arch
/usr/src/linux-%{KVERREL}/drivers
/usr/src/linux-%{KVERREL}/crypto
/usr/src/linux-%{KVERREL}/fs
/usr/src/linux-%{KVERREL}/init
/usr/src/linux-%{KVERREL}/ipc
/usr/src/linux-%{KVERREL}/kernel
/usr/src/linux-%{KVERREL}/lib
/usr/src/linux-%{KVERREL}/mm
/usr/src/linux-%{KVERREL}/net
/usr/src/linux-%{KVERREL}/scripts
/usr/src/linux-%{KVERREL}/configs
/usr/src/linux-%{KVERREL}/include
/usr/src/linux-%{KVERREL}/tmp_include_depends
/usr/src/linux-%{KVERREL}/.depend
/usr/src/linux-%{KVERREL}/.hdepend

%files doc
%defattr(-,root,root)
%doc linux-%{version}/Documentation/*

%endif

%changelog
* Tue Nov 13 2007 Don Howard <dhoward@redhat.com> kernel-2.4.21-53.EL
- Fix ipv4 treason uncloaked message (Anton Arapov) [249237]
- Fix ipv4 fib-sem-out-of-bounds checking (Don Howard) [250429] {CVE-2007-2172}
- Reset current->pdeath_signal on SUID binary execution (Peter Zijlstra) [251117] {CVE-2007-3848}
- Fix local DoS with corrupted elf on ia64 (Don Howard) [289171] {CVE-2006-4538}
- prevent stack from growing into hugepages region (Don Howard) [294951] {CVE-2007-3739}
- Fix missing ioctl permission checks in aacraid (Don Howard) [298331] {CVE-2007-4308}

* Mon Sep 24 2007 Don Howard <dhoward@redhat.com> kernel-2.4.21-52.EL
- Validate all 64bits of ptrace information. (Don Howard)

* Tue Jul 24 2007 Jerome Marchand <jmarchan@redhat.com> kernel-2.4.21-51.EL
- properly initialized e1000 ESB2 NIC RX unit (Andy Gospodarek)
- fix e1000: ESB2 register value causes an rlogin problem (Vince Worthington)
- fix bluetooth setsockopt() information leaks (Don Howard)
- fix overflow in CAPI subsystem (Don Howard)

* Tue May  8 2007 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-50.EL
- improve IGMP join processing during bonding failover (Andy Gospodarek)
- fix EHCI period handling for high-speed USB HID devices (Pete Zaitcev)

* Wed Apr 18 2007 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-49.EL
- fix dput() crash regression caused in -47.5.EL (Eric Sandeen)
- add ifcfg-bond0 documentation in bonding.txt (Andy Gospodarek)
- fix nfs.o symbol regression caused in -47.5.EL (Steve Dickson)

* Tue Mar 27 2007 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-48.EL
- revise megaraid_sas reboot notifier fix made in -47.7.EL (Chip Coldwell)
- rename RHEL_RELEASE created in -47.7.EL to RHEL_VERSION (Ernie Petrides)
- prevent stuck Alt-SysRq-active state with USB keyboards (Ernie Petrides)

* Thu Mar 22 2007 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-47.8.EL
- prevent igmp multicast messages as interface is going down (Thomas Graf)
- allow PAL_HALT_LIGHT idle loop for ia64 use under Xen (Aron Griffis)
- correct i/o resource allocations in acpiphp driver (Prarit Bhargava)
- fix __dget_locked() race leading to nr_unused underflow (Jeff Layton)
- allow LauS to audit init when audit_all_processes is 2 (Bryn Reeves)
- do not share ipv6 flow label list with new sockets (Neil Horman)
- avoid sleeping with spinlock in aacraid driver (Chip Coldwell)

* Mon Mar 19 2007 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-47.7.EL
- fix shmat() addr wrap for 32-bit-compat tasks on x86_64 (Larry Woodman)
- add oprofile recognition for Xeon cpu models 4 and 6 (Radovan Augustin)
- fix bonding failover w/e1000 under heavy UDP traffic (Andy Gospodarek)
- add megaraid_sas reboot notifier for cache flushing (Chip Coldwell)
- fix ext2/ext3 wrong-group block allocation problem (Eric Sandeen)
- add RHEL_RELEASE/UPDATE for 3rd-party modules (Konrad Rzeszutek)
- add LauS support for auditing detach events (Bryn Reeves)
- fix year-2007 time table overflow in tux (Jason Baron)

* Mon Mar  5 2007 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-47.6.EL
- add netdump support to 8139cp driver for use under Xen (Chris Lalancette)
- fix U7 e1000 Wake-on-LAN regression caused in -37.7.EL (Andy Gospodarek)
- prevent dup2() EBUSY errors from m/t fork() fd race (Radovan Augustin)
- avoid possible data corruption after swap i/o errors (Larry Woodman)
- update SCSI whitelist for STK OPENstorage 9176 devices (Tomas Henzl)
- reduce high TCP latency when transferring small packets (Adam Stokes)
- fix interrupt-interval for high-speed USB HID devices (Pete Zaitcev)
- prevent NT cpu flag leak to other tasks on x86_64 (Ernie Petrides)

* Wed Feb  7 2007 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-47.5.EL
- fix ACL effect on modes of newly created files on NFS (Peter Staubach)
- skip ext3 orphan inode recovery on read-only snapshots (Eric Sandeen)
- reduce stack usage when validating NFS file attributes (Thomas Graf)
- add ext2 dir size sanity checks in ext2_find_entry() (Eric Sandeen)
- avoid more races between unmount and dcache pruning (Eric Sandeen)
- fix Committed_AS accounting w/32-bit-compat execs (Ernie Petrides)
- prevent ipmi_si oops w/no underlying IPMI h/w (Peter Martuccelli)
- remove x86_64 debugging messages during SMP start-up (Jeff Burke)

* Wed Dec 20 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-47.4.EL
- fix USB handling of 6-byte payloads from PowerMate devs (Pete Zaitcev)
- correct file descriptor limit check for poll() syscalls (Chris Snook)
- prevent crash in md multipath alias sb update checking (Doug Ledford)
- avoid EOVERFLOW errors from fstat() with 64-bit inums (Jeff Layton)
- validate buffer len in cramfs_readpage() for safety (Eric Sandeen)
- enable GFP_ATOMIC retries via vm-defragment sysctl (Larry Woodman)
- unmap amd64 GART window to avoid memory corruption (Chip Coldwell)
- fix potential uidhash_lock/tasklist_lock deadlock (Ernie Petrides)

* Wed Nov  1 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-47.3.EL
- force BIOS call in acpi_power_off() to run on boot cpu (Jim Paradis)
- update dcache when NFS server returns ENOENT on remove (Jeff Layton)
- allow more UDP mounts by reworking xprt_bindresvport() (Jeff Layton)
- fix ipmi_kcs_drv module regression caused in -41.EL (Andy Gospodarek)
- fix kscand_work_percent regression caused in -32.12.EL (Larry Woodman)
- add zero-padding logic for s390,x copy_from_user() faults (Jan Glauber)
- add e1000 PCI device id for Intel 82572EI network card (John Linville)
- prevent submit_bh_rsector() from using freed buf head (Larry Woodman)

* Tue Oct 10 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-47.2.EL
- fix forcedeth driver to scan PHY 0 for xw9400 NICs (Prarit Bhargava)
- fix clock drift by disabling C1 clock ramping on AMD (Prarit Bhargava)
- update NVIDIA PCI quirk handling for nForce chipsets (Prarit Bhargava)
- fix checksum bug with multicast/broadcast IP packets (Andy Gospodarek)
- prevent potential memory corruption from ATM/clip_mkip() (Thomas Graf)
- avoid bogus MAC addresses with some tg3 5703X cards (Andy Gospodarek)
- fix autofs4 clean-up/restart when automount daemon aborts (Ian Kent)
- fix netconsole message timeouts following tg3 netdumps (Jeff Moyer)

* Fri Sep 22 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-47.1.EL
- (this is the first build for RHEL 3 Update 9)
- fix buflen assignment for DVD BDA read requests (Chip Coldwell)
- prevent write permission w/read-only shm segments (Ernie Petrides)
- dump all regs in x86_64 multi-threaded core dumps (Chris Lalancette)
- fix tty_wakeup() arg in hvsi and bluetooth drivers (Andy Gospodarek)
- fix message logging bug with /proc/s390dbf/dasd/sprintf (Jatin Nansi)
- prevent possible deadlock with shmat()/shm-rmid races (Sachin Prabhu)
- prevent smbfs chroot hole by prohibiting backslashes (Peter Staubach)
- fix losing of kmap entries during aborted core dumps (Ernie Petrides)

* Wed Jul  5 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-47.EL
- fix x86 cpu enumeration regression caused in -41.EL (Jim Paradis)
- fix ptrace_notify() regression caused in -40.10.EL (Ernie Petrides) 

* Fri Jun 23 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-46.EL
- fix double PCI slot scan regression caused in -37.8.EL (Brian Maly)
- fix MD list locking regression caused in -40.10 (Doug Ledford)

* Wed Jun 21 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-45.EL
- fix double f_count increment in nlmsvc_grant_reply() (Jeff Layton)
- fix support for 6321ESB in e1000 driver upgrade (John Linville)
- fix bad kfree() calls in SNMP NAT netfilter code (Thomas Graf)

* Fri Jun  9 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-44.EL
- fix "phantom increasing load" problem in scheduler (Ingo Molnar)
- fix long boot-up latency on x86_64 128-GB systems (Larry Woodman)
- fix netdump-on-e1000 regression caused in -40.6.EL (Neil Horman)
- update SCSI whitelist for Netapp/Decru controllers (Tom Coughlan)

* Fri May 12 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-43.EL
- fix e1000 packet-split regression caused in -40.6.EL (Neil Horman)
- fix QLogic symbol regression caused in -40.10.EL (Nobuhiro Tachino)

* Fri May  5 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-42.EL
- fix scatterlist loop limit in -41.EL SCSI tape dev fix (Chip Coldwell)
- use configured timeout in LVS connection sync daemon (Andy Gospodarek)
- fix netconsole hang regression in U7 from -37.11.EL fix (Jeff Moyer)
- update SCSI whitelist for new HP tape autoloader devs (Chip Coldwell)
- revert link-watch patch due to -41.EL boot-up hangs (Ernie Petrides)
- update Emulex lpfc storage driver (again) to 7.3.6 (Chip Coldwell)

* Tue Apr 25 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-41.EL
- make NFS "intr" option really work as advertised (Steve Dickson)
- resolve IPMI start-up race during module load (Peter Martuccelli)
- prevent SCSI tape device panic when allow_dio=1 (Chip Coldwell)
- fix x86 kernel boot with non-zero-based APIC IDs (Jim Paradis)
- fix bonding failover under heavy UDP traffic (Andy Gospodarek)
- avoid MCAs from accessing /proc/kcore on ia64 (Ernie Petrides)
- add blacklist entries for IBM RSA-II devices (Konrad Rzeszutek)
- update QLogic driver to more recent 7.07.04b6 (Mike Christie)

* Mon Apr 24 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-40.10.EL
- prevent reentry into reboot_notifier functions (Ernie Petrides)
- implement diskdump support in QLogic driver (Nobuhiro Tachino)
- fix exec() after ptrace() on thread group leader (Peter Staubach)
- add appropriate locking around MD list traversal (Doug Ledford)
- fix autofs4 ENOENTs for successful replicated mounts (Jeff Moyer)
- fix audit killing of 32-bit-compat cmds on x86_64 (Ernie Petrides)
- correct ppc64 handling of veth removal during init (David Howells)
- fix revalidation of devices with large sector sizes (Jeff Knaggs)

* Fri Apr 21 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-40.9.EL
- prevent USB devio oops from async SIGPIPE delivery (Pete Zaitcev)
- update cciss disk driver to version 2.4.60.RH1 (Tom Coughlan)
- update SCSI whitelist for HP, Xyratex devices (Tom Coughlan)
- update Emulex lpfc storage driver to 7.3.5 (Chip Coldwell)
- fix MD size for 1-TB arrays on 64-bit arches (Doug Ledford)
- fix reboot problems on Dell PowerEdge 6400, 6450 (Norm Murray)
- suppress "request_module[net-pf-0]" messages (Ernie Petrides)
- prevent x86/x86_64 FP info leak on AMD cpus (Jim Paradis)

* Thu Apr 20 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-40.8.EL
- add vm-defragment sysctl for __alloc_pages() retries (Larry Woodman)
- fix page cache consistency with mmap'ed files over NFS (Jeff Layton)
- fix USB serial driver oopses with device disconnects (Pete Zaitcev)
- update QLogic driver to 7.07.04b4 (w/new firmware) (Mike Christie)
- correct cpu-to-APIC ID mappings with >8 cpus on x86 (Jatin Nansi)
- prevent deadlocks using netfilter ip_queue module (Thomas Graf)
- incorporate Dell's dcdbas driver version 5.6.0-1 (Neil Horman)
- fix Alloc-PE value when lvm_snapshot_alloc() fails (Milan Broz)

* Wed Apr 19 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-40.7.EL
- allow IBM x336/x260/x460 to boot without "acpi=noirq" (Konrad Rzeszutek)
- add EM64T "maxdma=X" option to avoid DMA alloc failures (Larry Woodman)
- eliminate spurious GART TLB machine check errors on x86_64 (Jim Paradis)
- fix x86_64 32-bit-compat support for sched_rr_get_interval() (Jim Paradis)
- assign/propagate rlimit_rss for root/multi-threaded tasks (Larry Woodman)
- implement diskdump support in megaraid_sas driver (Nobuhiro Tachino)
- fix anomalous getcwd() result over NFS as root/nobody (Peter Staubach)
- incorporate adp94xx driver version 1.0.8 for 9410 Razor (Konrad Rzeszutek)

* Thu Apr  6 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-40.6.EL
- fix x86_64 sigreturn/vsyscall regression from -40.4.EL (Ernie Petrides)
- ensure interrupted NFS lock requests are cleaned up (Steve Dickson)
- avoid double clock intrs with ATI/ServerWorks chipsets (Brian Maly)
- update tg3 network driver to version 3.52RH (John Linville)
- update e1000 network driver to version 7.0.33-k2 (John Linville)
- prevent megaraid2 hang w/extra reboot-notify call (David Milburn)
- add x86_64 32-bit-compat PTRACE_GETEVENTMSG support (Chris Snook)
- eliminate "i8253 count too high!" warnings on Athlons (Brian Maly)

* Mon Mar 27 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-40.5.EL
- enable users to perform diskdumps to swap partitions (Kei Tokunaga)
- zero out scatterlist buffer in SCSI st tape driver (Chip Coldwell)
- resolve IPMI driver load issue on HS40 blades (Peter Martuccelli)
- update bnx2 net driver to 1.4.38 with menuconfig fix (John Linville)
- increase USB HCRESET timeout for new HP systems w/iLO2 (Norm Murray)
- copy extra siginfo si_fd value on x86_64/ppc64/s390x (Ernie Petrides)
- prevent zero IP packet ID vulnerability with no firewall (Thomas Graf)
- fix padding info leak w/getsockopt() SO_ORIGINAL_DST opt (Thomas Graf)

* Fri Mar 10 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-40.4.EL
- fix O_DIRECT reads of the final partial block of a file (Jeff Moyer)
- prevent reassignment of locks for close-on-exec files (Peter Staubach)
- reconnect USB storage devices to the correct interface (Pete Zaitcev)
- correct IPMI event id for kernel-generated events (Peter Martuccelli)
- fix double faults on EM64Ts from non-canonical RIPs (Ernie Petrides)
- avoid truncated data values following ppc64 sig return (Neil Horman)
- fix netdump operation over Broadcom bnx2 devices (Andy Gospodarek)
- fix ia64 big-endian unaligned access handling (Anil Keshavamurthy)

* Thu Feb 23 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-40.3.EL
- update QLogic driver to 7.07.02-RH1 (w/new firmware) (Mike Christie)
- make exported dump_stack() interface useful on x86_64 (Jeff Layton)
- fix 32-bit overflows for BHs/inodes with >4GB memory (Larry Woodman)
- avoid printing SCSI errors for missing removable media (Pete Zaitcev)
- fix memory leak in error path of e1000 loopback test (John Linville)
- fix bonding driver to allow VLAN traffic over bond (John Linville)
- fix bonding driver to let slave use bond's MAC addr (John Linville)
- add support for MCP51/MCP55 in forcedeth driver (Andy Gospodarek)

* Fri Feb 17 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-40.2.EL
- prevent syslog-only netdump config from dumping memory (Dave Anderson)
- fix double AIO completion for reads issued during writes (Jeff Moyer)
- add 10 ms TRSTRCY delay to USB hub port reset handling (Pete Zaitcev)
- warn about installs of x86_64 RPMs run on EM64T systems (Eric Paris)
- fix 32-bit overflow in vmap() check with >4GB memory (Larry Woodman)
- prevent /proc/scsi/scsi access oops in dpt_i2o driver (Don Howard)
- correct parsing of "mce=..." boot option on x86_64 (Jim Paradis)
- fix race between unmount and prune_one_dentry() (Dave Anderson)

* Wed Feb 15 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-40.1.EL
- (this is the first build for RHEL 3 Update 8)
- fix excessive firmware load times in qla2200 driver (Jeff Layton)
- fix missing bit in ECC syndrome reporting on x86_64 (Jeff Layton)
- correct hang with radeon driver when DRM DRI is active (Don Howard)
- fix mm_struct reference leak in ioctx_alloc() error path (Jeff Moyer)
- fix autofs4 hang due to race between mount/expire events (Jeff Moyer)
- switch IPSEC SAs over properly as recommended by RFC 2408 (Dave Miller)
- avoid NFS deadlocks due to holding multiple pkmap entries (Neil Horman)
- update forcedeth driver to v0.30 w/ethtool additions (Chris Lalancette)

* Thu Feb  2 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-40.EL
- fix multicast domain membership failover with bonding (Andy Gospodarek)
- add 82571/2 support to e1000 driver version 6.1.16-k3 (John Linville)
- fix NMI error w/acpi=noirq regression from -37.7.EL (Ernie Petrides)

* Fri Jan 20 2006 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-39.EL
- avoid logging info msgs when file leases are broken (Peter Staubach)
- restore e1000 PCI device id for Concho network adapter (John Linville)
- fix mptfusion intr mask handling to support PCI Express (Tom Coughlan)
- fix IPV4 DST entry leak in icmp_push_reply() error path (Thomas Graf)
- fix IPV6 SKB mem leak in ip6_input_finish() error path (Thomas Graf)
- correct struct ref counting in IPV6 flowlabel handling (Thomas Graf)
- reject unicast reports to prevent potential IGMP DoS (Thomas Graf)
- remove undesirable negative dentry caching in autofs4 (Jeff Moyer)
- add missing 5708 support to bnx2 network driver (John Linville)
- fix SATA assertion regression from -38.EL (Peter Martuccelli)
- prevent USB serial_write() oops after disconnect (Pete Zaitcev)
- add USB serial support for PL-2303 HX devices (Pete Zaitcev)
- fix x86 boot Viper/SCSI regression from -37.8.EL (Brian Maly)

* Thu Dec  1 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-38.EL
- incorporate dell_rbu driver version 2.1 for BIOS updates (Brian Maly)
- remove obsolete backup drivers replaced by newer revs (Tom Coughlan)
- upgrade SATA support (core, libata, and drivers) (Jeff Garzik)

* Tue Nov 29 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-37.12.EL
- prevent short writes to sparse files using O_DIRECT (Larry Woodman)
- add numa_memory_allocator sysctl for NUMA on x86_64 (Larry Woodman)
- limit SCSI request queue segments to fit in one page (Doug Ledford)
- rework USB ohci fixes that caused -26.2.EL regression (Pete Zaitcev)
- prevent races between /proc access and module unload (Alexander Viro)
- update OpenIPMI driver to version 35.11 plus fixes (Peter Martuccelli)
- update Emulex lpfc driver to 7.3.3 (no new backup rev) (Tom Coughlan)
- move ia64_do_page_fault() check for region 5 faults (Geoff Gustafson)

* Mon Nov 28 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-37.11.EL
- allow dir rename onto an existing empty dir under NFS (Neil Horman)
- add cpu_relax() calls in several ia64 spin loops (Geoff Gustafson)
- avoid wait queue misuse in s390,x pfault_interrupt() (Jan Glauber)
- fix broken expiration of negative dentries in autofs4 (Jeff Moyer)
- revise netconsole retransmit handling to be time-based (Jeff Moyer)
- incorporate megaraid_sas driver version 00.00.02.00 (Tom Coughlan)
- fix 32-bit-compat handling for USBDEVFS_IOCTL ioctl (Pete Zaitcev)
- fix megaraid2 rmmod/insmod crash on EM64Ts with >4GB (Tom Coughlan)

* Tue Nov 22 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-37.10.EL
- defend against cmsghdr32 changes in ppc64 recvmsg() (David Howells)
- fix cache coherency problem on ia64 for Montecito (Geoff Gustafson)
- eliminate usage of io_apic_get_unique_id() on x86_64 (Jim Paradis)
- fix s390,x race that could cause lost page dirty bit (Jan Glauber)
- correct phys/core cpu ids in /proc/cpuinfo on amd64 (Jim Paradis)
- update aacraid driver to 1.1.5-2412 (no backup) (Tom Coughlan)
- modify copyright in drivers/net/pcmcia/i82593.h (John Linville)
- fix ksyms compatibility w/_cpu_data on ia64 (Geoff Gustafson)

* Thu Nov 17 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-37.9.EL
- correct ppc64 XTABS definition to be same as TAB3 (David Howells)
- incorporate bnx2 network driver version 1.4.30 (John Linville)
- eliminate erroneous APIC IRR msgs on x86/x86_64 (Neil Horman)
- update tg3 network driver to version 3.43RH (John Linville)
- validate uaddr/uaddr2 args in futex() handling (Dave Anderson)
- update megaraid2 driver to v2.10.10.1 (no backup) (Tom Coughlan)
- update SCSI whitelist for several new devices (Tom Coughlan)
- add support for shrink_icache_sb() interface (Wendy Cheng)

* Wed Nov  2 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-37.8.EL
- add detection of PCI peer bridges on x86 for AGP tunnels (Brian Maly)
- prevent buf overflow in NFS handling of long symlinks (Steve Dickson)
- fix sys param string size used by /proc/ppc64/lparcfg (David Howells)
- add ia64 multi-core and multi-threading cpu support (Geoff Gustafson)
- prevent infinite loop in IPV6 w/full UDP port h/table (Ernie Petrides)
- fix gzip/zlib flaws in 3 kernel huft_build() routines (Peter Staubach)
- fix netfilter portptr decls in TCP and UDP NAT handling (Don Howard)
- fix "make dep" in kernel source with long cwd names (Ernie Petrides)

* Wed Oct 26 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-37.7.EL
- fix reading of ACPI RSDT tables that span page boundaries (Jim Paradis)
- add support for HT1000 chipset in serverworks driver (John Linville)
- update e1000 network driver to version 6.1.16-k2 (John Linville)
- remove bogus 32-bit compat munging w/ICMPV6_FILTER (David Woodhouse)
- minimize __alloc_pages() order>0 failures and hangs (Larry Woodman)
- implement fallback DMA desc allocation in b44 driver (John Linville)
- change default setting for nmi_watchdog on EM64Ts (Ernie Petrides)
- fix netdump hangs following diskdup failures (Keiichiro Tokunaga)

* Wed Oct 19 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-37.6.EL
- add deterministic cache parameters support for Intel cpus (Brian Maly)
- fix negative child time usage vals under /proc/*/stat (Peter Staubach)
- fix "noht" boot-time option on x86 and add it for x86_64 (Jim Paradis)
- prevent races while accessing PCI config space on x86_64 (Jim Paradis)
- avoid indefinite yield() in multi-threaded core dumps (Dave Anderson)
- prevent SCSI st/sg mixed command hang and st tape oops (Doug Ledford)
- fix possible pkt padding info leaks in orinoco driver (John Linville)
- release file ref in x86_64 32-bit-compat tiocgdev() (Ernie Petrides)

* Fri Oct  7 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-37.5.EL
- fix lockd deadlock potential w/NML garbage collection (Steve Dickson)
- fix spurious ECHILD errors w/waitpid() on threaded apps (Ingo Molnar)
- fix crashes when auto-running multipath RAID devices (Doug Ledford)
- enable Adaptec SA-1210 interrupts in siimage driver (John Linville)
- synchronize task command name updates and accesses (Dave Anderson)
- remove port check from nfsd_cache_lookup() search (Steve Dickson)
- prevent minor info leak in x86 sys_get_thread_area() (Don Howard)
- fix second rollover race in x86_64/ia64 sys32_time() (Wendy Cheng)

* Thu Sep 29 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-37.4.EL
- avoid file creation during open() failures w/ENFILE (Peter Staubach)
- fix RLIMIT_FSIZE enforcement to allow 64-bit limits (Peter Staubach)
- don't expire in-use directory hierarchies under autofs4 (Jeff Moyer)
- improve exec-shield coverage w/fallback randomizer tweak (Ingo Molnar)
- fix getpriority()/setpriority() semantics with PRIO_USER (Ingo Molnar)
- prevent oops in aic7xxx driver while adding new devices (Doug Ledford)
- add printk_ratelimit sysctl to allow I/O errmsg control (Tom Coughlan)
- fix change_page_attr() regressions caused in -37.1.EL (Ernie Petrides)

* Wed Sep 21 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-37.3.EL
- prevent race between USB hot-swapping and /proc access (Pete Zaitcev)
- fix exec() crash w/address space limit on x86_64/ia64 (Dave Anderson)
- correct memnodemap[] indexing w/4G+ x86_64 NUMA systems (Jim Paradis)
- fix arithmetic overflow w/large poll() timeout values (Peter Staubach)
- avoid infinite recursion in autofs4 when using bind mounts (Jeff Moyer)
- fix ppc64 EEH token translation for PCI port I/O space (Nathan Lynch)
- fix multi-threaded reparenting bug to avoid exit() crash (Ingo Molnar)
- make x86 APIC ID mask 8 bits for hard_smp_processor_id() (Ingo Molnar)

* Wed Sep 14 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-37.2.EL
- update networking docs to reflect current e100 driver (John Linville)
- fix erroneous EFAULT errors from ia64 put_user() w/funcs (Neil Horman)
- make x86 stack dumping resilient to unaligned stk ptrs (Larry Woodman)
- fix false ext3 EA/ACL sharing between mbcache blocks (Stephen Tweedie)
- protect x86 load_LDT() from being called reentrantly (Dave Anderson)
- prevent O_DIRECT i/o within VMAs using remap_page_range() (Alan Cox)
- force link reinitialization on forcedeth driver opens (Neil Horman)
- fix open/close race oops in USB ACM driver handling (Pete Zaitcev)

* Mon Sep 12 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-37.1.EL
- (this is the first build for RHEL 3 Update 7)
- enhance removable/virtual keyboard support on x86/x86_64 (Brian Maly)
- prevent stuck Corrected-Platform-Error intrs on ia64 (Larry Woodman)
- add support for system-wide IPV4 arp_announce sysctl (John Linville)
- fix NX text/large-page change_page_attr() bug on x86 (Ingo Molnar)
- fix ia64-specific bug in semaphore counting/wakeups (Larry Woodman)
- allow system accounting to write to acct files >2GB (Peter Staubach)
- prevent cciss driver unload while diskdump activated (Tom Coughlan)
- make msync()/MS_SYNC syscalls fail after write errs (Peter Staubach)

* Wed Sep  7 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-37.EL
- fix latent sendmsg() cmsghdr32 bug exposed in -36.EL (Dave Miller)

* Fri Sep  2 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-36.EL
- fix sync() hangs from NFS file create/delete races (Steve Dickson)
- add support for HP Smart Array E400i in cciss driver (Tom Coughlan)
- defend against cmsghdr32 changes in sendmsg() handling (Dave Miller)
- correct OpenIPMI module version strings (v35 -> 35.4) (Brian Maly)
- fix intermittent build failures under lpfc subdir (Ernie Petrides)

* Fri Aug 19 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-35.EL
- disable FAN processing in Emulex driver (7.3.2) (Tom Coughlan)
- update cciss disk driver to version 2.4.58.RH1 (Tom Coughlan)
- update SCSI whitelist for EMC Invista devices (Tom Coughlan)
- fix diskdump regression w/module CRC errors (Nobuhiro Tachino)
- update SCSI whitelist for IBM ULT3580 TapeLibrary (Wendy Cheng)
- fix f/w upgrade hang, dmi_table bug in IPMI (Peter Martuccelli)
- fix x86_64 machine check regression from -32.10.EL (Brian Maly)
- validate XFRM policy in IPSEC setsockopt() calls (John Linville)
- fix intr kiobuf_init() regression from -32.11.EL (Larry Woodman)
- fix pollcomplete error in cciss diskdump support (Tom Coughlan)
- enforce CAP_NET_ADMIN perms for policy creation (John Linville)

* Thu Jul 28 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-34.EL
- fix O_SYNC EIO error propagation through ext3/jbd (Stephen Tweedie)
- add support for Enterprise Southbridge II (ESB2) (Geoff Gustafson)
- implement devname callback for block device drivers (Doug Ledford)
- upgrade SATA support (core, libata, and drivers) (Jeff Garzik)
- add ia64 export of (*pm_power_off)() for IPMI (Peter Martuccelli)

* Tue Jul 19 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-33.EL
- update 3w-9xxx driver to version 2.24.03.008RH (Tom Coughlan)
- revise reserved port avoidance added in -32.8.EL (Steve Dickson)
- update OpenIPMI driver/configs to version v35 (Peter Martuccelli)
- add handling for NEC vendor ID in megaraid2 driver (Tom Coughlan)
- update SCSI whitelist for 3PARdata/Dell/SGI devices (Tom Coughlan)
- add support for netdump over bonded interfaces (Jeff Moyer)
- implement diskdump support for cciss devices (Tom Coughlan)
- add x86_64 ACPI Power Management timer support (Jim Paradis)
- add dual-core support on x86 and x86_64 arches (Jim Paradis)

* Fri Jul 15 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-32.12.EL
- constrain x86_64 MSR writes based on cpu model (Larry Woodman)
- correct smbfs mounts to support 32-bit uids/guids (Peter Staubach)
- eliminate long system pauses when kscand is running (Larry Woodman)
- update Emulex driver to 7.3.1, ioctl module to 1.2.1 (Tom Coughlan)
- update QLogic driver to 7.05.00-RH1 (w/new firmware) (Tom Coughlan)
- prevent ext3 EA/ACL block sharing/deletion races (Stephen Tweedie)
- fix dpt_i2o insmod oops during adpt_info() lookup (Neil Horman)
- fix dpt_i2o timeouts during long tape commands (Tom Coughlan)

* Wed Jul 13 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-32.11.EL
- downgrade blk_queue_bounce_limit() msg to KERN_INFO (Neil Horman)
- update cciss disk driver to version 2.4.56.RH1 (Adam Manthei)
- update mptfusion driver to version 2.06.16i.01 (Tom Coughlan)
- prevent expand_kiobuf() calls during interrupts (Larry Woodman)
- update iscsi_sfnet driver to version 3.6.2.1 (Mike Christie)
- account for system ticks in ITIMER_PROF sig delivery (Don Howard)
- correct superbh ptr arg to superbh_will_bounce() (Stephen Tweedie)
- fix ext3 symlink perms created w/i386-BOOT kernels (Stephen Tweedie)

* Mon Jul 11 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-32.10.EL
- prevent bogus GART errs from amd64 Northbridge handling (Brian Maly)
- get correct link status in b44 driver's open routine (John Linville)
- check for missing EM64T support for better panic msg (Ernie Petrides)
- fix ref counting bug in x86[_64] __change_page_attr() (Dave Anderson)
- fix memory leak in success path of sys_init_module() (John Linville)
- add ia64 ptrace/sigreturn RSC reg priv level validation (Jason Baron)
- prevent connection list corruption in ip_vs_conn_flush() (Neil Horman)
- limit arg/env ptrs for x86_64/ia64 32-bit-compat execs (Dave Anderson)

* Fri Jun 17 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-32.9.EL
- fix crashes from failed ACPI root bus additions (Jim Paradis)
- correct insufficient lock owner checks in DRM code (Don Howard)
- add missing sanity checks in Coda ioctl handling (Alexander Viro)
- fix autofs errors with ghosting and expire event races (Jeff Moyer)
- reset ppc64 signal handler correctly for SA_ONESHOT (David Howells)
- store prev user stack pointer in ppc64 signal frames (David Howells)
- fix kernel_lock deadlock between sd_open()/sd_ioctl() (Larry Woodman)
- add ht flag in /proc/cpuinfo for EM64Ts w/hyperthreading (Brian Maly)

* Tue Jun 14 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-32.8.EL
- update e100 network driver to version 3.4.8-k2 (John Linville)
- preserve x86_64 32-bit-compat ptrace reg changes (Roland McGrath)
- add missing x86_64 support for PTRACE_SETOPTIONS (Roland McGrath)
- avoid using reserved ports for portmapper connections (Steve Dickson)
- prevent non-canonical %rip in x86_64 ptrace reg mods (Jim Paradis)
- prevent invalid fs/gs_base in x86_64 ptrace reg mods (Ernie Petrides)
- improve ISO-9660 fs robustness against bad CD formats (Peter Staubach)
- correct __get_user_pages() ref counting w/PG_reserved (Dave Anderson)

* Wed Jun  8 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-32.7.EL
- fix IPV6 isRouter flag and default router list handling (John Linville)
- eliminate unexpected IO-APIC msg from x86 kernel on amd64 (Jim Paradis)
- switch to reg stack on user-mode x86_64 stk seg faults (Dave Anderson)
- fix two time-related problems in the netconsole module (Dave Anderson)
- remove microcode.o from x86 hugemem unsupported list (Ernie Petrides)
- fix x86_64 committed space accounting w/overcommit=2 (Larry Woodman)
- enforce page locking resource limit in expand_stack() (Jason Baron)
- fix SCSI command block leak w/off-line non-zero LUNs (Doug Ledford)

* Tue May 31 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-32.6.EL
- fix races between POSIX locking and file closes (Peter Staubach)
- update tg3 network driver to version 3.27RH (John Linville)
- add ia64 frame size validation in syscall handling (Jason Baron)
- prevent info leaks into JFS metadata disk blocks (Stephen Tweedie)
- fix ext2 fast-symlink/EA compatibility problem (Stephen Tweedie)
- add x86_64 32-bit-compat SO_{SND,RCV}TIMEO support (Guy Streeter)
- add piix driver PCI device ids for ICH4-L support (John Linville)
- validate "ndigis" value in addition of ROSE routes (Dave Miller)

* Thu May 26 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-32.5.EL
- update e1000 network driver to version 6.0.54-k2 (John Linville)
- fix arp_ip_traget failover with bonding driver mode 1 (Eric Paris)
- prevent indefinite postponement under __alloc_pages() (Ernie Petrides)
- capture ia64 reg state on all cpus for OS_INIT dumps (Nobuhiro Tachino)
- add documentation listing which drivers support netconsole (Jeff Moyer)
- fail opens of removable media drives if media not present (Pete Zaitcev)
- fix x86_64 find_target() oops in 32-bit-compat ptrace() (Ernie Petrides)
- prevent info leaks into ext2 directory entry blocks (Stephen Tweedie)

* Fri May 13 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-32.4.EL
- limit concurrent OOM kills using /proc/sys/vm/oom-kill (Ernie Petrides)
- rework ppc64 wchan fix to avoid module install crashes (David Woodhouse)
- fix diskdump signature check failures w/block_order=8 (Nobuhiro Tachino)
- fix data corruption from pte_clear() races on >4GB x86's (Larry Woodman)
- avoid s390,x kernel stack overflows in network ctc driver (Pete Zaitcev)
- add description of /proc/stat to file system documentation (Brian Maly)
- avoid inode races in __refile_inode() and clear_inode() (Larry Woodman)
- fix arg/env access in ELF core dumping and /proc reads (Ernie Petrides)

* Wed May  4 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-32.3.EL
- remove extra chars from scsi_logging_level mod param (Ernie Petrides)
- use GFP_NOFS allocs to avoid kswapd/rpciod deadlocks (Steve Dickson)
- fix ia64 kernel thread creation to force 64-bit tasks (Jason Baron)
- fix data corruption from 4K overflow in /proc/devices (Neil Horman)
- prevent mlock() resource limit bypass w/shm locking (Ernie Petrides)
- restrict MOXA ctlr firmware updates to privileged users (Brian Maly)
- support EM64T systems with mix of cpus with/without NX (Jim Paradis)
- allow modules to use get/put_task_struct() macros (Ernie Petrides)

* Fri Apr 22 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-32.2.EL
- fix IDE disk accounting bug from wrong ios_in_flight (Larry Woodman)
- limit IGMP traffic to active link in bond_alb_xmit() (John Linville)
- fix audit refs to permit /var unmounting on shutdown (Dave Anderson)
- prevent IP4/6 output memory leaks of dst_entry structs (Dave Miller)
- enhance support for ethtool in 3c59x network driver (John Linville)
- fix launder_page() locking to avoid kswapd deadlock (Larry Woodman)
- suppress ide-floppy I/O errors when media isn't present (Brian Maly)
- make netdump more reliable on NAPI-enabled controllers (Jeff Moyer)

* Wed Apr 20 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-32.1.EL
- (this is the first build for RHEL 3 Update 6)
- fix oops when io_setup() is called w/unwritable addr (Jeff Moyer)
- prevent kswapd hangs under launder_page() w/no bufs (Larry Woodman)
- fix autofs memory leaks when events share wait queues (Jeff Moyer)
- change IBM veth driver to indicate link is always up (David Howells)
- fix error resets and TF reg reads in SATA AHCI driver (Jeff Garzik)
- avoid dropping >200-byte frames in sk98lin driver (John Linville)
- prevent shared memory lock/unlock w/o permissions (Dave Anderson)
- remove duplicate USB ESSENTIAL_REALITY defines (Pete Zaitcev)

* Fri Apr 15 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-32.EL
- fix data corruption w/ext3 xattr on 64-bit arches (Jason Baron)
- validate LCP frame lengths in PPP async handling (Dave Miller)
- enable forcedeth net driver builds in x86 configs (Jim Paradis)
- isolate IP fragment queues among various callers (Dave Miller)
- prevent busy inodes for symlinks after unmounts (Don Howard)
- revise PCI device ids extending ICH7 support (John Linville)
- work around broken xw4300 BIOS AHCI BAR setup (John Linville)
- add protocol validation in net bluetooth driver (John Linville)
- enable software watchdog timer in s390,x configs (Jan Glauber)
- fix data corruption w/uselib() on bad ELF libs (Ernie Petrides)
- add USB tablet init delay in wacom_probe() (Kristian Hgsberg)
- prevent core dumps with non-readable ELF interps (Dave Anderson)
- add maxevents validation in epoll_wait() handling (Ernie Petrides)
- add len validation in /dev/random poolsize sysctl (Ernie Petrides)
- correct size of ia64 syscall table initialization (Jason Baron)
- correct x86_64 user-mode i/o port validation (Ernie Petrides)

* Thu Mar 10 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-31.EL
- fix missing ppc64 netdump/diskdump symbols (Nobuhiro Tachino)
- prevent ia64 unwind from traversing off stack (Jason Baron)
- disable 3w-9xxx driver builds on ppc64 (Peter Martuccelli)

* Wed Mar  9 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-30.EL
- fix obscure oops in tty init_dev() handling (Jason Baron)

* Thu Mar  3 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-29.EL
- incorporate urgent late-breaking SATA fixes (Jeff Garzik)

* Wed Feb 23 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-28.EL
- add more USB device support to visor driver (Pete Zaitcev)
- implement clustered APIC support for x86_64 (Larry Woodman)
- constrain x86 MSR writes based on cpu model (Jason Baron)
- increase max superbh size for performance (Stephen Tweedie)
- add locking to prevent oops in md_seq_show() (Doug Ledford)
- restore missing ia64 panic_on_oops handling (Tatsuo Uchida)
- implement Ethernet PCI quirk for HP xw9300 (Jim Paradis)
- revert NFS flock() avoidance to -27.7.EL (Ernie Petrides)

* Mon Feb 21 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-27.17.EL
- rework NFS flock() avoidance w/FS_WANT_FLOCK for GFS (Ken Preslan)
- prevent inode corruption from delete/lookup races (Wendy Cheng)
- preserve registers for ia64 16-byte atomic ops (Geoff Gustafson)
- update SCSI whitelist for LSI/HP/STK/EMC devices (Tom Coughlan)
- disable vary_io in ips driver to avoid ctlr hangs (Tom Coughlan)
- correct handling of 2-TB device partitions (Peter Martuccelli)
- update support for ia64 perfmon facility (Jason Baron)

* Fri Feb 18 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-27.16.EL
- implement diskdump support for SATA piix/promise (Nobuhiro Tachino)
- correct /proc/mtrr size values on EM64T platforms (Larry Woodman)
- restore page permissions after writes from ptrace() (Don Howard)
- fix /proc parent pids from multi-threaded forks (Ernie Petrides)
- enable software watchdog timer support on s390,x (Jan Glauber)
- update tg3 network driver to version 3.22RH (John Linville)
- incorporate 3w-9xxx driver version 2.24.00.011fw (Adam Manthei)
- correct ending boundary check in filemap_sync() (Larry Woodman)

* Wed Feb 16 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-27.15.EL
- add e100 driver PCI device ids for ICH7 support (John Linville)
- restore obsolete but ignored e100 module params (John Linville)
- implement user-mode (gdb) access to ia64 gate page (Jason Baron)
- fix x86_64 FPU IP and DP values in SIGFPE context (Larry Woodman)
- add qla2200 module parameter to use NVRAM RIO val (Tom Coughlan)
- update 3w-xxxx driver to 1.02.00.037 w/.033 backup (Adam Manthei)
- fix crashes in video Firewire (ieee1394) driver (Bastien Nocera)
- prevent info leaks into ext3 journal disk blocks (Ernie Petrides)

* Tue Feb 15 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-27.14.EL
- enhance AIO performance over NFS w/FS_AIO_SYNC hook (Steve Dickson)
- defer e100_tx_timeout() work from interrupt context (John Linville)
- correct IPV6 DST entry release to prevent route leak (Dave Miller)
- ignore MTU updates from invalid IPV6 ndisc packets (Dave Miller)
- add relevant PCI device ids to extend ICH7 support (John Linville)
- reduce system pauses during heavy page laundering (Larry Woodman)
- fix audit logging of paths w/predicate filter usage (Neil Horman)
- enable building of unsupported fusion isense module (Adam Manthei)

* Mon Feb 14 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-27.13.EL
- increase dxfer size limit for ppc64 SG_IO ioctl32 (David Howells)
- eliminate tty line discipline usage/switching races (Jason Baron)
- fix autofs recognition of ghosted direct map updates (Jeff Moyer)
- fix sg driver race between cmd completion and close (Tom Coughlan)
- prevent e100 data corruption from v.3.0.27-k2 update (John Linville)
- upgrade SATA support (core, libata, new/old drivers) (John Linville)
- implement diskdump support for sym53c8xx adapter (Yuichi Nagahama)
- add USB support for Wacom Cintiq/Intuos3 tablets (Kristian Hgsberg)

* Wed Feb  9 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-27.12.EL
- update e100 network driver to version 3.3.6-k2 (John Linville)
- correct cpu id macro for dual-core Opteron support (Jim Paradis)
- add "numa=off" message on x86_64 OOM kills w/NUMA (Larry Woodman)
- improve user/system timer tick accounting on s390,x (Pete Zaitcev)
- prevent EAGAIN errs from interrupted TCP recv() calls (Dave Miller)
- update cciss disk driver to version v2.4.54.RH1 (Adam Manthei)
- eliminate diskdump cpu id from frozen list (Nobuhiro Tachino)
- fix user-space access bug in USB vicam ioctl (Pete Zaitcev)

* Thu Feb  3 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-27.11.EL
- incorporate Emulex driver ioctl module version 1.0.13 (Tom Coughlan)
- eliminate potential call_lock deadlock with diskdump (Tatsuo Uchida)
- fix potential kiobuf_lock deadlock in free_kiovec() (Larry Woodman)
- add L2 cache descriptor for EM64T Irwindale processor (Neil Horman)
- prevent mmap() syscalls from choosing NULL mappings (Rik van Riel)
- include bounce buffer pages in show_mem() output (Larry Woodman)
- add I2C driver support for ICH5 in i2c-i801.c (John Linville)
- correct parport_pc errors on insmod failures (Ernie Petrides)

* Fri Jan 28 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-27.10.EL
- fix futex_wait() race condition that allowed app hang (Ingo Molnar)
- add/correct write barrier placement in timer routines (David Howells)
- add x86_64 NMI switch support to debug kernel hangs (Yuichi Nagahama)
- restore CIV/LVI offset operation in i810_audio driver (John Linville)
- update e1000 network driver to version 5.6.10.1-k2 (John Linville)
- prevent bogus BUG_ON during multi-threaded core dump (Roland McGrath)
- fix x86_64 crash in huge_page_release() w/SHM_HUGETLB (Larry Woodman)
- fix possible mem corruption from /proc/kcore access (Ernie Petrides)

* Tue Jan 25 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-27.9.EL
- fix core dumping over NFS mounts with "intr" option (Roland McGrath)
- prevent multi-threaded app hang from sys_wait4() race (Ingo Molnar)
- restore e1000 support for Intel PCI device id 1014 (John Linville)
- add ac97 quirk entries for HP xw6000/xw6200/xw8000 (John Linville)
- update b44 network driver to upstream version 0.95 (John Linville)
- revert NFS silly-delete and rpciod-hang patches (Steve Dickson)
- fix panics while backing up LVM snapshots (Heinz Mauelshagen)
- fix oops in redirect_target() on DHCP refresh (Neil Horman)

* Fri Jan 14 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-27.8.EL
- rework ia64 INIT switch stacks for clean tracebacks (Tatsuo Uchida)
- fix USB raced timeout errors and ohci_complete_add() (Pete Zaitcev)
- add O_DIRECT handling in LVM driver handling (Heinz Mauelshagen)
- downgrade wait4() SIGCHLD/SIG_IGN warning message (Ingo Molnar)
- eliminate potential VMA list races with do_brk() (Dave Anderson)
- ignore ICMP Source Quench messages in tcp_v4_err() (Dave Miller)
- prevent VMA overlap crashes in insert_vm_struct() (Jason Baron)
- move flock() avoidance from NFS up to F/S layer (Steve Dickson)

* Tue Jan 11 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-27.7.EL
- fix 32-compat alt-stack signal handling on x86_64 (Geoff Gustafson)
- add initialization of ppc64 EEH error buffer size (David Howells)
- make ppc64 xmon work properly with Power5 console (David Howells)
- prevent infinite sync loop from NFS ESTALE writes (Steve Dickson)
- update 8139too network driver w/recent 2.4 fixes (John Linville)
- avoid netfilter oops when ip_conntrack is unloaded (Dave Miller)
- fix potential rpciod hangs during NFS sillydelete (Steve Dickson)
- avoid "No locks available" errors w/flock() on NFS (Ken Preslan)

* Wed Jan  5 2005 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-27.6.EL
- fix x86 phys proc ids for non-clustered APIC systems (Geoff Gustafson)
- return EINVAL on e100/e1000 rx-mini/rx-jumbo settings (John Linville)
- fix i810_audio regression from modified ICH6 PCI ids (John Linville)
- prevent race conditions in add_wait_queue_cond() macros (Jeff Moyer)
- fix FAT32 file system corruption w/writing 8M files (Alexander Viro)
- fix derivation/presentation of PHB unit ids on ppc64 (David Howells)
- close OpenFirmware stdin device at boot on ppc64 (David Woodhouse)
- fix 32-bit-compat regression in CMSG validations (Ernie Petrides)

* Thu Dec 23 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-27.5.EL
- add "CommitLimit" data to /proc/meminfo output (Frank Hirtz)
- allow autofs to expire mounts on ppc64 arch (Jeff Moyer)
- add 3c59x EEPROM_RESET for 3c900 Boomerang (John Linville)
- ignore PTE mapping status in page_anon() (Larry Woodman)
- fix SIOCGIFHWADDR handling for zero addr_len (Dave Miller)
- add netdump support for x86_64, ia64, ppc64 (Dave Anderson)
- correct overcommit accounting on fork failure (Frank Hirtz)
- raise default ia64/ia32e swiotlb size to 64M (Larry Woodman)

* Wed Dec 22 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-27.4.EL
- add network CMSG validation checks (Dave Miller)
- fix data struct leak in ip_options_get() (Dave Miller)
- fix IGMP vulnerabilities in ip[6]_mc_source() (Dave Miller)
- fix e_phnum binfmt_elf loader vulnerability (Dave Anderson)
- clean x86_64 32-bit-compat syscall numbers (Jim Paradis)
- prevent ia64 floating point reg val leakage (Jason Baron)
- add USB io_edgeport driver size check (Peter Martuccelli)
- enable softirq deferral for x86_64 arch (Neil Horman)

* Thu Dec  9 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-27.3.EL
- add data/param length sanity checks in smbfs (Alexander Viro)
- prevent /proc/<PID>/cmdline env data disclosure (Dave Anderson)
- make tulip_stop_rxtx() wait for DMA termination (John Linville)
- fix mm_stat regression introduced in -20.13.EL (Rik van Riel)
- correct return value from vlan_dev_change_mtu() (John Linville)
- serialize datagram read w/appropriate semaphore (Dave Miller)
- fix keyboard regression introduced in -24.EL (Peter Martuccelli)
- enable mmap/mprotect PROT_EXEC for legacy apps (Ernie Petrides)

* Mon Nov 29 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-26.2.EL
- fix USB problems with keyboards and ia64 oopses (Pete Zaitcev)
- add i810 PCI IDs for nforce3/CK804 audio devices (Jim Paradis)
- fix ppc64 viodasd driver dev naming/limit bugs (David Howells)
- prevent tg3 fiber link bounces w/auto-negotiation (Dave Miller)
- add ac97 quirk handling for i810_audio driver (John Linville)
- prevent incorrect OOM killing with iscsi usage (Larry Woodman)
- create kiobuf cache to reduce lowmem contention (Larry Woodman)
- fix yet another binfmt_elf loader vulnerability (Dave Anderson)

* Mon Nov 15 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-25.1.EL
- (this is the first build for RHEL 3 Update 5)
- implement open() recovery from NFS ESTALE errors (Neil Horman)
- clean up warnings from lpfc and lpfc_703 Makefiles (Tom Coughlan)
- fix nessus-induced kernel panic with auditing (Peter Martuccelli)
- update 3c59x driver to LK1.1.18 and fix reset bug (John Linville)
- fix ext3 O_DIRECT bug in orphan list handling (Stephen Tweedie)
- flush cached dirty pages on NFS reads w/O_DIRECT (Steve Dickson)
- allow ia64 kernel unaligned access msg suppression (Neil Horman)
- correct test for performing buffer-head reclaim (Larry Woodman)

* Fri Nov 12 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-25.EL
- fix binfmt_elf loader vulnerabilities (Jim Paradis, Dave Anderson)
- limit kernel data struct slabs to single-page allocs (Larry Woodman)
- update Emulex driver to 7.1.14 (backup still 7.0.3) (Tom Coughlan)

* Wed Nov 10 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-24.EL
- fix several ppc64 problems with signal catching (David Woodhouse)
- fix several bugs in /proc/ppc64/lparcfg driver (David Howells)
- fix possible diskdump hangs w/megaraid2 driver (Tatsuo Uchida)
- add support for IBM EM64T-based Groucho blade (Peter Martuccelli)
- fix regression in USB BIOS->kernel hand-off support (Pete Zaitcev)
- fix regression in ia64 kernel stack unwind handling (Don Howard)
- fix regression w/agpgart support of i8xx chipsets (Larry Woodman)
- add support for BLKSSZGET ioctl in cciss driver (Tom Coughlan)
- disable iSCSI builds in ppc64 and s390* configs (Tom Coughlan)
- update Emulex driver to 7.1.13 (backup still 7.0.3) (Tom Coughlan)
- correct SCSI whitelist for Chaparral FR1422 devices (Tom Coughlan)

* Thu Oct 28 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-23.EL
- prevent kswapd from getting stuck in prune_icache() (Larry Woodman)
- fix ppc64 single-stepping into signal handlers (David Woodhouse)
- fix corruption from user stack expansion races (Rik van Riel)

* Mon Oct 18 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-22.EL
- prevent add/removal races in SCSI open handling (Doug Ledford)
- fix U3 agpgart regression with Intel i8xx chipsets (Dave Jones)
- update SCSI whitelist for IBM 1722/1724 devices (Tom Coughlan)
- correct TSS descriptor limit checking for x86_64 (Jim Paradis)
- add nforce3/CK804 device support and fix ACPI bug (Jim Paradis)
- add support for "forcedeth" net driver version 0.28 (Jim Paradis)
- enable diskdump support in amd64/ia32e configs (Nobuhiro Tachino)
- restore/improve linux-2.4.21-ia64-fancyiommu.patch (Larry Woodman)
- add missing page_cache_release() in launder_page() (Larry Woodman)
- update Emulex driver to 7.1.11 (backup still 7.0.3) (Tom Coughlan)
- add new USB ids to support latest Wacom tablets (Kristian Hgsberg)
- remove drivers/net/tun.o from unsupported list (Peter Martuccelli)

* Thu Sep 30 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-21.EL
- fix potential PTE race in do_anonymous_page() (Rik van Riel)
- add "Committed_AS" data to /proc/meminfo output (Frank Hirtz)
- revise DMA zone paging thresholds for x86_64 (Larry Woodman)
- prevent /proc/scsi/scsi oops during probes (David Woodhouse)
- avoid kswapd hangs via free_more_memory() hooks (Rik van Riel)
- update megaraid2 driver to 2.10.8.2 w/2.10.6 backup (Adam Manthei)
- fix do_notify_parent() panic from ptrace death race (Roland McGrath)
- fix large core file support on 64-bit architectures (Dave Anderson)
- enable tux on ia64 and increase max tux threads to 16 (Ingo Molnar)
- fix ia64/s390,x single-stepping w/signal handlers (David Woodhouse)

* Wed Sep 29 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-20.14.EL
- fix hang in SCSI starvation management code (David Howells)
- update SCSI whitelist for NETAPP LUN devices (Wendy Cheng)
- fix s390 cio handling during ESS fail-overs (Pete Zaitcev)
- update Emulex driver to 7.1.8 w/7.0.3 backup (Tom Coughlan)
- update Qlogic driver to 7.01.01 w/7.00.03 backup (Tom Coughlan)
- correct unlock/free order in proc_lookupfd() (Ernie Petrides)
- use ACPI for PCI interrupt routing on ia32e (Jim Paradis)
- allow cpus to boot w/APIC IDs > 8 on ia32e (Jim Paradis)
- fix pid allocation when pid_max > 32768 (Ernie Petrides)
- fix regs in multi-threaded ia64 core dumps (Keiichi Mori)
- enable sym53c8xx driver for ppc64 iSeries (David Howells)
- fix ac97 depmod errors w/hugemem configs (John Linville)

* Tue Sep 28 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-20.13.EL
- fix aic79xx_osm.h/3c59x.c changes in prior rev (Tachino/Linville)
- allow for larger nfsd block sizes on some archs (Steve Dickson)
- fix possible aacraid driver panic in aac_info() (Tom Coughlan)
- fix xdr argsize check to handle writes >= 2^31 (Steve Dickson)
- update e1000 network driver to version 5.3.19-k2 (John Linville)
- apply several cciss driver fixes (to 2.4.52.RH2) (Adam Manthei)
- fix x86_64 versions of cpu capability test macros (Jim Paradis)
- fix ppc64 HPTE memory corruption race condition (Rik van Riel)
- add sys_epoll support on s390,x (Stephen Tweedie, Pete Zaitcev)
- prevent keyboard.c warnings from mouse clicks (Norm Murray)

* Mon Sep 27 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-20.12.EL
- improve slab cache page reaping heuristics (Larry Woodman)
- implement diskdump support for x86_64 arch (Nobuhiro Tachino)
- add ia64 INIT trigger switch support for debugging (Tatsuo Uchida)
- fix several problems in handling of AIO on pipes (Jeff Moyer)
- update fixes for LTP read02 test hangs with tmpfs (Alexander Viro)
- fix x86_64 single-stepping out of signal handlers (Jim Paradis)
- increase size of ppc64 RTAS error log buffer (David Howells)
- increase max possible kNFSD lockd cookie size (Steve Dickson)
- backport 3c59x fixes for mii-tool problems w/10Mb (John Linville)
- incorporate Cisco's iscsi_sfnet initiator driver (Tom Coughlan)

* Thu Sep 23 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-20.11.EL
- implement diskdump support for megaraid2 adapter (Tatsuo Uchida)
- update ips driver to version 7.10.18 w/7.00.15 backup (Tom Coughlan)
- correct max page aging interval boundary in kscand() (Larry Woodman)
- add ppc64 support for ptrace() with PT_SINGLESTEP (David Woodhouse)
- update e100 network driver to version 3.0.27-k2 (John Linville)
- fix LTP read02 test hangs when tmpfs is in use (Alexander Viro)
- get proc_dir_entry reference in proc_lookup() (Alexander Viro)
- add exports of several AIO-related interfaces (Larry Woodman)
- reduce swapping during excessive pagecache use (Larry Woodman)
- implement statfs64() syscall on x86 for NFS use (Rik van Riel)

* Wed Sep 22 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-20.10.EL
- implement early USB hand-off (BIOS->kernel) support (Pete Zaitcev)
- fix stack pointer calculation in x86 show() handling (Jeff Moyer)
- prevent interference between flock/POSIX lock types (Frank Hirtz)
- update pcnet32 network driver to version 1.30c (John Linville)
- add export of block_commit_write() f/s interface (Larry Woodman)
- implement diskdump support for dpt_i2o adapter (Tatsuo Uchida)
- update mptfusion driver to version 2.05.16.02 (Adam Manthei)
- move disk_dump_notifier_list to diskdumplib.c (Nobuhiro Tachino)
- update s390 zfcp driver to revision 5.31.2.11+ (Pete Zaitcev)

* Mon Sep 20 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-20.9.EL
- fix occasional ibmvscsic driver insmod crash (David Howells)
- disable linux-2.4.21-ia64-fancyiommu.patch (Larry Woodman)
- prevent double slashes in symlink auditing (Peter Martuccelli)
- fix overzealous compat32 setsockopt conversions (David Woodhouse)
- backport tulip driver fixes from upstream 2.4.28 (John Linville)
- update tg3 network driver to version 3.10RH (John Linville)
- implement sysctl to force igmp protocol versions (Neil Horman)
- add diskdump performance improvement info (Nobuhiro Tachino)
- fix s390 iucv lost connections and ping hangs (Pete Zaitcev)

* Sun Sep 19 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-20.8.EL
- prevent diskdump deadlock in case of die() recursion (Tatsuo Uchida)
- add x86/x86_64 support for ptrace() w/PT_SINGLESTEP (Roland McGrath)
- fix x86/x86_64 single-stepping into signal handlers (Roland McGrath)
- increase x86 value for MAX_MP_BUSSES definition to 260 (Ingo Molnar)
- eliminate ia64 potential for scheduler runq deadlock (Larry Woodman)
- add support for /proc/sys/kernel/mem_nmi_panic sysctl (Dave Anderson)
- prevent keyboard-initiated sysrq hangs in handle_sysrq() (Jeff Moyer)
- fix intermittent netdump hangs from cpu-frozen messages (Jeff Moyer)

* Fri Sep 17 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-20.7.EL
- fix premature OOM killing change added in prior rev (Larry Woodman)
- backport vlan driver fixes from upstream 2.4.28-rc1 (John Linville)
- add _sb_findmap symbol export in s390/s390x kernels (Pete Zaitcev)
- add ppc64 support for 32-bit sendfile64() syscall (David Howells)
- fix 32-bit IPC_INFO shmctl() syscalls for ppc64 (David Howells)
- upgrade libata/SATA support to current 2.4 bits (John Linville)
- avoid USB device resets of shared/busy interfaces (Pete Zaitcev)
- fix miscellaneous problems in ppc64 icom driver (David Howells)
- fix ip_queue_maxlen sysctl for ip[6]_queue modules (Neil Horman)
- add module parm for max entries in NFS_ACL replies (Neil Horman)

* Tue Sep 14 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-20.6.EL
- prevent OOM killer from kicking in prematurely (Larry Woodman)
- avoid NMI watchdog crashes during sysrq-m usage (Wendy Cheng)
- add auditing support for ia64 clone2 syscall (Peter Martuccelli)
- correct sign of auditing error codes for ia64 (Peter Martuccelli)
- implement ia64 auditing 32-bit-disable sysctl (Peter Martuccelli)
- fix ia64 faults w/stale VHPT-generated TLB entries (Dave Anderson)
- fix invalid x86_64 checksums for multicast packets (Mike Gahagan)
- fix incorrect blocking bug inside wakeup_kswapd() (Larry Woodman)
- validate appropriate media type in DVD drives (Doug Ledford)
- reduce s390 stack usage in qeth/qdio drivers (Pete Zaitcev)

* Fri Sep 10 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-20.5.EL
- prevent scenarios that lead to hang of kswapd (Larry Woodman)
- add locking for access to /proc/bus/usb/devices (Pete Zaitcev)
- correct x86 rescheduling to handle apm=power-off (Ingo Molnar)
- fix OOM killer locking and mm referencing holes (Larry Woodman)
- pin ia64 mapping for idle proc stack during boot (Larry Woodman)
- fix warning throttle for amd64 stack overflow check (Neil Horman)
- fix content lengths when using tux gzip compression (Ingo Molnar)
- add auditing support for pread/pwrite syscalls (Peter Martuccelli)

* Thu Sep  9 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-20.4.EL
- prevent bogus data in /proc/scsi/ibmvscsi/* (David Howells)
- update tg3 network driver to version 3.9RH (John Linville)
- improve ramfs memory alloc w/scarce highmem (Larry Woodman)
- correct several values in /proc/ppc64/lparcfg (David Howells)
- allow dirty page rebalancing under mem pressure (Rik van Riel)
- prevent memory leak in scsi_build_commandblocks() (Doug Ledford)
- fix potential kswapd deadlock w/disk quota usage (Larry Woodman)
- increase MAX_IO_APICS from 8 to 32 for x86_64 arch (Jim Paradis)

* Fri Sep  3 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-20.3.EL
- fix various error path bugs in bcm5820 driver (John Linville)
- validate addresses used with /dev/kmem accesses (Neil Horman)
- eliminate IPSEC tunnel leaks when using IPComp (Dave Miller)
- add auditing support for utimes() syscalls (Peter Martuccelli)
- prevent netconsole freeze w/cable dis-/re-connect (Jeff Moyer)
- correct reboot_cpu validation for "reboot=s<n>" (Doug Ledford)
- fix mem/irq clean-up in olympic tokenring driver (Neil Horman)
- update network bonding driver to version 2.6.0 (John Linville)

* Wed Sep  1 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-20.2.EL
- add maps/rlimits output with print-fatal-signals=2 (Ingo Molnar)
- backport ac97 sound support from upstream 2.4.27 (John Linville)
- eliminate kernel stack data leaks from USB drivers (Mark Cox)
- fix interrupt status mask in AMD PCnet32 driver (David Howells)
- fix module loading problems in ibmvscsic driver (David Howells)
- fix x86 shared runq mapping when ACPI data is bad (Bernd Schmidt)
- disable enhanced error handling on PCI-ISA bridges (David Howells)
- add memory-mapped i/o support to i810_audio driver (John Linville)

* Mon Aug 30 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-20.1.EL
- (this is the first build for RHEL 3 Update 4)
- backport r8169 network driver changes from 2.4 (John Linville)
- update i810_audio sound driver to version 1.01 (John Linville)
- convert USB UHCI driver warning to debug message (Pete Zaitcev)
- backport 2.6 PROT_GROWSDOWN/UP mprotect() support (Jakub Jelinek)
- lower ppc64 console logging level of RTAS messages (David Howells)
- fix ppc64 handling of "smt-emabled=off" boot option (David Howells)
- correct socket sndbuf accounting w/IP_MULTICAST_LOOP (Neil Horman)
- reduce x86_64 user stack start randomization to 16K (Jim Paradis)

* Wed Aug 18 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-20.EL
- change TARGET_CPUS on x86_64 to include all on-line cpus (Jim Paradis)

* Thu Aug 12 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-19.EL
- fix possible races/overflows in file offset handling (Alexander Viro)
- correct logging of boot progress messages on Power5 (David Howells)
- extend ppc64 EEH support for other types of devices (David Howells)
- fix ibmveth driver to properly shut down and restart (David Howells)
- fix several races and overflows in ppc64 RTAS driver (David Howells)
- backport "acpi=noirq" support to work around Nocona hangs (Don Howard)
- conditionalize pbn_hp_diva to fix serial driver oops (Matthew Galgoci)
- add amd64 GART entry guard mappings for PCI mis-prefetch (Jim Paradis)
- upgrade SATA support again to resolve several problems (Jeff Garzik)
- qualify ia32e IRQ affinity disable with BIOS flag check (Jim Paradis)
- fix eeh_check_failure() on ppc64 to be interrupt safe (David Howells)
- correct ppc64 EEH macros to use appropriate data size (David Howells)
- fix x86/ia64 no-wait handling in smp_call_function() (Larry Woodman)
- fix "Filter target 0x203 not known ..." audit msgs (Peter Martuccelli)

* Wed Jul 21 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-18.EL
- prevent s390 mlock hangs with follow_page() rework (Ernie Petrides)
- fix Power5 initialization and handling of RAS IRQs (David Howells)
- fix ppc64 viocons driver deadlocks with printk() (David Howells)
- apply eh_timeout, netdump, cli fixes in diskdump (Tatsuo Uchida)
- add skip_mapped_pages tuning for page eviction (Stephen Tweedie)
- fix initrd's effect on ppc64 mem_end calculation (David Howells)
- allow HT support on ppc64 systems with single cpu (David Howells)
- backport v2.0.8 aic7xxx driver h/w support for Dell (Tom Coughlan)
- correct ppc64 device node searching in hvsi driver (David Howells)
- fix KMI compat problem w/pgprot_t in x86 NX support (Jim Paradis)
- resurrect mptfusion driver backup version 2.05.05 (Tom Coughlan)
- disable IRQ affinity setting on some ia32e systems (Jim Paradis)
- update SCSI whitelist for Dot Hill SANnet/StorEdge (Tom Coughlan)

* Thu Jul  8 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-17.EL
- account for zone holes in big hash table allocator (Stephen Tweedie)
- prevent reserved stack space overflow of mmap_top (Ernie Petrides)
- fix USB crash in scan_async() with EHCI hardware (Pete Zaitcev)

* Sat Jul  3 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-16.EL
- enable exec-shield and add x86 NX support (Ingo Molnar, Jim Paradis)

* Fri Jul  2 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.19.EL
- add owner check in inode_change_ok() for gid changes (Ernie Petrides)
- fix race in finish_task_switch() between wakeup/exit (Ernie Petrides)
- remove Samsung CD-ROM SN-124 from IDE DMA blacklist (Tom Coughlan)
- update e1000 network driver to version 5.2.52-k3 (John Linville)
- add auditing support for semtimedop syscalls (Peter Martuccelli)
- fix tasklet and locking bugs in Power5 hvsi driver (David Howells)
- fix megaraid2 handling of TUR cmds with SCSI CD-ROM (Adam Manthei)
- update SCSI whitelist for HP NS E1200-160 router (Tom Coughlan)
- prevent x86 read_ldt() from reading beyond kmap (Ernie Petrides)
- force single loadable segment in ia64 kernels (Jakub Jelinek)

* Fri Jun 25 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.18.EL
- implement ia64 work-around for TLB fetch timeout MCA (Larry Woodman)
- fix Power3 interrupt initialization in ppc64 setup (David Howells)
- correct info msg, prevent double panic in diskdump (Tatsuo Uchida)
- defend against NULL "mm" ptrs in page_referenced() (Rik van Riel)
- fix miscellaneous audit subsystem problems (Peter Martuccelli)
- prevent crash with tux CGI execution on x86_64 (Ingo Molnar)
- add installer info to SATA sx8 block driver (Jeff Garzik)
- turn on vary_io flag in SCSI ips driver (Tom Coughlan)

* Wed Jun 23 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.17.EL
- allocate big system hash tables w/bootmem allocator (David Howells)
- prevent loading aic7xxx_old when aic7xxx is in use (Doug Ledford)
- implement stat() recovery from NFS ESTALE errors (Steve Dickson)
- fix raw/O_DIRECT i/o bug with unmapped pages (Stephen Tweedie)
- correct another locking hole in RAID1 handling (Doug Ledford)
- fix __x86_64__ conditional in megaraid2.c driver (Adam Manthei)
- fix unresolved symbols on ia64 in cciss driver (Tom Coughlan)

* Tue Jun 22 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.16.EL
- make NFS sillydelete wait for unlink completion (Steve Dickson)
- prevent EIO w/concurrent O_DIRECT+buffered i/o (Stephen Tweedie)
- upgrade SATA support (core, libata, and drivers) (Jeff Garzik)
- implement futex() FUTEX_CMP_REQUEUE op (Al Viro, Pete Zaitcev)
- update b44 network driver to version 0.93 (John Linville)
- avoid unix_stream_sendmsg() ENOBUFS errors (Larry Woodman)

* Mon Jun 21 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.15.EL
- improve SCSI mid-layer error handling w/sdev_retry_q (Doug Ledford)
- eliminate rw-semaphore races between waiter/wakeup (David Howells)
- add locking and fix accounting bug in RAID1 handling (Doug Ledford)
- backport Carmel sx8.c driver from upstream 2.4 base (John Linville)
- rename ppc64-squadrons-* patches to ppc64-power5-* (Ernie Petrides)

* Sat Jun 19 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.14.EL
- introduce support for IBM Squadrons/Power5 systems (David Howells)
- update aacraid driver to 1.1.5-2339 w/1.1.2 backup (Adam Manthei)
- allow sys_remap_file_pages() on unlocked ramfs VMAs (Larry Woodman)
- fix diskdump hangs during resets with aic79xx driver (Tatsuo Uchida)
- fix possible data corruption when using SHM_HUGETLB (Larry Woodman)
- set QLogic HbaApiNode proc file permissions to 0600 (Tom Coughlan)
- add IRQ blocking/restoring in add_gendisk/del_gendisk (Jeff Needle)

* Thu Jun 17 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.13.EL
- fix problem causing PCI bus 255 to be missing on ia64 (Ben Woodard)
- make nfs_statfs() recognize/handle fs size overflows (Steve Dickson)
- update QLogic driver to 7.00.03-RH1 w/6.07.02 backup (Tom Coughlan)
- allow procfs to utilize more dynamic inode numbers (David Howells)
- prevent inappropriate "unexpected IO-APIC" messages (Ernie Petrides)
- avoid lost dirty page bits in s390/s390x VM handling (Pete Zaitcev)
- fix ACPI SCI interrupt defaults and add kernel params (Jim Paradis)
- fix user-space access bugs in acpi/airo/decnet/sound (Alexander Viro)
- remove drivers/net/starfire.o from unsupported list (Ernie Petrides)
- fix mm_struct mem leak in copy_process() error path (Ernie Petrides)

* Tue Jun 15 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.12.EL
- correct s390/s390x tests for PT_AUDITED flag (Peter Martuccelli)
- update e100 network driver to version 2.3.43-k1 (John Linville)
- update megaraid2 driver to 2.10.6 w/2.10.1.1 backup (Adam Manthei)
- add x86_64 auditing support for 32-bit-compat (Peter Martuccelli)
- fix ia64 unwind handling for UNW_INSN_SETNAT_MEMSTK (Jason Baron)
- update cciss driver to v2.4.52 for several fixes (Tom Coughlan)
- fix variable block mode tape handling in st driver (Tom Coughlan)
- incorporate latest Emulex fibre channel driver (Tom Coughlan)
- fix USB EHCI problem with BIOS-to-host handoff (Pete Zaitcev)
- update SCSI whitelist for DDN/Xyratex/SanDisk/CBOX3 (Tom Coughlan)

* Mon Jun 14 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.11.EL
- upgrade to latest autofs4, remove from unsupported list (Jeff Moyer)
- fix memory corruption bug in audit driver code (Peter Martuccelli)
- store adjusted KSP value in ia64 diskdump support (Tatsuo Uchida)
- update e1000 network driver to version 5.2.52-k1 (John Linville)
- update ips driver to version 7.00.15 w/6.11.07 backup (Adam Manthei)
- implement USB device interlock between ioctls/SCSI-ops (Pete Zaitcev)
- update tg3 driver to version 3.6RH for upcoming chipsets (Dave Miller)
- downgrade several PCI cache line size debugging messages (Jim Paradis)
- correct x86_64 32-bit-compat support for AIO syscalls (Jeff Moyer)
- prevent FPU exception handling hangs on x86/x86_64 (Ernie Petrides)

* Fri Jun 11 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.10.EL
- give wait.func highest priority in wake_up_filtered() (Larry Woodman)
- reduce system time when using sys_remap_file_pages() (Larry Woodman)
- enable CONFIG_SOFT_WATCHDOG module for ppc64 configs (David Howells)
- improve page allocation to avoid unnecessary swapping (Rik van Riel)
- implement diskdump support for ia64 with mptfusion (Tatsuo Uchida)
- disable native ia32 support for ia64 Montecito cpus (Jason Baron)
- save/restore P4/ia32e perf registers for oprofile (Will Cohen)
- fix oprofile ESCR_SET_EVENT_SELECT() event mask (Will Cohen)

* Wed Jun  9 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.9.EL
- update s390 zcrypt driver to version 1.2.1 (Pete Zaitcev)
- update network tg3 driver to version 3.5RH (Dave Miller)
- eliminate separate ia32e oprofile processor id (Will Cohen)
- update SCSI whitelist for IBM 2105/2145 devs (Doug Ledford)
- avoid EAGAIN errors on blocking UDP sockets (Steve Dickson)
- avoid putting locked inodes on dirty list (Steve Dickson)

* Tue Jun  8 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.8.EL
- decouple NFS O_DIRECT handling for performance gain (Steve Dickson)
- export page_is_ram() interface for amd64/ia32e arch (Jim Paradis)
- enable CONFIG_SCSI_SATA_* options in x86_64 configs (Jim Paradis)
- update mptfusion driver to 2.05.16 w/2.05.11.03 backup (Adam Manthei)
- fix nopage_sequential_readahead() and filemap_sync() (Larry Woodman)
- fix USB EHCI driver to avoid Squadrons install oops (Pete Zaitcev)
- add x86 NMI trigger switch support for debugging (Yuichi Nagahama)
- add dmi_blacklist[] entry for "Intel NA440BX DP" (Doug Ledford)

* Mon Jun  7 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.7.EL
- apply some minor scsi_dump_status() format tweaks (Doug Ledford)
- implement SCSI support for dynamic add (hot plug) (Doug Ledford)
- upgrade lvm driver logic to version 1.0.8-2 (Heinz Mauelshagen)
- fix x86_64 definition for inlined ffs() function (Jim Paradis)
- preserve VM_MAYEXEC for executable stack support (Jim Paradis)
- add extra SLBIEs for ppc64 Power5 DD2.0 errata (David Howells)
- add ppc64 32-bit compat for TIOCGICOUNT/MIWAIT (David Howells)
- hold file struct ref when removing POSIX locks (Steve Dickson)
- fix window scaling bug in tcp_ack_update_window() (Dave Miller)

* Fri Jun  4 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.6.EL
- make fsync() flush all pending NFS updates to disk (Steve Dickson)
- complete ia64 support for multiple I/O port spaces (Larry Woodman)
- fix sending of IP broadcast frames with TTL of zero (Neil Horman)
- prevent context switch storms under high VM loads (Larry Woodman)
- fix sigaltstack() errors w/JVM on hugemem kernels (Roland McGrath)
- add locking and improve output in scsi_dump_status() (Doug Ledford)
- add size boundary checking in scsi_resize_dma_pool() (Doug Ledford)
- fix SCSI request struct leak on command init failures (Doug Ledford)

* Fri May 14 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.5.EL
- overhaul ia64 SAL/MCA subsystem (Ben Woodard)
- enable x86_64 32-bit UID support (Jim Paradis)
- add initial diskdump support (Nobuhiro Tachino)

* Wed May 12 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.4.EL
- reduce chance of "VFS: Busy inodes after unmount." errs (Steve Dickson)
- convert "uaddr2" arg ptr in s390x futex() compat syscall (Pete Zaitcev)
- add ppc64 32-bit compat handler for PE_LOCKED_COPY ioctl (David Howells)
- update s390 dasd driver with several recent bug fixes (Pete Zaitcev)
- fix amd64 NUMA node scanning for Northbridge systems (Jim Paradis)

* Mon May 10 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.3.EL
- prevent exp_stopfodrop() oops during cluster failover (Steve Dickson)
- make nfs_file_commit() always flush the entire file (Steve Dickson)
- fix pcnet32 driver's MAC address selection on ppc64 (Julie DeWandel)
- backport /dev/random driver fixes for missed wakeups (Mark DeWandel)
- fix hang w/SoundBlaster 16-bit sampling w/odd count (Ernie Petrides)
- make s390 tape driver specify GPL module license type (Pete Zaitcev)
- correct buffer len value in ppc64 pSeries ipr driver (David Howells)

* Tue May  4 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.2.EL
- enable booting on 8-way Opteron systems (Jim Paradis)
- fix 32-bit-compat truncate64() on x86_64 (Jim Paradis)
- correct promiscuous mode counter handling (Dave Miller)
- support 128-GB ia64 systems w/HP zx1 chipset (Larry Woodman)
- add export of sys_ioctl() global symbol on s390x (Pete Zaitcev)

* Mon May  3 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.1.EL
- (this is the first build for RHEL 3 Update 3)
- reenable/fix linux-2.4.21-ppc64-pte-hash-lock.patch (Julie DeWandel)
- clean up file locks when NFS clients receive signals (Steve Dickson)
- complete ia64-specific LAuS syscall auditing support (Mark DeWandel)
- prevent NULL pointer dereference in page_referenced() (Rik van Riel)
- fix max sectors argument in lvm_snapshot_alloc() (Heinz Mauelshagen)
- allow AGP bus scanning to execute for all architectures (John Dennis)
- fix page_referenced() rss limit checks w/unmapped pages (Rik van Riel)
- correct locking and cr/lf problems in usbserial driver (Pete Zaitcev)
- add /proc/cpuinfo support for new ppc64 processors (Julie DeWandel)
- fix sense data handling on certain SCSI cmd retries (Doug Ledford)

* Wed Apr 21 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.EL
- fix clobbering of /proc/cpuinfo vendor_id on x86_64 (Jim Paradis)
- correct MCAST_MSFILTER/IP_MSFILTER size checking (Ernie Petrides)

* Wed Apr 14 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-14.EL
- disable linux-2.4.21-ppc64-pte-hash-lock.patch (Julie DeWandel)
- prevent symlink buffer overflow in ISO-9660 fs (Ernie Petrides)
- check for skb overrun in IPV4/IPV6 IGMP handling (Dave Miller)
- fix possible hang in rebalance_laundry_zone() (Larry Woodman)
- correct zone_wired[] initialization for NUMA (Jim Paradis)

* Wed Apr  7 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-13.EL
- fix several critical libata bugs (Jeff Garzik)
- correct IPSEC XFRM policy ref counting (Dave Miller)
- add amd64/ia32e parsing for "acpi=off" arg (Jim Paradis)
- update tg3 driver to v3.1 for several fixes (Dave Miller)
- fix SCSI whitelist for Hitachi/HP DFx00, Apple Xserve (Tom Coughlan)

* Fri Mar 26 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-12.EL
- add USB support for Handspring Treo 600 PDA syncing (Matthew Galgoci)
- clear state for CPEs during ia64 MCA SAL error logging (Ben Woodard)
- prevent DMA resource leak in QLogic driver error path (Tom Coughlan)
- change default QLogic driver device queue depth to 64 (Tom Coughlan)
- replace fabricated cciss drive geometry w/ENXIO error (Tom Coughlan)
- update SCSI whitelist for HP SureStore/StorageWorks (Tom Coughlan)
- disable CONFIG_ACPI_DEBUG in amd64/ia32e configs (Jim Paradis)

* Mon Mar  8 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-11.EL
- add yet another Intel ICH6 SATA PCI id (Jeff Garzik)
- fix ref counting in copy_process() error path (Larry Woodman)
- remove ia64 support for /proc/bus/mckinley/bitmap (Jason Baron)
- correct depmod versioning for unsupported modules (Ernie Petrides)
- prevent data corruption in ia32e phys_proc_id[] info (Larry Woodman)
- change default value for inactive_clean_percent to 30 (Larry Woodman)
- enable improved version of s390 on-demand timer patch (Pete Zaitcev)

* Tue Mar  2 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-10.EL
- incorporate late-breaking libata fixes (Jeff Garzik)
- enable amd64 syscall for tux support (Ingo Molnar)

* Mon Mar  1 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.17.EL
- reduce s390 idle overhead with on-demand timer patch (Pete Zaitcev)
- complete ia64 NPTL support for 32-bit-EL executables (Jason Baron)
- add several ia64 syscall table entries for 32-bit-EL (Jason Baron)
- upgrade libata/SATA support, delete ich5-sata.patch (Jeff Garzik)
- check for mremap/vmtruncate race in move_one_page() (Jason Baron)
- prevent ia64 NaT-bit corruption during sig catching (Jason Baron)
- fix amd64 get_mtrr() parsing error with >4GB memory (Jim Paradis)
- change amd64 default behavior to avoid TSC timer use (Jim Paradis)
- force s390utils upgrade to prevent zipl seg fault (Ernie Petrides)

* Sun Feb 29 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.16.EL
- restore varyio capability in mptfusion driver update (Adam Manthei)
- enhance SCSI mid-layer queuing for indefinite retries (Doug Ledford)
- add ia64 reg reloads for 32-bit-EL strace -f support (Jason Baron)
- fix ia64 core dump support for 32-bit-EL executables (Jason Baron)
- add SCSI whitelist devs with BLIST_RETRY_ABORTED_CMD (Doug Ledford)
- remove stack-in-interpreter check in binfmt_elf.c (Julie DeWandel)
- clear all flags in exec_usermodehelper() for kmod (Alexander Viro)
- fix aacraid command completion (rq corruption) bugs (Tom Coughlan)
- correct cciss_proc_tape_report() type in flags decl (Tom Coughlan)
- enable USB-2.0-hub-based mice/keyboards to function (Pete Zaitcev)

* Sat Feb 28 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.15.EL
- fix amd64 oprofile linkage problem in ia32e support (Ernie Petrides)
- update ips driver to version 6.11.07 w/6.10.52 backup (Tom Coughlan)
- add size checks to DRM ATI r128 driver ioctl handling (John Dennis)
- avoid megaraid2 irq_disable calls for mem-mapped ctlrs (Tom Coughlan)
- upgrade firmware imbedded in QLogic driver to 3.02.24 (Tom Coughlan)
- correct ia64 memory accounting in overcommit mode 2 (Larry Woodman)
- implement softirq deferral to limit kernel stack depth (Ingo Molnar)
- reduce kernel stack usage in a couple of tux functions (Ingo Molnar)
- fix shared extended attribute ref counting in ext3 (Stephen Tweedie)
- clear SCSI sense data buffer between eh retries (Doug Ledford)

* Thu Feb 26 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.14.EL
- add .RH1 suffix to cciss driver version v2.4.50 (Tom Coughlan)
- implement initial LAuS syscall auditing support (Mark DeWandel)
- introduce GFS enablers for locking and sendfile ops (Ken Preslan)
- update QLogic driver to 6.07.01 w/6.06.00b11 backup (Tom Coughlan)
- improve netdump reliability w/asynchronous IPI param (Jeff Moyer)
- add ICH6 DSP audio support to i810_audio driver (Jeff Garzik)
- apply SCSI whitelist updates for several devices (Tom Coughlan)
- fix odd byte tape i/o handling in sym53c8xx driver (Tom Coughlan)
- correct minimum nfsd version that supports acls (Steve Dickson)

* Wed Feb 25 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.13.EL
- allow concurrent NFS direct i/o to same file if !append (Steve Dickson)
- introduce support for new Intel 64-bit ia32e processor (Larry Woodman)
- update mptfusion driver to 2.05.11.03 w/2.05.05 backup (Adam Manthei)
- remove fs/binfmt_misc.o from linux-modules-unsupported (Jason Baron)
- fix ia64 predicate register use in sig trampoline code (Jason Baron)
- add oprofile cpu type recognition for ia32e processor (Will Cohen)
- update e1000 network driver to version 5.2.30.1-k1 (Jeff Garzik)
- add more Intel PCI ids to match upstream 2.4 (Jeff Garzik)
- add ICH6 PATA support, PCI ids, irq routing (Jeff Garzik)

* Mon Feb 23 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.12.EL
- add deferred page freeing for intr-context unmap_kvec() (Jeff Moyer)
- update megaraid2 driver to v2.10.1.1 w/v2.00.9 backup (Tom Coughlan)
- fix ppc64 pte hash table locking to avoid deadlocks (Julie DeWandel)
- fix ia64 data TLB init to prevent random boot-up hangs (Jason Baron)
- fix ia64 RNat register corruption with alt sig stacks (Jason Baron)
- allow smaller ia64 sig stacks in ia32 emulation layer (Jason Baron)
- backport ncpfs fixes to eliminate var-length arrays (Jeff Moyer)

* Fri Feb 20 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.11.EL
- backport cisco aironet driver from 2.6.3-rc4 (Matthew Galgoci)
- update tg3 driver to v2.7 to fix status reg handling (Dave Miller)
- correct lost jiffies logic for x440/5 cyclone timer (Bernd Schmidt)
- fix open() error clean-up for unsupported O_DIRECT (Stephen Tweedie)
- prevent ia64 crashes when unmapping hugetlb pages (Jason Baron)
- add ppc64 processor support for future PPC970+ (Julie DeWandel)
- rework ppc64 32-bit-compat iptables support (Julie DeWandel)
- fix func ptr test in ethtool_set_ringparam() (Jeff Garzik)
- disable linux-2.4.21-scsi-affine-queue.patch (Doug Ledford)
- improve scsi_allow_ghost_devices description (Doug Ledford)

* Wed Feb 18 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.10.EL
- fix amd64 iommu bug causing data corruption on >4GB systems (Jim Paradis)
- return EINVAL for unsupported ioctl32 syscalls on ppc64 (Julie DeWandel)
- remove incorrect BUG() call in __remove_inode_page() (Stephen Tweedie)
- fix s390 ctc driver problem causing build system hangs (Pete Zaitcev)
- fix s390 qeth driver error path to reset write_busy (Pete Zaitcev)
- update s390 zfcp driver to fix miscellaneous bugs (Pete Zaitcev)
- apply upstream nfs fixes for acl error handling (Steve Dickson)
- prevent kernel stack data leak via /dev/rtc (Ernie Petrides)
- allow AIO operations on sockets for non-inet (Dave Miller)

* Mon Feb 16 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.9.EL
- restore genksyms_smp_prefix setting for non-x86 builds (Ernie Petrides)
- display/log memory stats whenever there's an OOM kill (Larry Woodman)
- update tg3 driver to v2.6, the latest upstream version (Jeff Garzik)
- update net bonding driver to v2.4.1, latest upstream (Jeff Garzik)
- fix irq, mem, printk, strtol bugs in cciss driver (Tom Coughlan)
- wait for board ready after hot add, cciss driver (Tom Coughlan)
- enable cciss adapter prefetch for x86 platforms (Tom Coughlan)
- add preserve_arg0 handling for ia32 emulation (Larry Woodman)
- fix ppc64 compat support for quota syscall (Julie DeWandel)

* Thu Feb 12 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.8.EL
- remove Power-Blade-specific def for USB TEAC floppy (Julie DeWandel)
- fix s390 crash in iucv driver on connection shutdown (Pete Zaitcev)
- fix ia64 ACPI parsing for multinode IDE devs on x455 (Jim Paradis)
- fix amd64 core dumping of multithreaded 32-bit apps (Jim Paradis)
- fix s390 oprofile conditional and zero top addr bits (Will Cohen)
- add ipr driver v1.0.3 for IBM's PPC RAID adapters (Tom Coughlan)
- add {alloc,free}_netdev(), list macro, tg3 PCI ids (Jeff Garzik)

* Tue Feb 10 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.7.EL
- restrict /proc/tty/driver directory access to root (Jeff Moyer)
- allow non-standard usr/sys VM splits at 2G/2G, 1G/3G (Ingo Molnar)
- extend existing ppc64 RTAS firmware flash interface (Mark DeWandel)
- fix ppc64 version of strncpy() to zero-pad buffers (Julie DeWandel)
- fix s390/x version of strncpy() to zero-pad buffers (Pete Zaitcev)
- fix generic version of strncpy() to zero-pad buffers (Jim Paradis)
- improve ppc64 segment table entry replacement logic (Julie DeWandel)
- correct type/cast of "len" in ppc64/kernel/nvram.c (Julie DeWandel)
- implement new ppc64 RTAS system call interface (Julie DeWandel)
- increase x86 RSDT table limit in ACPI parsing (Jim Paradis)

* Mon Feb  9 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.6.EL
- fix more usb-storage bugs for Power Blade support (Julie DeWandel)
- remove extra inactive_clean_pages-- in reclaim_page() (Larry Woodman)
- return proper error codes for do_munmap() failure in mremap (Dave Jones)
- fix binfmt_elf.c problems for apps with huge bss regions (Julie DeWandel)
- update cciss driver to v2.4.50 for Smart Array 6i support (Tom Coughlan)

* Thu Feb  5 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.5.EL
- prevent netdump progress output from filling up log_buf (Jeff Moyer)
- add ppc64 RAS hook at end of panic() processing (Julie DeWandel)
- correct source IP address in ICMP error message (Dave Miller)
- fix smp deadlock with pdeath_signal posting (Roland McGrath)
- add ppc64 support for /proc/ppc64/lparcfg (Julie DeWandel)

* Wed Feb  4 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.4.EL
- update nfsd mode-with-acls fix for upstream conformance (Steve Dickson)
- rework usb-storage locking to avoid hangs on disconnect (Pete Zaitcev)
- fix mmio alignment error in olympic token ring driver (Julie DeWandel)
- prevent tux logger-thread shutdown problems on ppc64 (Ingo Molnar)
- add ppc64 AltiVec chip support for Power Blades (Julie DeWandel)
- eliminate multi-threaded coredump hang potential (Ingo Molnar)
- fix ppc64 segfaults with tasks > 2GB in size (Julie DeWandel)
- fix usb-storage memory-allocation/iowait deadlock (Alan Cox)

* Mon Feb  2 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.3.EL
- add amd64 support for PT_GNU_STACK with exec shield (Jim Paradis)
- fix s390 raid1 sync problem w/writes at end of dev (Pete Zaitcev)
- update s390 zcrypt driver to version 1.1.4 (Pete Zaitcev)
- fix output of large /proc/pid/statm values (Mark DeWandel)
- fix output of large /proc/partitions values (Mark DeWandel)
- enable ppc64 support for JS20 Power Blades (Julie DeWandel)
- fix kernel stack memory leak on fork failures (Dave Anderson)
- fix ipv6 packet quoting problem in icmpv6_send() (Dave Miller)

* Thu Jan 29 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.2.EL
- apply Intel's x86 microcode loader update (Jim Paradis)
- enhance PCI multifunction support for ppc64 (Julie DeWandel)
- fix nfsd returning bad mode bits when acls set (Steve Dickson)
- prevent unkillable zombies from detached NPTL threads (Ingo Molnar)
- avoid missing scsi disks in /proc/partitions on detach (Jason Baron)
- correct pte calculation inside zeromap_pte_range() loop (Ben Woodard)
- add inline function PDE() to help driver backporting (Matthew Galgoci)

* Wed Jan 21 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.1.EL
- (this is the first build for RHEL 3 Update 2)
- relocate various pieces of the "undo" patch (Patch Review Committee)
- rename s390 zcrypt and zfcp driver patches (Pete Zaitcev)
- add LKML discussion to COPYING.modules (Arjan van de Ven)

* Thu Jan  8 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.EL
- fix race condition between thread creation and signals (Ingo Molnar)

* Wed Jan  7 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-8.EL
- fix amd64 eflags masking in 32-bit emulation of ptrace (Jim Paradis)

* Tue Jan  6 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-7.EL
- fix numerous ppc64 problems with /proc access (Julie DeWandel)
- allow user core files larger than 2GB in size (Dave Anderson)
- add ia64 support for Crestone Peak AGP bridges (John Dennis)
- fix unaligned kernel accesses in nfs_readdir() (Steve Dickson)
- add new_len/new_addr checks in do_mremap() (Ernie Petrides)
- fix nfs O_DIRECT corruption with >4GB files (Steve Dickson)
- enable bus scan for AGP ctlrs on amd64 systems (John Dennis)
- limit PCI-alloc'ed physaddrs to 4GB on HP ia64 (Jason Baron)

* Mon Dec  8 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-6.EL
- fix ppc64 firmware updates (Julie DeWandel)
- fix sync wakeup problem (Ingo Molnar)
- add ia64 cyclone support (Jason Baron)

* Mon Dec  1 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-5.EL
- undo rejected patches (Stephen Tweedie, Arjan van de Ven, Rik van Riel)

* Wed Nov 26 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.20.EL
- enable NUMA support in amd64 smp configs (Jim Paradis)
- prevent oopses with tux in OOM scenarios (Ingo Molnar)
- apply several ipv6 multicast bug fixes (Dave Miller)
- assign retval in copy_process() error path (Ingo Molnar)
- add lseek-in-/proc support for s390x "ps" (Pete Zaitcev)
- redefine zone_is_highmem() for Celestica (Dave Anderson)
- fix unresolved symbols in amd64 modules (Bill Nottingham)

* Tue Nov 25 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.19.EL
- fix tg3 rx_pending limit for BCM5705/BCM5782 chips (Jeff Garzik)
- reset page error flag prior to read of new contents (Jeff Moyer)
- enable CONFIG_HOTPLUG_PCI option for ia64 configs (Doug Ledford)
- fix inactive laundry list race in ramfs_writepage() (Dave Anderson)
- avoid out_of_memory() for wired pages when there's lomem (Dave Anderson)
- conditionalize ppc64 machdep_calls change for KMI compat (Ernie Petrides)
- limit anon/cache pages scanned in refill_inactive_zone() (Larry Woodman)

* Mon Nov 24 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.18.EL
- create old version (rev. 5.64) of cmpci sound driver (Tom Coughlan)
- remove ac97.o, ad1848.o, cs4232.o from unsupported (Jeff Moyer)

* Mon Nov 17 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.17.EL
- fix missing use of __GFP_HIGHMEM flag in pte_alloc_one() (Larry Woodman)

* Sat Nov 15 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.16.EL
- rework scsi mid-layer queuing logic to fix error handling (Doug Ledford)
- fix pci_dma_sync_sg() scatterlist arg in megaraid2 driver (Tom Coughlan)
- move more-ptes-in-rmap-pte-chain logic to its own patch (Ernie Petrides)
- tag uses of __GENKSYMS__ with KMI/ABI compat comment (Ernie Petrides)

* Fri Nov 14 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.15.EL
- fix MD multipath bugs causing crashes during fail-overs (Doug Ledford)
- add chain_ptep_t and revert pte_addr_t for KMI compat (Ernie Petrides)
- restore sub-timer-tick time-of-day granularity for ia64 (Jason Baron)
- modify agpgart and drm drivers for ia64 HP ZX1 support (John Dennis)
- fix ia64 32-bit emulation for several stat-related calls (Jason Baron)
- enable amd64 use of new ips driver w/config separation (Tom Coughlan)
- update e100 network driver to version 2.3.30-k1 (Jeff Garzik)
- update e1000 network driver to version 5.2.20-k1 (Jeff Garzik)
- apply scsi whitelist updates for IBM/CNSi/NEC devices (Tom Coughlan)
- reenable varyio for aic7xxx driver (hangs were unrelated) (Jeff Moyer)
- conditionalize NVIDIA_NFORCE3 to restore KMI compat (Ernie Petrides)
- prevent two ext3 panics on corrupted filesystems (Stephen Tweedie)
- apply two minor fixes to ppc64 RAS nvram reading (Julie DeWandel)

* Thu Nov 13 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.14.EL
- update ServeRAID (ips) driver to version 6.10.52 (Tom Coughlan)
- configure xmon on by default in ppc64 configs (Julie DeWandel)
- create initial s390 zcrypt driver, version 1.1.2 (Pete Zaitcev)
- remove zfcp driver from linux-modules-unsupported (Pete Zaitcev)
- revise ppc64 reliability/serviceability support (Julie DeWandel)
- reduce kernel stack usage inside nfs_readdir() (Steve Dickson)
- add gameport dependency to cmpci driver config (Tom Coughlan)

* Wed Nov 12 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.13.EL
- reduce UDP retransmissions and fix slow reads for NFS (Steve Dickson)
- implement wired page lists for better ramfs handling (Larry Woodman)
- fix vfork deadlock when child process causes core dump (Ingo Molnar)
- enhance AltSysRq-M output and fix deadlock potential (Larry Woodman)
- update cmpci sound driver for some HP IPF workstations (Tom Coughlan)
- correct tq_struct struct initialization in tg3 driver (Jeff Garzik)
- fix NFS file attribute inconsistency after rename (Steve Dickson)
- prevent ia64 machine checks w/sysreport on Olympia (Larry Woodman)

* Tue Nov 11 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.12.EL
- redesign refill_inactive_zone() for smarter deactivation (Larry Woodman)
- improve page deactivation scalability w/delayed laundering (Larry Woodman)
- rework locking and timer usage in s390 ctc network driver (Pete Zaitcev)
- allow xmon to be enabled at boot-time for ppc64 debugging (Julie DeWandel)
- reverse kscand's order of anon/cache active list traversal (Larry Woodman)
- force in-lining of br_read/write_lock/unlock routines (Julie DeWandel)
- fix mistaken fall-through cases in s390 chandev driver (Pete Zaitcev)
- make a few exported symbols available to OpenGFS (Stephen Tweedie)
- fix ld/st ordering bug causing lost signal wakeups (Mark DeWandel)

* Thu Nov  6 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.11.EL
- make profile=X imply nmi_watchdog=1 and fix NMI w/d bugs (Ernie Petrides)
- add lock init in scsi_get_host_dev() to fix shutdown hang (Doug Ledford)
- enable distributed interrupts by default on ppc64 iSeries (Julie DeWandel)
- improve amd64 reporting of machine check errors (Jim Paradis)
- fix disabling of autonegotiation in tg3 driver (Dave Miller)
- add image name to s390 ioctl32 debug message (Pete Zaitcev)

* Wed Nov  5 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.10.EL
- fix file lock ownership by NPTL threads to be process-wide (Ernie Petrides)
- upgrade megaraid driver to version 1.18k and fix isr/fw sync (Tom Coughlan)
- upgrade megaraid2 driver to version 2.00.9 and enable varyio (Tom Coughlan)
- improve scsi mlqueue handling to enable BUSY/QUEUE_FULL fix (Doug Ledford)
- correct reporting of i/o errors in ppc64 viodasd driver (Julie DeWandel)
- update acenic driver to handle enabling of jumbo frame mode (Jeff Moyer)
- fix i386 PAGE_NONE bits to prevent get_user_page() hang (Roland McGrath)
- fix ia64 show_mem() handler to use efi_memmap_walk() call (Dave Anderson)
- replace spaces in slabinfo entry name for async poll table (Matt Wilson)
- fix race condition in buffer-head memory footprint patch (Larry Woodman)

* Tue Nov  4 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.9.EL
- improve spec file robustness in %post/%preun stanzas (Florian La Roche)
- add s390x iovec length checking for 32-bit reads/writes (Matt Wilson)
- use highmem for pte/ramfs page allocation w/__GFP_WIRED (Larry Woodman)
- upgrade oprofile support with bug fixes and enhancements (Will Cohen)
- fix infinite recursion in SCSI mid-layer post-processing (Jeff Moyer)
- introduce no-auto-start-on-add handling for SCSI blacklist (Jeff Moyer)
- enable s390 support for blk stats handling for iostat -x (Pete Zaitcev)
- fix LVS timer-related hang from ip_vs_conn_expire() bug (Ernie Petrides)
- correct module init in cpqarray driver to fix insmod crash (Tom Coughlan)
- incorporate ESB PATA support and fix a pirq_routers PCI id (Jeff Garzik)
- fix nfs async write deadlock potential w/nfs_writepage() (Steve Dickson)
- fix SCSI error handling for BUSY queue status messages (Doug Ledford)
- improve ppc64 32-bit ioctl support for use by ethtool (Julie DeWandel)
- add missing unlock in ip_mc_del_src() to fix IGMP deadlock (Dave Miller)
- change ppc64 reporting of floppy capacity to be 1.44 MB (Julie DeWandel)

* Wed Oct 29 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.8.EL
- fix up various problems on Nforce3-based amd64 systems (Jim Paradis)
- double number of pte addrs in rmap pte_chain structs (Larry Woodman)
- restrict slab size for kernel data structs to 2 pages (Larry Woodman)
- clean up obsolete quicklist usage for ppc64 pte pages [rejected]
- prevent readdirplus from returning hidden mount points (Steve Dickson)
- prevent lockd deadlocks caused by export table locking (Steve Dickson)
- eliminate use of parallel task_struct init macro on ia64 [rejected]
- fix broken s390x overflow checks with 32-bit F_GETLK use (Matt Wilson)
- fix SCSI errors with "mt stoptions" and IDE tape drives (Pete Zaitcev)

* Sun Oct 26 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.7.EL
- fix bad checksumming interaction between e100 and bridge (Jeff Garzik)
- prevent system hang by OOM killing when overcommitted (Larry Woodman)
- un-inline ext3 error function to reduce stack usage (Stephen Tweedie)
- fix several ppc64 problems with interrupt handling (Julie DeWandel)
- correct amd64 identification in /dev/oprofile/cpu_type (Jim Paradis)
- move fput() call in do_tty_hangup() to avoid oops w/kon (Alexander Viro)
- eliminate creation of never-used task_struct slab cache (Larry Woodman)

* Thu Oct 23 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.6.EL
- reduce buffer-head memory footprint from read-only files (Ingo Molnar)
- update qeth driver for reduced stack usage and bug fixes (Pete Zaitcev)
- fix s390 qeth driver again to allow tcpdump to function (Pete Zaitcev)
- add exec_mmap() locking to prevent vma lookup races (Ernie Petrides)
- rework RPC slot allocation for further NFS improvements (Steve Dickson)
- reduce frequency of RPC retransmits during NFS writes (Steve Dickson)
- make generic/ext3 file system write handling 64-bit clean (Jeff Moyer)
- allow SMP scheduling rebalancing to occur every 200 msecs (Ingo Molnar)
- prevent races during IPC semaphore set and msg queue removal (Ingo Molnar)
- fix ACPI handling to identify trigger/polarity of PCI IRQs (Jim Paradis)
- correct amd64/ia64 acpi_disabled decls for post-boot access (Jeff Moyer)
- update ppc64 viocons driver with several bug fixes (Julie DeWandel)

* Thu Oct 16 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.5.EL
- move fix for PPR use in sym53c8xx driver to its own patch (Ernie Petrides)
- correct pids exported by msgctl/semctl/shmctl/fcntl calls (Ulrich Drepper)
- apply s390 lcs driver wait queue init and locking updates (Pete Zaitcev)
- enable dummy network driver use in generic s390 config file (Pete Zaitcev)
- add missing ptrace hooks for exec and vfork-done events (Bill Nottingham)
- fix SMP timer race that triggered BUG_ON() in add_timer() (Ingo Molnar)
- fix several bogus ipvs boundary checks in ftp module [rejected]
- fix vfsmount queuing in attach_mnt() for CLONE_NEWNS [rejected]
- add net_device check to prevent oops in pppoe driver [rejected]
- fix memory leak in symlink error path of /proc driver [rejected]
- fix overflow in v1_disk2mem_dqblk() quota calculation [rejected]
- increase ppc64 ramdisk size to 8192k in p/iSeries configs (Jeremy Katz)
- lower amd64 TASK_UNMAPPED_32 to increase avail address space (Jim Paradis)

* Mon Oct 13 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.4.EL
- fix ppc64 stack pointer alignment in user signal handlers (Jakub Jelinek)
- increase amd64 exception stack size to 4k to avoid overflow (Jim Paradis)
- fix ppc64 interrupt rate accounting for vmstat and /proc (Julie DeWandel)
- extend amd64 NMI watchdog timeouts to tolerate bad 2nd cpu (Jim Paradis)
- allow s390 dasd driver to use noop elevator module (Pete Zaitcev)
- add free_irq() in error path of olympic token ring driver (Matt Wilson)

* Sat Oct 11 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.3.EL
- make pid fields in ucred structures hold tgid values (Ulrich Drepper)
- prevent ppc64 iSeries virtual console writes > 4k (Julie DeWandel)
- control ia64 unaligned access messages with new sysctl (Jeff Moyer)
- correct SCSI data direction on cmd to spin up disks (Pete Zaitcev)
- add do_brk() TASK_SIZE and address space wrap checks (Arjan van de Ven)
- limit PPR use in sym53c8xx driver for ppc64 Zapata drives (Doug Ledford)
- list ac97.o, ad1848.o, and cs4232.o modules as unsupported (Jeff Moyer)
- clean up conditional compilation in s390 zfcp driver (Pete Zaitcev)

* Thu Oct  9 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.2.EL
- identify whether i686 or athlon config in oops output (Arjan van de Ven)
- remove warning in reclaim_page() unmapped page path (Ernie Petrides)
- fix several lvm error handling paths causing memory leaks [rejected]
- correct i386 smp shutdown logic when netdump is enabled (Jeff Moyer)
- fix amd64 potential data leaks on FPU save/restore errors (Jim Paradis)
- prevent aic7xxx chip resets leading to PCI parity errors (Tom Coughlan)
- remove ia64 user tty warning on unaligned accesses (Arjan van de Ven)
- fix ppc64 /proc file buf overruns in viodasd driver (Mark DeWandel)

* Wed Oct  8 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.1.EL
- (this is the first build for RHEL 3 Update 1)
- avoid m/ctime update for pipe writes on r/o file systems (Stephen Tweedie)
- prevent theoretical ext3 fs corruption in ext3_read_inode (Stephen Tweedie)
- enable AGRESSIVE_IDLE_STEAL to improve scheduler balancing (Ingo Molnar)
- fix potential ppc64 lock-up on ioctl32 un/reregistering (Pete Zaitcev)

* Fri Oct  3 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.EL
- extend ppc64 scsi timeout values for Zapata DVD-ROM drives (Julie DeWandel)

* Fri Sep 19 2003 Rik van Riel <riel@redhat.com> kernel-2.4.21-3.EL
- make sure to release viotape op structure after use (Julie DeWandel)
- disable pgd/pmd quicklists on ppc64 (Mark DeWandel)
- temporarily disable aio on sockets (Jeff Moyer)
- correctly refile inodes to make them reclaimable (Harald Hoyer)

* Wed Sep 17 2003 Rik van Riel <riel@redhat.com> kernel-2.4.21-2.EL
- S390: update zfcp and cio drivers (Pete Zaitcev)
- IA64: add extra check to virtual mem_map (Larry Woodman, Dave Anderson)
- initialise local variables in ide-tape & ide-scsi
- cap qla2200 tcq depth to 255
- switch version number scheme to kernel-2.4.21-N.EL

* Tue Sep 16 2003 Rik van Riel <riel@redhat.com>
- PPC64: invalidate evicted sbl entries in the erat (Julie DeWandel)
- increase ethernet tx_queue_len to 1000 (David Miller)
- in udp_{v6_}flush_pending_frames, reset up->len too (David Miller)
- S390: CMS reserved minidisk detection (Pete Zaitcev)
- call recount_segments() on a different occasion (Pete Zaitcev)

* Mon Sep 15 2003 Rik van Riel <riel@redhat.com>
- really disable exec-shield (Roland McGrath)
- reduce stack randomisation, disable brk randomisation (Ingo Molnar)
- make e1000 driver 64 bit clean (Julie DeWandel)
- minor aio corner case error condition fix (Jeff Moyer)
- AMD64: more lenient check for call workaround (Ernie Petrides)
- PPC64: disable CONFIG_XMON (Mark DeWandel)
- S390: fix CCW slab selection (Pete Zaitcev)
- fix two-disk combined mode sata (Jeff Garzik)
- move buslogic scsi driver to supported, for vmware only (Tom Coughlan)
- change viocons message from KERN_WARNING to KERN_INFO (Julie DeWandel)

* Fri Sep 12 2003 Rik van Riel <riel@redhat.com>
- VM: handle race condition in reclaim_page (Stephen Tweedie, Larry Woodman)
- PPC64: fix "log_buffer broken" xmon issue (Julie DeWandel)
- fix compiler warnings in netdump (Jeff Moyer)
- AMD64: workaround for 32 bit compat mode page fault problem (Ernie Petrides)
- IA64: make perfmon root-only (Jason Baron)

* Thu Sep 11 2003 Rik van Riel <riel@redhat.com>
- fix smp race in rebalance_laundry_zone()

* Wed Sep 10 2003 Rik van Riel <riel@redhat.com>
- fix compiler warnings when hugetlbfs is disabled (Pete Zaitcev)
- fix tux performance bug (Ingo Molnar)

* Tue Sep  9 2003 Rik van Riel <riel@redhat.com>
- don't evict kernel stack seg translation on ppc64 (Julie DeWandel)
- fix callers of do_page_fault on ppc64 (Mark DeWandel)
- AMD64 munmap return value, fix lsb failure (Jeff Moyer)
- fix for PPC64 32-bit ioctl (Jim Paradis)
- bring IA64 value of MINSIGSTKSZ in line with upstream (Jakub Jelinek)

* Mon Sep  8 2003 Rik van Riel <riel@redhat.com>
- fix potential datacorruptor in viodasd driver (Julie DeWandel)
- fix race condition in s390 dirty bit handling (Pete Zaitcev)
- limit per-cpu slab cache size
- correct 32-bit readv/writev border cases on ppc64 (Matt Wilson)
- AMD Golem IO-APIC fixup for i686 kernel on AMD64 (Jeremy Katz)
- NFS Solaris 8 acl fix (Steve Dickson)

* Fri Sep  5 2003 Rik van Riel <riel@redhat.com>
- minor nfs permissions bugfix (Steve Dickson)
- change mprotect return value to SuS mandated value (Arjan van de Ven)
- kernel-unsupported now provides kernel-modules (Jeremy Katz)
- correct __hugemem__modules typos in rhkernel.h
- fix subtle pmd corruption error (Larry Woodman, Dave Anderson)
- fix cut'n'paste error in SATA io port reservation
- restore NFSEXP_CROSSMNT ABI compatibility (Steve Dickson)
- round up executable name field length in core file (Jakub Jelinek)
- switch off exception_trace on amd64 (Jeff Moyer)

* Tue Sep  2 2003 Rik van Riel <riel@redhat.com>
- patch to access odd last sector on ia64 (Jason Baron)
- misc fixes from upstream (Arjan van de Ven)
- fix audigy driver (Jeff Garzik)
- tunable dcache reclaim priority for tux (Ingo Molnar)
- tg3 driver update (Jeff Garzik)
- ipv6 and icmp network bugfixes (David Miller)
- fix ppc64 memory access security bug (Julie DeWandel)
- reduce memory allocated for skb (Ingo Molnar)
- small smp fix for scalable timers (Ingo Molnar)
- make s390 recognise MSDOS partitions (Pete Zaitcev)
- small smp fixes in tux (Ingo Molnar)
- make mptfusion drivers supported on 4/4 split kernel (Tom Coughlan)
- add entries to scsi whitelist (Tom Coughlan)
- minor sata/ata driver updates (Jeff Garzik)
- small fixes to viodasd driver (Julie DeWandel)
- nfs_get_root and nfs access bit patches (Steve Dickson)

* Thu Aug 28 2003 Rik van Riel <riel@redhat.com>
- don't show interrupts in /proc/stat for ppc64 (Matt Wilson)
- make sure sync returns in a reasonable time
- PPC64: fix for boot cpu not being cpu 0 (Julie DeWandel)
- zero sized write no longer updates mtime (Matt Wilson)
- fix video bios read corruption on ia64 (Larry Woodman)
- network fixes to tg3, bonding (Jeff Garzik)
- properly reserve legacy IDE regions in sata driver (Jeff Garzik)
- fix ppc64 signal handling bugs (Mark DeWandel)
- tux fixes (Ingo Molnar)
- tgkill syscall for s390(x) (Pete Zaitcev)
- amd64 32 bit compatibility fixes (Jim Paradis)
- ppc64 32 bit compatibility fixes (Julie DeWandel)
- fix 4G/4G follow_page problem (Ingo Molnar)
- reduce memory used by VMAs and dentries (Arjan van de Ven)
- make LVM snapshotting of ext3 work reliably (Stephen Tweedie)
- make netdump play better with the nmi watchdog (Jeff Moyer)
- QLA2200: disable irq mitigation, fix off-by-one (Arjan van de Ven)

* Mon Aug 25 2003 Rik van Riel <riel@redhat.com>
- seq_file /proc/interrupts for x86 too (Ingo Molnar)
- fix memory leak in ia64 exec of ia32 binaries
- check tgid not pid in scm_check_creds()  (David Miller)
- VM fixes: shm swap priority, zeromap_page_range
- workaround VFS limitations for VXFS NFS export

* Fri Aug 22 2003 Rik van Riel <riel@redhat.com>
- use personality for 3GB userspace on x86 -hugemem (Ingo Molnar)
- add sysctl interface for lockd (Steve Dickson)
- don't prod VGA space on HP Pinnacle systems (Larry Woodman)
- fix for 32 bit binaries on amd64 (Jim Paradis)
- add preemption point to write_some_buffers (Julie DeWandel)
- sort ACPI table to get correct device ordering on HP (Larry Woodman)
- fix refcounting bug with ipv6 addresses on netdevs (David Miller)
- add s390 syscalls for tux (Pete Zaitcev)
- md multipath enablers (Doug Ledford)

* Thu Aug 21 2003 Rik van Riel <riel@redhat.com>
- fix process and nice time accounting (Doug Ledford)
- amd64: syscall table updates, timer robustness (Jim Paradis)
- amd64 3GB personality for 32-bit processes (Jim Paradis)
- use 256MB pagesize for hugetlbfs on ia64 (Larry Woodman)
- make sure e100 only claims ipv4 checksumming
- igmpv3/mldv2 OOPS'er fix (David Miller)
- hugetlbfs: make chown work and allow uid=X,gid=Y mount options
- make larger mmap windows work (Ernie Petrides, Ingo Molnar)
- ia64: improve ia32 compatibility (Larry Woodman)
- fix bug in rpc retry code (Steve Dickson)
- make acpi pci hotplug modulable (Jeff Moyer)
- update (trivial) to megaraid 1.18j (Tom Coughlan) 
- enable varyio on mptfusion (Tom Coughlan)
- panic on oops to prevent data corruption opportunities (Ernie Petrides)
- small iorl locking fix (Doug Ledford)
- fix ppc64 get_wchan() bad deref (Mark DeWandel)
- fix aio read into mmap()d PROT_WRITE (Jeff Moyer, Ernie Petrides)

* Wed Aug 20 2003 Rik van Riel <riel@redhat.com>
- libata update (Jeff Garzik)
- amd64 syscalls for xattrs & ACLs (Jim Paradis)
- tux fixes (Julie DeWandel, Ingo Molnar)
- via & i810 audio fixes (Jeff Garzik)
- small 4G/4G split bugfixes (Ingo Molnar)
- fix sigsuspend race on x86, amd64, ia64 (Mark DeWandel)
- ia32 behavior for FP denormal exceptions on ia64 (Jason Baron)
- get the set/get of NAT bits for ia64 correct (Jason Baron)
- ipsec update, adds cast6 encryption (David Miller)
- VM update: OOM bugfix & page->flags atomic updates (Rik van Riel)
- reenable serpent encryption on ppc64
- bladecenter usb-ohci support (Pete Zaitcev)
- iorl fixes (Doug Ledford)
- network bonding driver oops fix (Jeff Garzik)

* Wed Aug 13 2003 Rik van Riel <riel@redhat.com>
- DAC960 back to bigmem supported, ne2k-pci & usb audio to bigmem unsupported
- netdump updates for tg3 and e1000 (Jeff Moyer)
- put a hole between stack and mmap area (Ernie Petrides)
- process time accounting updates (Doug Ledford)
- fix null characters in TUX header (Julie DeWandel, Ingo Molnar)
- display correct executable when running interpreted script
- zfcp zSeries fibrechannel driver (Pete Zaitcev)
- ipsec updates (David Miller)
- fix 4G/4G race conditions (Ingo Molnar)
- rename -bigmem kernel to -hugemem to reflect changed tradeoffs
- optionally show task states from hangcheck timer (Jason Baron)
- various small bugfixes from upstream

* Sat Aug  9 2003 Rik van Riel <riel@redhat.com>
- fix scalable timer race condition  (Julie DeWandel, Ingo Molnar)
- print warning on boot with >16GB RAM on -smp kernel (Arjan van de Ven)
- fix for xapic issue with ServerWorks chipsets (Ernie Petrides)
- remove spurious ioctl printk on ppc64 (Mark DeWandel)
- ppc64 wchan improvement (Mark DeWandel)
- hint @pause changes for ia64
- longer scsi scan timeout on ppc64 (Julie DeWandel)
- readv/writev for raw IO (Stephen Tweedie)
- fix for easy stack/mmap collisions (Ernie Petrides)

* Thu Aug  6 2003 Rik van Riel <riel@redhat.com>
- various XAPIC related fixes (Ingo Molnar)
- correct context switch and iowait stats with HT shared runqueues
- ext3 obscure deadlock fixes (Stephen Tweedie)
- knfsd fixes: blocked lock, symlink error & missing bkl  (Steve Dickson)

* Wed Aug  5 2003 Rik van Riel <riel@redhat.com>
- de_thread bugfix from 2.6 upstream  (Matt Wilson)
- viocons driver update (Julie DeWandel)
- fix VM non-overcommit mode (Rik van Riel)

* Tue Aug  4 2003 Rik van Riel <riel@redhat.com>
- plug data leak in aio code (Jeff Moyer)
- initial list of 4G/4G unsupported modules (Tom Coughlan)
- nfs softirq race fix (Steve Dickson)
- updated IPSEC patch (David Miller)
- networking updates/fixes from 2.4.22-preX (David Miller)

* Sun Aug  3 2003 Rik van Riel <riel@redhat.com>
- drop orlov allocator for now (Arjan van de Ven)
- correct HT cpu pair detection (Arjan van de Ven)
- build zImage.partial for netbooting on pSeries (Matt Wilson)
- fix missing symbols

* Sat Aug  2 2003 Rik van Riel <riel@redhat.com>
- export two AIO symbols for OCFS
- disable CONFIG_DEBUG_SLAB so performance testing can start
- crosshost mmap hooks for distributed filesystems (Stephen Tweedie)
- include partially linked zImage for pSeries netboot (Matt Wilson)
- nfs highmem fix, unmap when xdr_kmap() fails (Steve Dickson)
- update megaraid2 locking to work with IORL (Com Coughlan)
- make sure to build the qla2100 driver (Tom Coughlan)
- fix cdrom ioctl 32 bit compatibility for ppc64, amd64 (Julie DeWandel)

* Thu Jul 31 2003 Rik van Riel <riel@redhat.com>
- run depmod on install of unsupported modules (Arjan van de Ven)
- fix register corruption in IA64 lazy fpu handling (Larry Woodman)
- add b44 network driver (Jeff Garzik)
- make ppc64 pci interface routines compatible (Julie DeWandel)
- allow 32 bit userland on AMD64 and PPC64 to use volumes > 2GB (Jeff Moyer)
- nfsd: acl related mount and export flags (Steve Dickson)
- fix nfs exp_fodrop oops (Steve Dickson)
- fix missed signal wakeups on ppc64 (Mark DeWandel)
- smp scalable timer bugfixes (Ingo Molnar)
- workaround for a prefetch bug in some Athlon CPUs (Ernie Petrides)
- code to make more modules unsupported for 4/4 split (Arjan van de Ven)
- various spec file and config cleanups
- viopath driver fix (Julie DeWandel)
- add match for 440gx chipset bioses (Arjan van de Ven)
- move epic100 and ne2k-pci back to supported (Jeff Garzik)

* Tue Jul 29 2003 Rik van Riel <riel@redhat.com>
- updated finegrained process accounting patch (Doug Ledford)
- make iSeries compile without CONFIG_ICOM (Julie DeWandel)
- nfsd: only set ->reuse for tcp sockets, not udp  (Steve Dickson)
- enable the 4G/4G split on the i686-bigmem kernel only
- sysrq support for viocons (Julie DeWandel)
- limit pci_bus size changes to ppc64 (Jeff Garzik)
- fix for signal delivery race (Ernie Petrides, Mark DeWandel)
- add ShdPnd to /proc (Ingo Molnar)
- fix de_thread() hang (Ingo Molnar)
- add kernel support for CLONE_STOPPED (Ernie Petrides)
- make sure to initialise HVC console (Julie DeWandel)
- fix _SEG abort hit in ACPI code (Larry Woodman)
- build addon drivers on amd64 and ppc64 too (Tom Coughlan)
- build IPS driver on all architectures (Tom Coughlan)
- fix a few ia32 emulation bugs for IA64 (Larry Woodman)
- enable correct/new __clear_bit macro for IA64 (Larry Woodman)
- flexible mmap allows mappings of huge executable segments (Larry Woodman)
- sysrq-w for s390 (Pete Zaitcev)

* Thu Jul 17 2003 Rik van Riel <riel@redhat.com>
- have s390 cpu_relax() also include barrier  (Pete Zaitcev)
- convert ppc64 xmon traceback code to ksymoops (Matt Wilson)
- rename kstat_sum() variable with aliasing problems  (Ingo Molnar)
- fix AIO-on-hugetlbfs crash (Ingo Molnar)
- update support for IA64 Long's Peak ACPI serial ports  (Larry Woodman)
- turn on xmon for both iSeries and pSeries (Matt Wilson)
- bugfix to make CLI work correctly on iSeries (Julie DeWandel)
- SATA bugfixes (Jeff Garzik)
- enable 4G/4G split in -BOOT kernel, due to syslinux trouble

* Wed Jul 16 2003 Rik van Riel <riel@redhat.com>
- fix s390 compile (Pete Zaitcev)
- taint the kernel on sii6512 driver link, GPL but no source available
- handle debug registers with 4G/4G split (Ingo Molnar)
- tgkill syscall for ppc64 (Julie DeWandel)
- fix NFSD/ACL/ext3/jbd deadlock (Stephen Tweedie, Steve Dickson)
- fix maxcpus=1 installation panic fix for ppc64 (Julie DeWandel)
- IDE byteswapping io functions for ppc64 (Julie DeWandel)
- update sata driver (Jeff Garzik)
- raise the number of /proc entries (Julie DeWandel)
- sticky sysrq key with timeout (Jeff Moyer)

* Tue Jul 15 2003 Rik van Riel <riel@redhat.com>
- make SysRq-W useable on s390 (Pete Zaitcev)
- updated process accounting patch (Doug Ledford)
- siginfo_t fixes for s390x and amd64 (Jakub Jelinek)
- clustered NFS fail-over support (Steve Dickson)
- autofs4 updates and fixes
- ia64 patches to reduce cpu power/temp in idle loop (Larry Woodman)
- add irqsafe up() for LVM locking (Stephen Tweedie)
- O_DIRECT fallback to synchronous allocation in holes (Stephen Tweedie)

* Mon Jul 14 2003 Rik van Riel <riel@redhat.com>
- ia64 HP iommu: add sx1000 detection
- possible bug in s390x 32-bit emulation  (Roland McGrath)
- updated ipsec patch, should fix all current ipv6 bugs  (David Miller)
- finegrained process accounting (Doug Ledford)
- ICH5 pci irq routing, and associated ids (Jeff Garzik)
- fix the machine_real_restart() reboot path on 4G/4G (Ingo Molnar)

* Fri Jul 11 2003 Rik van Riel <riel@redhat.com>
- fix amd64 agp-gart code to work around hugetlbfs debug code (Jim Paradis)
- fix ppc32 pthread_cancel (Jakub Jelinek) 
- Do not sent IGMP leave messages unless IFF_UP  (David Miller)
- software iommu for ia64 systems without hardware iommu (Jason Baron)
- fix ext3 oops fix during dio, LTP failure (Arjan van de Ven, Stephen Tweedie)

* Thu Jul 10 2003 Pete Zaitcev <zaitcev@redhat.com>
- Remove illegal calls to dst_link_failure

* Thu Jul 10 2003 Rik van Riel <riel@redhat.com>
- enable HT scheduler for bigmem kernel
- add tgkill syscall for x86 and ia64
- make -BOOT kernel smaller w/ modular md and CONFIG_SMALL
- rmap VM updates
- 4G/4G agpgart potential corruption fix (Larry Woodman)

* Wed Jul  9 2003 Rik van Riel <riel@redhat.com>
- switch off exec shield everywhere
- eliminate hostfs for amd64 (Jim Paradis)
- megaraid update, mostly vendor ID (Tom Coughlan)
- shrink boot kernel by disabling some config options
- additions for the SCSI whitelist (Tom Coughlan)
- ia64 extable fix (Jason Baron)
- viocons driver upgrade (Julie DeWandel)
- another ia64 mmu context wraparound deadlock fix (Larry Woodman)
- iSeries icom debugger patch (Julie DeWandel)

* Tue Jul 8 2003 Pete Zaitcev <zaitcev@redhat.com>
- Drop io_request_lock in usb scsiglue.c:device_reset

* Tue Jul  8 2003 Rik van Riel <riel@redhat.com>
- fix cpu_relax for amd64 and ia64 to include a barrier (Ingo Molnar)
- restore o_direct api compatibility (Stephen Tweedie)
- fix possible ext3 deadlock in o_direct patches (Stephen Tweedie)
- ACLs for JFS (Stephen Tweedie)
- fix /proc/cpuinfo runqueue printing (Ingo Molnar)
- via audio fixes, smaller emu10k1 patch (Alan Cox, Matt Wilson)

* Mon Jul  7 2003 Rik van Riel <riel@redhat.com>
- fix process accounting, tux ftp passwords and si_pid (Ingo Molnar)
- 32bit compat statfs fix (Guy Streeter)
- don't serialise exit on BKL when accounting is off (Ingo Molnar)
- truncate timeouts to 32 bits on 64bit systems (Ingo Molnar)
- fix network channel bonding (Jeff Garzik)
- split netdump patch into core and net-drivers (Jeff Garzik)
- delayed tlb flushing for ia64 (Larry Woodman)
- emu10k1 driver fixes
- kksymoops for AMD64 (Jim Paradis)
- select bugfixes from 2.4 upstream (Jeff Garzik)
- OOM tweaks (Rik van Riel)
- use seq_file for /proc/interrupts on ppc64 (Mark DeWandel)

* Wed Jul  2 2003 Rik van Riel <riel@redhat.com>
- add qdio and qeth drivers for s390(x)  (Phil Knirsch)
- slab cache scale bugfix (Larry Woodman)
- S390: qdio & qeth drivers (Phil Knirsch)
- hangcheck timer for ppc64 (Julie DeWandel)
- fix race conditions in ia64 ia32 compat layer (Larry Woodman)
- update megaraid, aic7xxx, cciss and cpqarray drivers (Tom Coughlan)
- nfs xdr_shift_buf, tcp client corruption and alignment (Steve Dickson)
- rhconfig.h stuff for ppc64, s390 and s390x (Matt Wilson)
- AIO on sockets

* Tue Jul  1 2003 Rik van Riel <riel@redhat.com>
- kiobuf optimisations (Stephen Tweedie, Larry Woodman)
- ipsec update (David Miller)
- ipvs update to deal with timer changes (David Miller)
- 4G/4G split patch optimisations (Ingo Molnar)
- hangcheck timer (Jason Baron)
- recent (AGP 3.0) agpgart support (Jeff Garzik)

* Mon Jun 30 2003 Rik van Riel <riel@redhat.com>
- semtimedop() support on s390/s390x  (Ernie Petrides)
- fix a 4G bug that triggers on systems with >30 CPUs (Ingo Molnar)
- updated SCSI SMP affine queueing patch  (Arjan van de Ven)
- page hash prefetch in do_generic_file_read bugfix (Julie DeWandel)
- updates the qlogic driver to the latest (Arjan van de Ven)
- slab cache SMP scalability tweaks (Ingo Molnar)
- ACPI 2.0 for IPF and AMD64 (Jim Paradis, Larry Woodman)
- statm fixes for hugetlbfs and remap_file_pages (Jason Baron)
- acpi serial port detection (Larry Woodman)

* Fri Jun 27 2003 Rik van Riel <riel@redhat.com>
- iseries driver updates (Julie DeWandel)
- aio scalability and 2.5 backports  (Ingo Molnar)
- SMP scalable timers (Ingo Molnar)

* Thu Jun 26 2003 Rik van Riel <riel@redhat.com>
- make qlogic driver use new scsi infrastructure (Arjan van de Ven)
- export aio kvec functions
- fix statm oops
- compile fixes 
- NFS ACL over the wire protocol extensions (Steve Dickson)
- rate limit slab pruning, to limit IPI load on SMP systems (Stephen Tweedie)

* Tue Jun 24 2003 Rik van Riel <riel@redhat.com>
- scsi request lock scaling (Ingo Molnar)
- cpu affinity for scsi command processing (Ingo Molnar)
- use softirqs instead of bhs for the scsi layer (Doug Ledford)
- igmpv3 fixes and improvements (David Miller)
- oprofile for ppc64 (Will Cohen)
- Increase MAX_ADDR_LEN from 8 to 32 for Infiniband over IP (Tom Coughlan)

* Mon Jun 23 2003 Rik van Riel <riel@redhat.com>
- per-cpu kstat arrays (Ingo Molnar)
- optimise 4G/4G tlb flushing (Ingo Molnar)
- kiobuf reclaim together with buffer reclaim (Arjan van de Ven)
- more scalable gendisk statistics (Ingo Molnar)
- nfs reconnect fixes (Steve Dickson)
- add 32-bit compatibility for ustat system call on ppc64 (Julie DeWandel)
- scalable gettimeofday (Ingo Molnar)
- hugetlbfs ppc64 & s390 bits (Mark DeWandel, Pete Zaitcev)
- hugetlbfs for ia64 (Jason Baron)
- qlogic scsi driver update (Arjan van de Ven)

* Sat Jun 21 2003 Rik van Riel <riel@redhat.com>
- nfs patches (Steve Dickson)
- xapic improvements, summit support (Ingo Molnar)
- fix core dump name for multithreaded programs (Roland McGrath)

* Fri Jun 20 2003 Rik van Riel <riel@redhat.com>
- merge up to marcelo's latest

* Thu Jun 19 2003 Rik van Riel <riel@redhat.com>
- oom killer fixes (Larry Woodman, Rik van Riel)
- tunable VM overcommit (Rik van Riel)
- hugetlbfs for amd64 (Jim Paradis)

* Wed Jun 18 2003 Rik van Riel <riel@redhat.com>
- updated iseries virtual drivers (Julie DeWandel)
- nfs lockd improvements (Steve Dickson)
- remap_file_pages improvements (Ingo Molnar)
- /proc/efi/symtab patch for ia64 (Larry Woodman)
- disable O_PROFILE on UP x86 machines
- allow NMI watchdog profiling frequencies up to 10kHz (Ingo Molnar)
- statm (Jason Baron)
- hugetlbfs (Ingo Molnar)
- have nfsd honour ACLs on a per-export basis (Steve Dickson)

* Tue Jun 17 2003 Rik van Riel <riel@redhat.com>
- Enable O_PROFILE on non-SMP configs (Stephen Tweedie)
- more conservative AIC config options
- Fix BOOT kernel panic while mounting /dev/cdrom (Larry Woodman)

* Mon Jun 16 2003 Rik van Riel <riel@redhat.com>
- merge to 2.4.21 + selected ac bits
- ipsec upgrade (David Miller)
- HT scheduler patch fix (correct sibling counting)
- make bdflush writeout smoother
- AMD64 gdb fix (Roland McGrath)

* Thu Jun 12 2003 Rik van Riel <riel@redhat.com>
- don't include unsupported drivers in -BOOT kernel
- merge up to 2.4.21-rc8 + selected ac bits
- FIXME: sysrq for 3170, dasd, odirect & odirect for nfs

* Thu Jun 12 2003 Pete Zaitcev <zaitcev@redhat.com
- oprofile for s390

* Tue Jun 10 2003 Rik van Riel <riel@redhat.com>
- statm (Jason Baron / Julie DeWandel)
- AIO 32-bit compat for 64-bit machines (Julie DeWandel)
- only do bufferhead reclaim in extreme situations (Rik van Riel)

* Mon Jun  9 2003 Rik van Riel <riel@redhat.com>
- Serial ATA support (Jeff Garzik)
- mtp fusion 2.05.05+ (Dave Maley)

* Fri Jun  6 2003 Rik van Riel <riel@redhat.com>
- XATTR/ACL patches, except NFS over the wire (Stephen Tweedie)
- ipsec module autoloading (David Miller)
- remap_file_pages (Ingo Molnar)

* Thu Jun  5 2003 Rik van Riel <riel@redhat.com>
- upgrade to latest -rmap with Ernie's fixes
- sysrq+C shows the stack dump of all CPUs
- ext3 truncate fix (Stephen Tweedie)
- NFS fixes for HZ=1000 machines (Steve Dickson)

* Wed Jun  4 2003 Rik van Riel <riel@redhat.com>
- 4G/4G split fix (Ingo Molnar)
- ppc64 fixes (Guy Streeter, Rik van Riel)
- enable oprofile on amd64
- ipsec updates (David Miller)
- fork returns pid instead of task_struct* (Julie DeWandel)
- ia64 ptrace bugfixes (Dave Anderson)

* Tue Jun  3 2003 Rik van Riel <riel@redhat.com>
- HP diva serial driver (Jeff Garzik)

* Mon Jun  2 2003 Rik van Riel <riel@redhat.com>
- NFS over TCP patches (Steve Dickson)
- switch to using ppc64pseries/ppc64iseries arches instead of
  kernel-pseries and kernel-iseries (Jeremy Katz)
- egenera scsi bus rescan patch (Jeff Garzik)
- oprofile (Graydon Hoare)

* Fri May 30 2003 Rik van Riel <riel@redhat.com>
- futex requeue (Ingo Molnar)
- enable NAPI for E1000
- signal latency and scheduler improvements (Ingo Molnar)

* Thu May 29 2003 Rik van Riel <riel@redhat.com>
- kscand oops fix (Ingo Molnar, Rik van Riel)
- pcnet32 fixes (Julie Dewandel)
- raid autorun (Pete Zaitcev)
- turn off CONFIG_SUNDANCE_MMIO (Jeff Garzik)
- flexible mmap (Larry Woodman)
- ppc64 fixes (Matt Wilson, Guy Streeter)
- loop softirq 10 times before giving up (Ingo Molnar)
- O_DIRECT for NFS (Steve Dickson)
- prevent md from shutting down active arrays (Doug Ledford)
- rmap updates, inode reclaim & higher order allocations (Rik van Riel)
- network channel bonding (Jeff Garzik)

* Wed May 28 2003 Jim Paradis <jparadis@redhat.com>
- Re-enable x86_64 in build
- x86_64-specific updates for exec-shield
- Bring in improved "nonx" support for x86_64 from upstream

* Wed May 28 2003 Pete Zaitcev <zaitcev@redhat.com>
- Hush s390 printks upon user SIGSEGV by default. It can be enabled back with
  a sysctl kernel.userprocess_debug.
- Enable optional 3270 console mode on s390.

* Fri May 23 2003 Rik van Riel <riel@redhat.com>
- get rid of vsyscall page (Arjan van de Ven)
- fix missing symbol copy_str_fromuser_size

* Tue May 20 2003 Rik van Riel <riel@redhat.com>
- exec-shield updates to fix hang-on-boot on some systems (Ingo Molnar)
- temporarily disabled the architectures, which got broken by exec-shield updates
- fix for LTP sigprocmask02 failure (Matt Wilson)
- ppc64 updates (Julie DeWandel)

* Mon May 19 2003 Rik van Riel <riel@redhat.com>
- pagecache scalability patch (Ingo Molnar)
- IPC semaphore scalability patch (Ingo Molnar)
- ppc64 updates (Guy Streeter)

* Thu May 15 2003 Rik van Riel <riel@redhat.com>
- exec-shield (Ingo Molnar)
- AMD64 ACPI updates (Jim Paradis)

* Wed May 14 2003 Rik van Riel <riel@redhat.com>
- reenable O_DIRECT, O_DIRECT fixes and superbh-aio (Stephen Tweedie)

* Tue May 13 2003 Rik van Riel <riel@redhat.com>
- vma merging (Stephen Tweedie)

* Mon May 12 2003 Rik van Riel <riel@redhat.com>
- nmi profiler
- VM updates: rmap, dma zone isolation
- tux (Ingo Molnar)
- ext3 stall fixes (Ingo Molnar)
- e1000 fixes (Ingo Molnar)

* Fri May  9 2003 Rik van Riel <riel@redhat.com>
- config files overhaul (Arjan van de Ven)
- fix bug in mlock patch
- IPVS (Dave Miller)

* Thu May  8 2003 Rik van Riel <riel@redhat.com>
- import IO elevator changes from gingin
- critical VM fix
- matrox framebuffer patch for pseries (Julie DeWandel)

* Wed May  7 2003 Rik van Riel <riel@redhat.com>
- hammer nptl fixes (Ulrich Drepper)
- 4G/4G split (Ingo Molnar)

* Tue May  6 2003 Rik van Riel <riel@redhat.com>
- upgrade to 2.4.21-rc1-ac4 (minus -ac acpi and xapic changes)
- drop nfs patches since those seem to be in -ac

* Mon May  5 2003 Rik van Riel <riel@redhat.com>
- larger message buffer size + boot option (Mark DeWandel)
- AMD64: tls handling, coredump fixes (Jim Paradis)
- SMP & highmem VM fixes (Ben LaHaise)
- HT+NUMA scheduler (Ingo Molnar)

* Sat May  3 2003 Rik van Riel <riel@redhat.com>
- ext3 orphan cleanup fix (Ernie Petrides)
- s390 affinity fixes (Pete Zaitcev)
- i386 vsyscall DSO changes (Roland McGrath)

* Fri May  2 2003 Rik van Riel <riel@redhat.com>
- bugfixes and config changes galore

* Thu May  1 2003 Rik van Riel <riel@redhat.com>
- enable semtimedop for other architectures (Ernie Petrides)
- large pci bus numbers (Julie DeWandel)
- bugfixes galore

* Tue Apr 29 2003 Rik van Riel <riel@redhat.com>
- igmpv3 (David Miller) 

* Mon Apr 28 2003 Rik van Riel <riel@redhat.com>
- generic 32bit compat stuff + amd64/ppc64/ipf pieces (Matt Wilson)
- clustered apic (XAPIC) support (Ingo Molnar)
- ppc64 architecture updates (Matt Wilson, Guy Streeter)

* Fri Apr 25 2003 Rik van Riel <riel@redhat.com>
- ppc64 fixes

* Thu Apr 24 2003 Rik van Riel <riel@redhat.com>
- collapse ipsec into one patch (David Miller)
- ppc64 build fix (Matt Wilson)
- improve smp scheduler fairness (Ingo Molnar)
- allow mlock for normal users, up to ulimit (Ingo Molnar)
- AMD64 port (Jim Paradis)

* Wed Apr 23 2003 Rik van Riel <riel@redhat.com>
- clean up mechanism to pass extra CFLAGS so we don't override what's
  already there
- merge ia64 build stuff (Larry Woodman)
- merge varyio + superbh (Stephen Tweedie)

* Tue Apr 22 2003 Rik van Riel <riel@redhat.com>
- merge up to 2.4.21-rc1
- IA64: virtual mem_map, acpi updates, netdump update, pte-highmem & fealnx
- IA64: architecture specific patches

* Mon Apr 21 2003 Rik van Riel <riel@redhat.com>
- import davem's ipsec patch pile
- ppc64 kallsyms and dump_fpu patches (Matt Wilson)
- rmap updates (x86_64 & bufferhead reclaim)
- ppc64 ptrace patch (Matt Wilson)

* Fri Apr 18 2003 Rik van Riel <riel@redhat.com>
- open up patch namespace 2000-5000 for network protocol changes
- renumber existing patches in that range

* Thu Apr 17 2003 Rik van Riel <riel@redhat.com>
- make sure to actually apply the rmap-updates patch
- iowait statistics
- ppc64 code merge (Mark & Julie DeWandel)
- ppc64 build scripts (Matt Wilson)
- raise symlink recursion level to 8 (Ernie Petrides)

* Wed Apr 16 2003 Rik van Riel <riel@redhat.com>
- merge up to marcelo's latest
- pte-highmem bits for x86-64 and ppc64

* Tue Apr 15 2003 Rik van Riel <riel@redhat.com>
- merge up to 2.4.21-pre7-ac1
- drop semtimedop patches (now in -ac)
- drop nfs xprt_fixes, fix_softirq, d_drop and nfs-readeof (merged in -pre7)
- add !CONFIG_QUOTA compile fix for 2.4.21-pre7-ac1

* Mon Apr 14 2003 Pete Zaitcev <zaitcev@redhat.com>
- add LCS driver (endemic to s390)

* Mon Apr 14 2003 Rik van Riel <riel@redhat.com>
- add rmap VM
- add kunmap_atomic debugging patch

* Sat Apr 12 2003 Rik van Riel <riel@redhat.com>
- remove dir.c part of NFS kmap_atomic patch for now
- using strlen as local variable name in nfs code kills, literally

* Fri Apr 11 2003 Rik van Riel <riel@redhat.com>
- merge S390(x) back in  (Pete Zaitcev)
- fix NFS kmap_atomic patch
- sched.c patch to disable interrupts in wake_forked_task  (Julie DeWandel)

* Thu Apr 10 2003 Rik van Riel <riel@redhat.com>
- AIO infrastructure  (Ben LaHaise)
- update NFS kmap_atomic patch  (Steve Dickson)

* Wed Apr  9 2003 Rik van Riel <riel@redhat.com>
- semtimedop patches  (Ernie Petrides)

* Tue Apr  8 2003 Rik van Riel <riel@redhat.com>
- I know understand linux-2.4.20-nfs-readeof.patch, so I merged it
- netdump update (Dave Anderson)
- 64 bit pci & elf loader fix (Mark & Julie)
- nptl whitespace patches, folded into nptl patch (Arjan van de Ven)
- rediff linux-2.4.18-smallpatches.patch

* Mon Apr  7 2003 Rik van Riel <riel@redhat.com>
- merge NFS patches by Steve Dickson (blame me for NFS kmap_atomic patch)
- split x86 syscall stuff out into separate patch

* Sat Apr  5 2003 Rik van Riel <riel@redhat.com>
- fix nptl patch, now it boots

* Fri Apr  4 2003 Rik van Riel <riel@redhat.com>
- port linux-2.4.20 o1-nptl.patch from gingin
- rediff a few patches

* Tue Apr  2 2003 Rik van Riel <riel@redhat.com>
- update linux-modules-unsupported (with Arjan)
- fix up the list a second time to fix module dependencies

* Mon Apr  1 2003 Rik van Riel <riel@redhat.com>
- copy -head into new AS3 branch
- remove i586 build
- remove 7.x compatibility (linux-2.4.9-fstat.patch)
- architecture patches get more breathing room (100 - 500)
- reserve patch numbers 1000 - 2000 for VM
- patch numbers 2000 - 5000 for bugfixes, changes and updates to
  existing drivers and filesystems
- remove inode reclaim patch (will be merged later as part of rmap)
- remove io priority scheduler (still experimental)
- remove nfs patches (linux-2.4.20-nfs-cto.patch,
  linux-2.4.20-nfs-access.patch & linux-2.4.20-nfs-rdplus.patch)
- remove linux-2.4.18-gericom.patch
- update netdump from RH9 branch

* Fri Mar 21 2003 Steve Dickson <SteveD@RedHat.com>
- Added three NFS performance patches

* Fri Mar 21 2003 Arjan van de Ven <arjanv@redhat.com>
- add a timer for aging requests up

* Thu Mar 20 2003 Arjan van de Ven <arjanv@redhat.com>
- fix the sorting in the io elevator

* Wed Mar 19 2003 Arjan van de Ven <arjanv@redhat.com>
- remerge ext3 orlov allocator and enable
- more priority io elevator infrastructure work

* Sat Mar 08 2003 Arjan van de Ven <arjanv@redhat.com>
- merge ext3 orlov allocator

* Thu Mar 04 2003 Arjan van de Ven <arjanv@redhat.com>
- go to 2.4.21-pre5-ac1
- split the rpm into a primary fileset and secondary (rare modules) fileset

* Wed Feb 26 2003 Arjan van de Ven <arjanv@redhat.com>
- go to 2.4.21-pre4-ac6
- drop lots of patches
- trim changelog to not have 2000, 2001 and 2002 anymore


* Mon Feb 17 2003 Arjan van de Ven <arjanv@redhat.com>
- downgrade pwc webcam driver one notch to the last known working version
- work around vm livelock
- make the cciss driver not enable irq's in it's irq handler

* Thu Feb 13 2003 Benjamin LaHaise <bcrl@redhat.com>
- fix for shared statistic < 0

* Thu Feb 13 2003 Arjan van de Ven <arjanv@redhat.com>
- Signal fixes for LSB testsuite
- merge patch to fix init=/bin/sh
- 2.4.21-pre4-ac4 bugfixes (mostly IDE crashes)

* Mon Feb 09 2003 Arjan van de Ven <arjanv@redhat.com>
- merge 2.4.21-pre4-ac3 bugfixes 

* Tue Feb  4 2003 Stephen C. Tweedie <sct@redhat.com>
- Add ext3 fix for truncating negative i_blocks

* Mon Feb 03 2003 Benjamin LaHaise <bcrl@redhat.com>
- add oopsmeharder for debugging hard hangs

* Mon Feb 03 2003 Arjan van de Ven <arjanv@redhat.com>
- merge rmap15d
- set the sbp2 command buffer to 64 elements instead of 8

* Wed Jan 29 2003 Arjan van de Ven <arjanv@redhat.com>
- merge tcp stall fix from DaveM
- merge bugfixes from 2.4.21-pre4

* Mon Jan 13 2003 Steve Dickson <SteveD@RedHat.com>
- Merge in the ACL and XATTR patches from the UL and BestBits trees.

* Sat Jan 11 2003 Stephen C. Tweedie <sct@redhat.com>
- Merge in the LVM pvmove fix to current tree

* Wed Jan 8 2003 Benjamin LaHaise <bcrl@redhat.com>
- add AMD Golem fixup
